import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface ApiManagementBackendConfig extends cdktf.TerraformMetaArguments {
    readonly apiManagementName: string;
    readonly description?: string;
    readonly name: string;
    readonly protocol: string;
    readonly resourceGroupName: string;
    readonly resourceId?: string;
    readonly title?: string;
    readonly url: string;
    /**
     * credentials block.
     */
    readonly credentials?: ApiManagementBackendCredentials[];
    /**
     * proxy block.
     */
    readonly proxy?: ApiManagementBackendProxy[];
    /**
     * service_fabric_cluster block.
     */
    readonly serviceFabricCluster?: ApiManagementBackendServiceFabricCluster[];
    /**
     * timeouts block.
     */
    readonly timeouts?: ApiManagementBackendTimeouts;
    /**
     * tls block.
     */
    readonly tls?: ApiManagementBackendTls[];
}
export interface ApiManagementBackendCredentialsAuthorization {
    readonly parameter?: string;
    readonly scheme?: string;
}
export interface ApiManagementBackendCredentials {
    readonly certificate?: string[];
    readonly header?: {
        [key: string]: string;
    };
    readonly query?: {
        [key: string]: string;
    };
    /**
     * authorization block.
     */
    readonly authorization?: ApiManagementBackendCredentialsAuthorization[];
}
export interface ApiManagementBackendProxy {
    readonly password?: string;
    readonly url: string;
    readonly username: string;
}
export interface ApiManagementBackendServiceFabricClusterServerX509Name {
    readonly issuerCertificateThumbprint: string;
    readonly name: string;
}
export interface ApiManagementBackendServiceFabricCluster {
    readonly clientCertificateThumbprint: string;
    readonly managementEndpoints: string[];
    readonly maxPartitionResolutionRetries: number;
    readonly serverCertificateThumbprints?: string[];
    /**
     * server_x509_name block.
     */
    readonly serverX509Name?: ApiManagementBackendServiceFabricClusterServerX509Name[];
}
export interface ApiManagementBackendTimeouts {
    readonly create?: string;
    readonly delete?: string;
    readonly read?: string;
    readonly update?: string;
}
export interface ApiManagementBackendTls {
    readonly validateCertificateChain?: boolean;
    readonly validateCertificateName?: boolean;
}
export declare class ApiManagementBackend extends cdktf.TerraformResource {
    constructor(scope: Construct, id: string, config: ApiManagementBackendConfig);
    private _apiManagementName;
    get apiManagementName(): string;
    set apiManagementName(value: string);
    get apiManagementNameInput(): string;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    get id(): string;
    private _name;
    get name(): string;
    set name(value: string);
    get nameInput(): string;
    private _protocol;
    get protocol(): string;
    set protocol(value: string);
    get protocolInput(): string;
    private _resourceGroupName;
    get resourceGroupName(): string;
    set resourceGroupName(value: string);
    get resourceGroupNameInput(): string;
    private _resourceId?;
    get resourceId(): string;
    set resourceId(value: string);
    resetResourceId(): void;
    get resourceIdInput(): string | undefined;
    private _title?;
    get title(): string;
    set title(value: string);
    resetTitle(): void;
    get titleInput(): string | undefined;
    private _url;
    get url(): string;
    set url(value: string);
    get urlInput(): string;
    private _credentials?;
    get credentials(): ApiManagementBackendCredentials[];
    set credentials(value: ApiManagementBackendCredentials[]);
    resetCredentials(): void;
    get credentialsInput(): ApiManagementBackendCredentials[] | undefined;
    private _proxy?;
    get proxy(): ApiManagementBackendProxy[];
    set proxy(value: ApiManagementBackendProxy[]);
    resetProxy(): void;
    get proxyInput(): ApiManagementBackendProxy[] | undefined;
    private _serviceFabricCluster?;
    get serviceFabricCluster(): ApiManagementBackendServiceFabricCluster[];
    set serviceFabricCluster(value: ApiManagementBackendServiceFabricCluster[]);
    resetServiceFabricCluster(): void;
    get serviceFabricClusterInput(): ApiManagementBackendServiceFabricCluster[] | undefined;
    private _timeouts?;
    get timeouts(): ApiManagementBackendTimeouts;
    set timeouts(value: ApiManagementBackendTimeouts);
    resetTimeouts(): void;
    get timeoutsInput(): ApiManagementBackendTimeouts | undefined;
    private _tls?;
    get tls(): ApiManagementBackendTls[];
    set tls(value: ApiManagementBackendTls[]);
    resetTls(): void;
    get tlsInput(): ApiManagementBackendTls[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
