import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface ApiManagementConfig extends cdktf.TerraformMetaArguments {
    readonly location: string;
    readonly name: string;
    readonly notificationSenderEmail?: string;
    readonly policy?: ApiManagementPolicy[];
    readonly publisherEmail: string;
    readonly publisherName: string;
    readonly resourceGroupName: string;
    readonly skuName: string;
    readonly tags?: {
        [key: string]: string;
    };
    readonly virtualNetworkType?: string;
    /**
     * additional_location block.
     */
    readonly additionalLocation?: ApiManagementAdditionalLocation[];
    /**
     * certificate block.
     */
    readonly certificate?: ApiManagementCertificate[];
    /**
     * hostname_configuration block.
     */
    readonly hostnameConfiguration?: ApiManagementHostnameConfiguration[];
    /**
     * identity block.
     */
    readonly identity?: ApiManagementIdentity[];
    /**
     * protocols block.
     */
    readonly protocols?: ApiManagementProtocols[];
    /**
     * security block.
     */
    readonly security?: ApiManagementSecurity[];
    /**
     * sign_in block.
     */
    readonly signIn?: ApiManagementSignIn[];
    /**
     * sign_up block.
     */
    readonly signUp?: ApiManagementSignUp[];
    /**
     * timeouts block.
     */
    readonly timeouts?: ApiManagementTimeouts;
    /**
     * virtual_network_configuration block.
     */
    readonly virtualNetworkConfiguration?: ApiManagementVirtualNetworkConfiguration[];
}
export interface ApiManagementPolicy {
    readonly xmlContent?: string;
    readonly xmlLink?: string;
}
export interface ApiManagementAdditionalLocationVirtualNetworkConfiguration {
    readonly subnetId: string;
}
export interface ApiManagementAdditionalLocation {
    readonly location: string;
    /**
     * virtual_network_configuration block.
     */
    readonly virtualNetworkConfiguration?: ApiManagementAdditionalLocationVirtualNetworkConfiguration[];
}
export interface ApiManagementCertificate {
    readonly certificatePassword: string;
    readonly encodedCertificate: string;
    readonly storeName: string;
}
export interface ApiManagementHostnameConfigurationDeveloperPortal {
    readonly certificate?: string;
    readonly certificatePassword?: string;
    readonly hostName: string;
    readonly keyVaultId?: string;
    readonly negotiateClientCertificate?: boolean;
}
export interface ApiManagementHostnameConfigurationManagement {
    readonly certificate?: string;
    readonly certificatePassword?: string;
    readonly hostName: string;
    readonly keyVaultId?: string;
    readonly negotiateClientCertificate?: boolean;
}
export interface ApiManagementHostnameConfigurationPortal {
    readonly certificate?: string;
    readonly certificatePassword?: string;
    readonly hostName: string;
    readonly keyVaultId?: string;
    readonly negotiateClientCertificate?: boolean;
}
export interface ApiManagementHostnameConfigurationProxy {
    readonly certificate?: string;
    readonly certificatePassword?: string;
    readonly defaultSslBinding?: boolean;
    readonly hostName: string;
    readonly keyVaultId?: string;
    readonly negotiateClientCertificate?: boolean;
}
export interface ApiManagementHostnameConfigurationScm {
    readonly certificate?: string;
    readonly certificatePassword?: string;
    readonly hostName: string;
    readonly keyVaultId?: string;
    readonly negotiateClientCertificate?: boolean;
}
export interface ApiManagementHostnameConfiguration {
    /**
     * developer_portal block.
     */
    readonly developerPortal?: ApiManagementHostnameConfigurationDeveloperPortal[];
    /**
     * management block.
     */
    readonly management?: ApiManagementHostnameConfigurationManagement[];
    /**
     * portal block.
     */
    readonly portal?: ApiManagementHostnameConfigurationPortal[];
    /**
     * proxy block.
     */
    readonly proxy?: ApiManagementHostnameConfigurationProxy[];
    /**
     * scm block.
     */
    readonly scm?: ApiManagementHostnameConfigurationScm[];
}
export interface ApiManagementIdentity {
    readonly identityIds?: string[];
    readonly type?: string;
}
export interface ApiManagementProtocols {
    readonly enableHttp2?: boolean;
}
export interface ApiManagementSecurity {
    readonly enableBackendSsl30?: boolean;
    readonly enableBackendTls10?: boolean;
    readonly enableBackendTls11?: boolean;
    readonly enableFrontendSsl30?: boolean;
    readonly enableFrontendTls10?: boolean;
    readonly enableFrontendTls11?: boolean;
    readonly enableTripleDesCiphers?: boolean;
}
export interface ApiManagementSignIn {
    readonly enabled: boolean;
}
export interface ApiManagementSignUpTermsOfService {
    readonly consentRequired: boolean;
    readonly enabled: boolean;
    readonly text?: string;
}
export interface ApiManagementSignUp {
    readonly enabled: boolean;
    /**
     * terms_of_service block.
     */
    readonly termsOfService: ApiManagementSignUpTermsOfService[];
}
export interface ApiManagementTimeouts {
    readonly create?: string;
    readonly delete?: string;
    readonly read?: string;
    readonly update?: string;
}
export interface ApiManagementVirtualNetworkConfiguration {
    readonly subnetId: string;
}
export declare class ApiManagement extends cdktf.TerraformResource {
    constructor(scope: Construct, id: string, config: ApiManagementConfig);
    get developerPortalUrl(): string;
    get gatewayRegionalUrl(): string;
    get gatewayUrl(): string;
    get id(): string;
    private _location;
    get location(): string;
    set location(value: string);
    get locationInput(): string;
    get managementApiUrl(): string;
    private _name;
    get name(): string;
    set name(value: string);
    get nameInput(): string;
    private _notificationSenderEmail?;
    get notificationSenderEmail(): string;
    set notificationSenderEmail(value: string);
    resetNotificationSenderEmail(): void;
    get notificationSenderEmailInput(): string | undefined;
    private _policy?;
    get policy(): ApiManagementPolicy[];
    set policy(value: ApiManagementPolicy[]);
    resetPolicy(): void;
    get policyInput(): ApiManagementPolicy[] | undefined;
    get portalUrl(): string;
    get privateIpAddresses(): string[];
    get publicIpAddresses(): string[];
    private _publisherEmail;
    get publisherEmail(): string;
    set publisherEmail(value: string);
    get publisherEmailInput(): string;
    private _publisherName;
    get publisherName(): string;
    set publisherName(value: string);
    get publisherNameInput(): string;
    private _resourceGroupName;
    get resourceGroupName(): string;
    set resourceGroupName(value: string);
    get resourceGroupNameInput(): string;
    get scmUrl(): string;
    private _skuName;
    get skuName(): string;
    set skuName(value: string);
    get skuNameInput(): string;
    private _tags?;
    get tags(): {
        [key: string]: string;
    };
    set tags(value: {
        [key: string]: string;
    });
    resetTags(): void;
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _virtualNetworkType?;
    get virtualNetworkType(): string;
    set virtualNetworkType(value: string);
    resetVirtualNetworkType(): void;
    get virtualNetworkTypeInput(): string | undefined;
    private _additionalLocation?;
    get additionalLocation(): ApiManagementAdditionalLocation[];
    set additionalLocation(value: ApiManagementAdditionalLocation[]);
    resetAdditionalLocation(): void;
    get additionalLocationInput(): ApiManagementAdditionalLocation[] | undefined;
    private _certificate?;
    get certificate(): ApiManagementCertificate[];
    set certificate(value: ApiManagementCertificate[]);
    resetCertificate(): void;
    get certificateInput(): ApiManagementCertificate[] | undefined;
    private _hostnameConfiguration?;
    get hostnameConfiguration(): ApiManagementHostnameConfiguration[];
    set hostnameConfiguration(value: ApiManagementHostnameConfiguration[]);
    resetHostnameConfiguration(): void;
    get hostnameConfigurationInput(): ApiManagementHostnameConfiguration[] | undefined;
    private _identity?;
    get identity(): ApiManagementIdentity[];
    set identity(value: ApiManagementIdentity[]);
    resetIdentity(): void;
    get identityInput(): ApiManagementIdentity[] | undefined;
    private _protocols?;
    get protocols(): ApiManagementProtocols[];
    set protocols(value: ApiManagementProtocols[]);
    resetProtocols(): void;
    get protocolsInput(): ApiManagementProtocols[] | undefined;
    private _security?;
    get security(): ApiManagementSecurity[];
    set security(value: ApiManagementSecurity[]);
    resetSecurity(): void;
    get securityInput(): ApiManagementSecurity[] | undefined;
    private _signIn?;
    get signIn(): ApiManagementSignIn[];
    set signIn(value: ApiManagementSignIn[]);
    resetSignIn(): void;
    get signInInput(): ApiManagementSignIn[] | undefined;
    private _signUp?;
    get signUp(): ApiManagementSignUp[];
    set signUp(value: ApiManagementSignUp[]);
    resetSignUp(): void;
    get signUpInput(): ApiManagementSignUp[] | undefined;
    private _timeouts?;
    get timeouts(): ApiManagementTimeouts;
    set timeouts(value: ApiManagementTimeouts);
    resetTimeouts(): void;
    get timeoutsInput(): ApiManagementTimeouts | undefined;
    private _virtualNetworkConfiguration?;
    get virtualNetworkConfiguration(): ApiManagementVirtualNetworkConfiguration[];
    set virtualNetworkConfiguration(value: ApiManagementVirtualNetworkConfiguration[]);
    resetVirtualNetworkConfiguration(): void;
    get virtualNetworkConfigurationInput(): ApiManagementVirtualNetworkConfiguration[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
