import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface AppServiceSlotConfig extends cdktf.TerraformMetaArguments {
    readonly appServiceName: string;
    readonly appServicePlanId: string;
    readonly appSettings?: {
        [key: string]: string;
    };
    readonly clientAffinityEnabled?: boolean;
    readonly enabled?: boolean;
    readonly httpsOnly?: boolean;
    readonly location: string;
    readonly name: string;
    readonly resourceGroupName: string;
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * auth_settings block.
     */
    readonly authSettings?: AppServiceSlotAuthSettings[];
    /**
     * connection_string block.
     */
    readonly connectionString?: AppServiceSlotConnectionString[];
    /**
     * identity block.
     */
    readonly identity?: AppServiceSlotIdentity[];
    /**
     * logs block.
     */
    readonly logs?: AppServiceSlotLogs[];
    /**
     * site_config block.
     */
    readonly siteConfig?: AppServiceSlotSiteConfig[];
    /**
     * timeouts block.
     */
    readonly timeouts?: AppServiceSlotTimeouts;
}
export declare class AppServiceSlotSiteCredential extends cdktf.ComplexComputedList {
    get password(): string;
    get username(): string;
}
export interface AppServiceSlotAuthSettingsActiveDirectory {
    readonly allowedAudiences?: string[];
    readonly clientId: string;
    readonly clientSecret?: string;
}
export interface AppServiceSlotAuthSettingsFacebook {
    readonly appId: string;
    readonly appSecret: string;
    readonly oauthScopes?: string[];
}
export interface AppServiceSlotAuthSettingsGoogle {
    readonly clientId: string;
    readonly clientSecret: string;
    readonly oauthScopes?: string[];
}
export interface AppServiceSlotAuthSettingsMicrosoft {
    readonly clientId: string;
    readonly clientSecret: string;
    readonly oauthScopes?: string[];
}
export interface AppServiceSlotAuthSettingsTwitter {
    readonly consumerKey: string;
    readonly consumerSecret: string;
}
export interface AppServiceSlotAuthSettings {
    readonly additionalLoginParams?: {
        [key: string]: string;
    };
    readonly allowedExternalRedirectUrls?: string[];
    readonly defaultProvider?: string;
    readonly enabled: boolean;
    readonly issuer?: string;
    readonly runtimeVersion?: string;
    readonly tokenRefreshExtensionHours?: number;
    readonly tokenStoreEnabled?: boolean;
    readonly unauthenticatedClientAction?: string;
    /**
     * active_directory block.
     */
    readonly activeDirectory?: AppServiceSlotAuthSettingsActiveDirectory[];
    /**
     * facebook block.
     */
    readonly facebook?: AppServiceSlotAuthSettingsFacebook[];
    /**
     * google block.
     */
    readonly google?: AppServiceSlotAuthSettingsGoogle[];
    /**
     * microsoft block.
     */
    readonly microsoft?: AppServiceSlotAuthSettingsMicrosoft[];
    /**
     * twitter block.
     */
    readonly twitter?: AppServiceSlotAuthSettingsTwitter[];
}
export interface AppServiceSlotConnectionString {
    readonly name: string;
    readonly type: string;
    readonly value: string;
}
export interface AppServiceSlotIdentity {
    readonly identityIds?: string[];
    readonly type: string;
}
export interface AppServiceSlotLogsApplicationLogsAzureBlobStorage {
    readonly level: string;
    readonly retentionInDays: number;
    readonly sasUrl: string;
}
export interface AppServiceSlotLogsApplicationLogs {
    readonly fileSystemLevel?: string;
    /**
     * azure_blob_storage block.
     */
    readonly azureBlobStorage?: AppServiceSlotLogsApplicationLogsAzureBlobStorage[];
}
export interface AppServiceSlotLogsHttpLogsAzureBlobStorage {
    readonly retentionInDays: number;
    readonly sasUrl: string;
}
export interface AppServiceSlotLogsHttpLogsFileSystem {
    readonly retentionInDays: number;
    readonly retentionInMb: number;
}
export interface AppServiceSlotLogsHttpLogs {
    /**
     * azure_blob_storage block.
     */
    readonly azureBlobStorage?: AppServiceSlotLogsHttpLogsAzureBlobStorage[];
    /**
     * file_system block.
     */
    readonly fileSystem?: AppServiceSlotLogsHttpLogsFileSystem[];
}
export interface AppServiceSlotLogs {
    /**
     * application_logs block.
     */
    readonly applicationLogs?: AppServiceSlotLogsApplicationLogs[];
    /**
     * http_logs block.
     */
    readonly httpLogs?: AppServiceSlotLogsHttpLogs[];
}
export interface AppServiceSlotSiteConfigIpRestriction {
    readonly action?: string;
    readonly ipAddress?: string;
    readonly name?: string;
    readonly priority?: number;
    readonly subnetId?: string;
    readonly virtualNetworkSubnetId?: string;
}
export interface AppServiceSlotSiteConfigScmIpRestriction {
    readonly action?: string;
    readonly ipAddress?: string;
    readonly name?: string;
    readonly priority?: number;
    readonly subnetId?: string;
    readonly virtualNetworkSubnetId?: string;
}
export interface AppServiceSlotSiteConfigCors {
    readonly allowedOrigins: string[];
    readonly supportCredentials?: boolean;
}
export interface AppServiceSlotSiteConfig {
    readonly alwaysOn?: boolean;
    readonly appCommandLine?: string;
    readonly autoSwapSlotName?: string;
    readonly defaultDocuments?: string[];
    readonly dotnetFrameworkVersion?: string;
    readonly ftpsState?: string;
    readonly healthCheckPath?: string;
    readonly http2Enabled?: boolean;
    readonly ipRestriction?: AppServiceSlotSiteConfigIpRestriction[];
    readonly javaContainer?: string;
    readonly javaContainerVersion?: string;
    readonly javaVersion?: string;
    readonly linuxFxVersion?: string;
    readonly localMysqlEnabled?: boolean;
    readonly managedPipelineMode?: string;
    readonly minTlsVersion?: string;
    readonly phpVersion?: string;
    readonly pythonVersion?: string;
    readonly remoteDebuggingEnabled?: boolean;
    readonly remoteDebuggingVersion?: string;
    readonly scmIpRestriction?: AppServiceSlotSiteConfigScmIpRestriction[];
    readonly scmType?: string;
    readonly scmUseMainIpRestriction?: boolean;
    readonly use32BitWorkerProcess?: boolean;
    readonly websocketsEnabled?: boolean;
    readonly windowsFxVersion?: string;
    /**
     * cors block.
     */
    readonly cors?: AppServiceSlotSiteConfigCors[];
}
export interface AppServiceSlotTimeouts {
    readonly create?: string;
    readonly delete?: string;
    readonly read?: string;
    readonly update?: string;
}
export declare class AppServiceSlot extends cdktf.TerraformResource {
    constructor(scope: Construct, id: string, config: AppServiceSlotConfig);
    private _appServiceName;
    get appServiceName(): string;
    set appServiceName(value: string);
    get appServiceNameInput(): string;
    private _appServicePlanId;
    get appServicePlanId(): string;
    set appServicePlanId(value: string);
    get appServicePlanIdInput(): string;
    private _appSettings?;
    get appSettings(): {
        [key: string]: string;
    };
    set appSettings(value: {
        [key: string]: string;
    });
    resetAppSettings(): void;
    get appSettingsInput(): {
        [key: string]: string;
    } | undefined;
    private _clientAffinityEnabled?;
    get clientAffinityEnabled(): boolean;
    set clientAffinityEnabled(value: boolean);
    resetClientAffinityEnabled(): void;
    get clientAffinityEnabledInput(): boolean | undefined;
    get defaultSiteHostname(): string;
    private _enabled?;
    get enabled(): boolean;
    set enabled(value: boolean);
    resetEnabled(): void;
    get enabledInput(): boolean | undefined;
    private _httpsOnly?;
    get httpsOnly(): boolean;
    set httpsOnly(value: boolean);
    resetHttpsOnly(): void;
    get httpsOnlyInput(): boolean | undefined;
    get id(): string;
    private _location;
    get location(): string;
    set location(value: string);
    get locationInput(): string;
    private _name;
    get name(): string;
    set name(value: string);
    get nameInput(): string;
    private _resourceGroupName;
    get resourceGroupName(): string;
    set resourceGroupName(value: string);
    get resourceGroupNameInput(): string;
    siteCredential(index: string): AppServiceSlotSiteCredential;
    private _tags?;
    get tags(): {
        [key: string]: string;
    };
    set tags(value: {
        [key: string]: string;
    });
    resetTags(): void;
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _authSettings?;
    get authSettings(): AppServiceSlotAuthSettings[];
    set authSettings(value: AppServiceSlotAuthSettings[]);
    resetAuthSettings(): void;
    get authSettingsInput(): AppServiceSlotAuthSettings[] | undefined;
    private _connectionString?;
    get connectionString(): AppServiceSlotConnectionString[];
    set connectionString(value: AppServiceSlotConnectionString[]);
    resetConnectionString(): void;
    get connectionStringInput(): AppServiceSlotConnectionString[] | undefined;
    private _identity?;
    get identity(): AppServiceSlotIdentity[];
    set identity(value: AppServiceSlotIdentity[]);
    resetIdentity(): void;
    get identityInput(): AppServiceSlotIdentity[] | undefined;
    private _logs?;
    get logs(): AppServiceSlotLogs[];
    set logs(value: AppServiceSlotLogs[]);
    resetLogs(): void;
    get logsInput(): AppServiceSlotLogs[] | undefined;
    private _siteConfig?;
    get siteConfig(): AppServiceSlotSiteConfig[];
    set siteConfig(value: AppServiceSlotSiteConfig[]);
    resetSiteConfig(): void;
    get siteConfigInput(): AppServiceSlotSiteConfig[] | undefined;
    private _timeouts?;
    get timeouts(): AppServiceSlotTimeouts;
    set timeouts(value: AppServiceSlotTimeouts);
    resetTimeouts(): void;
    get timeoutsInput(): AppServiceSlotTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
