import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface AppServiceConfig extends cdktf.TerraformMetaArguments {
    readonly appServicePlanId: string;
    readonly appSettings?: {
        [key: string]: string;
    };
    readonly clientAffinityEnabled?: boolean;
    readonly clientCertEnabled?: boolean;
    readonly enabled?: boolean;
    readonly httpsOnly?: boolean;
    readonly location: string;
    readonly name: string;
    readonly resourceGroupName: string;
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * auth_settings block.
     */
    readonly authSettings?: AppServiceAuthSettings[];
    /**
     * backup block.
     */
    readonly backup?: AppServiceBackup[];
    /**
     * connection_string block.
     */
    readonly connectionString?: AppServiceConnectionString[];
    /**
     * identity block.
     */
    readonly identity?: AppServiceIdentity[];
    /**
     * logs block.
     */
    readonly logs?: AppServiceLogs[];
    /**
     * site_config block.
     */
    readonly siteConfig?: AppServiceSiteConfig[];
    /**
     * source_control block.
     */
    readonly sourceControl?: AppServiceSourceControl[];
    /**
     * storage_account block.
     */
    readonly storageAccount?: AppServiceStorageAccount[];
    /**
     * timeouts block.
     */
    readonly timeouts?: AppServiceTimeouts;
}
export declare class AppServiceSiteCredential extends cdktf.ComplexComputedList {
    get password(): string;
    get username(): string;
}
export interface AppServiceAuthSettingsActiveDirectory {
    readonly allowedAudiences?: string[];
    readonly clientId: string;
    readonly clientSecret?: string;
}
export interface AppServiceAuthSettingsFacebook {
    readonly appId: string;
    readonly appSecret: string;
    readonly oauthScopes?: string[];
}
export interface AppServiceAuthSettingsGoogle {
    readonly clientId: string;
    readonly clientSecret: string;
    readonly oauthScopes?: string[];
}
export interface AppServiceAuthSettingsMicrosoft {
    readonly clientId: string;
    readonly clientSecret: string;
    readonly oauthScopes?: string[];
}
export interface AppServiceAuthSettingsTwitter {
    readonly consumerKey: string;
    readonly consumerSecret: string;
}
export interface AppServiceAuthSettings {
    readonly additionalLoginParams?: {
        [key: string]: string;
    };
    readonly allowedExternalRedirectUrls?: string[];
    readonly defaultProvider?: string;
    readonly enabled: boolean;
    readonly issuer?: string;
    readonly runtimeVersion?: string;
    readonly tokenRefreshExtensionHours?: number;
    readonly tokenStoreEnabled?: boolean;
    readonly unauthenticatedClientAction?: string;
    /**
     * active_directory block.
     */
    readonly activeDirectory?: AppServiceAuthSettingsActiveDirectory[];
    /**
     * facebook block.
     */
    readonly facebook?: AppServiceAuthSettingsFacebook[];
    /**
     * google block.
     */
    readonly google?: AppServiceAuthSettingsGoogle[];
    /**
     * microsoft block.
     */
    readonly microsoft?: AppServiceAuthSettingsMicrosoft[];
    /**
     * twitter block.
     */
    readonly twitter?: AppServiceAuthSettingsTwitter[];
}
export interface AppServiceBackupSchedule {
    readonly frequencyInterval: number;
    readonly frequencyUnit: string;
    readonly keepAtLeastOneBackup?: boolean;
    readonly retentionPeriodInDays?: number;
    readonly startTime?: string;
}
export interface AppServiceBackup {
    readonly enabled?: boolean;
    readonly name: string;
    readonly storageAccountUrl: string;
    /**
     * schedule block.
     */
    readonly schedule: AppServiceBackupSchedule[];
}
export interface AppServiceConnectionString {
    readonly name: string;
    readonly type: string;
    readonly value: string;
}
export interface AppServiceIdentity {
    readonly identityIds?: string[];
    readonly type: string;
}
export interface AppServiceLogsApplicationLogsAzureBlobStorage {
    readonly level: string;
    readonly retentionInDays: number;
    readonly sasUrl: string;
}
export interface AppServiceLogsApplicationLogs {
    readonly fileSystemLevel?: string;
    /**
     * azure_blob_storage block.
     */
    readonly azureBlobStorage?: AppServiceLogsApplicationLogsAzureBlobStorage[];
}
export interface AppServiceLogsHttpLogsAzureBlobStorage {
    readonly retentionInDays: number;
    readonly sasUrl: string;
}
export interface AppServiceLogsHttpLogsFileSystem {
    readonly retentionInDays: number;
    readonly retentionInMb: number;
}
export interface AppServiceLogsHttpLogs {
    /**
     * azure_blob_storage block.
     */
    readonly azureBlobStorage?: AppServiceLogsHttpLogsAzureBlobStorage[];
    /**
     * file_system block.
     */
    readonly fileSystem?: AppServiceLogsHttpLogsFileSystem[];
}
export interface AppServiceLogs {
    /**
     * application_logs block.
     */
    readonly applicationLogs?: AppServiceLogsApplicationLogs[];
    /**
     * http_logs block.
     */
    readonly httpLogs?: AppServiceLogsHttpLogs[];
}
export interface AppServiceSiteConfigIpRestriction {
    readonly action?: string;
    readonly ipAddress?: string;
    readonly name?: string;
    readonly priority?: number;
    readonly subnetId?: string;
    readonly virtualNetworkSubnetId?: string;
}
export interface AppServiceSiteConfigScmIpRestriction {
    readonly action?: string;
    readonly ipAddress?: string;
    readonly name?: string;
    readonly priority?: number;
    readonly subnetId?: string;
    readonly virtualNetworkSubnetId?: string;
}
export interface AppServiceSiteConfigCors {
    readonly allowedOrigins: string[];
    readonly supportCredentials?: boolean;
}
export interface AppServiceSiteConfig {
    readonly alwaysOn?: boolean;
    readonly appCommandLine?: string;
    readonly autoSwapSlotName?: string;
    readonly defaultDocuments?: string[];
    readonly dotnetFrameworkVersion?: string;
    readonly ftpsState?: string;
    readonly healthCheckPath?: string;
    readonly http2Enabled?: boolean;
    readonly ipRestriction?: AppServiceSiteConfigIpRestriction[];
    readonly javaContainer?: string;
    readonly javaContainerVersion?: string;
    readonly javaVersion?: string;
    readonly linuxFxVersion?: string;
    readonly localMysqlEnabled?: boolean;
    readonly managedPipelineMode?: string;
    readonly minTlsVersion?: string;
    readonly phpVersion?: string;
    readonly pythonVersion?: string;
    readonly remoteDebuggingEnabled?: boolean;
    readonly remoteDebuggingVersion?: string;
    readonly scmIpRestriction?: AppServiceSiteConfigScmIpRestriction[];
    readonly scmType?: string;
    readonly scmUseMainIpRestriction?: boolean;
    readonly use32BitWorkerProcess?: boolean;
    readonly websocketsEnabled?: boolean;
    readonly windowsFxVersion?: string;
    /**
     * cors block.
     */
    readonly cors?: AppServiceSiteConfigCors[];
}
export interface AppServiceSourceControl {
    readonly branch?: string;
    readonly manualIntegration?: boolean;
    readonly repoUrl?: string;
    readonly rollbackEnabled?: boolean;
    readonly useMercurial?: boolean;
}
export interface AppServiceStorageAccount {
    readonly accessKey: string;
    readonly accountName: string;
    readonly mountPath?: string;
    readonly name: string;
    readonly shareName: string;
    readonly type: string;
}
export interface AppServiceTimeouts {
    readonly create?: string;
    readonly delete?: string;
    readonly read?: string;
    readonly update?: string;
}
export declare class AppService extends cdktf.TerraformResource {
    constructor(scope: Construct, id: string, config: AppServiceConfig);
    private _appServicePlanId;
    get appServicePlanId(): string;
    set appServicePlanId(value: string);
    get appServicePlanIdInput(): string;
    private _appSettings?;
    get appSettings(): {
        [key: string]: string;
    };
    set appSettings(value: {
        [key: string]: string;
    });
    resetAppSettings(): void;
    get appSettingsInput(): {
        [key: string]: string;
    } | undefined;
    private _clientAffinityEnabled?;
    get clientAffinityEnabled(): boolean;
    set clientAffinityEnabled(value: boolean);
    resetClientAffinityEnabled(): void;
    get clientAffinityEnabledInput(): boolean | undefined;
    private _clientCertEnabled?;
    get clientCertEnabled(): boolean;
    set clientCertEnabled(value: boolean);
    resetClientCertEnabled(): void;
    get clientCertEnabledInput(): boolean | undefined;
    get customDomainVerificationId(): string;
    get defaultSiteHostname(): string;
    private _enabled?;
    get enabled(): boolean;
    set enabled(value: boolean);
    resetEnabled(): void;
    get enabledInput(): boolean | undefined;
    private _httpsOnly?;
    get httpsOnly(): boolean;
    set httpsOnly(value: boolean);
    resetHttpsOnly(): void;
    get httpsOnlyInput(): boolean | undefined;
    get id(): string;
    private _location;
    get location(): string;
    set location(value: string);
    get locationInput(): string;
    private _name;
    get name(): string;
    set name(value: string);
    get nameInput(): string;
    get outboundIpAddresses(): string;
    get possibleOutboundIpAddresses(): string;
    private _resourceGroupName;
    get resourceGroupName(): string;
    set resourceGroupName(value: string);
    get resourceGroupNameInput(): string;
    siteCredential(index: string): AppServiceSiteCredential;
    private _tags?;
    get tags(): {
        [key: string]: string;
    };
    set tags(value: {
        [key: string]: string;
    });
    resetTags(): void;
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _authSettings?;
    get authSettings(): AppServiceAuthSettings[];
    set authSettings(value: AppServiceAuthSettings[]);
    resetAuthSettings(): void;
    get authSettingsInput(): AppServiceAuthSettings[] | undefined;
    private _backup?;
    get backup(): AppServiceBackup[];
    set backup(value: AppServiceBackup[]);
    resetBackup(): void;
    get backupInput(): AppServiceBackup[] | undefined;
    private _connectionString?;
    get connectionString(): AppServiceConnectionString[];
    set connectionString(value: AppServiceConnectionString[]);
    resetConnectionString(): void;
    get connectionStringInput(): AppServiceConnectionString[] | undefined;
    private _identity?;
    get identity(): AppServiceIdentity[];
    set identity(value: AppServiceIdentity[]);
    resetIdentity(): void;
    get identityInput(): AppServiceIdentity[] | undefined;
    private _logs?;
    get logs(): AppServiceLogs[];
    set logs(value: AppServiceLogs[]);
    resetLogs(): void;
    get logsInput(): AppServiceLogs[] | undefined;
    private _siteConfig?;
    get siteConfig(): AppServiceSiteConfig[];
    set siteConfig(value: AppServiceSiteConfig[]);
    resetSiteConfig(): void;
    get siteConfigInput(): AppServiceSiteConfig[] | undefined;
    private _sourceControl?;
    get sourceControl(): AppServiceSourceControl[];
    set sourceControl(value: AppServiceSourceControl[]);
    resetSourceControl(): void;
    get sourceControlInput(): AppServiceSourceControl[] | undefined;
    private _storageAccount?;
    get storageAccount(): AppServiceStorageAccount[];
    set storageAccount(value: AppServiceStorageAccount[]);
    resetStorageAccount(): void;
    get storageAccountInput(): AppServiceStorageAccount[] | undefined;
    private _timeouts?;
    get timeouts(): AppServiceTimeouts;
    set timeouts(value: AppServiceTimeouts);
    resetTimeouts(): void;
    get timeoutsInput(): AppServiceTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
