import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface ApplicationGatewayConfig extends cdktf.TerraformMetaArguments {
    readonly enableHttp2?: boolean;
    readonly firewallPolicyId?: string;
    readonly location: string;
    readonly name: string;
    readonly resourceGroupName: string;
    readonly tags?: {
        [key: string]: string;
    };
    readonly zones?: string[];
    /**
     * authentication_certificate block.
     */
    readonly authenticationCertificate?: ApplicationGatewayAuthenticationCertificate[];
    /**
     * autoscale_configuration block.
     */
    readonly autoscaleConfiguration?: ApplicationGatewayAutoscaleConfiguration[];
    /**
     * backend_address_pool block.
     */
    readonly backendAddressPool: ApplicationGatewayBackendAddressPool[];
    /**
     * backend_http_settings block.
     */
    readonly backendHttpSettings: ApplicationGatewayBackendHttpSettings[];
    /**
     * custom_error_configuration block.
     */
    readonly customErrorConfiguration?: ApplicationGatewayCustomErrorConfiguration[];
    /**
     * frontend_ip_configuration block.
     */
    readonly frontendIpConfiguration: ApplicationGatewayFrontendIpConfiguration[];
    /**
     * frontend_port block.
     */
    readonly frontendPort: ApplicationGatewayFrontendPort[];
    /**
     * gateway_ip_configuration block.
     */
    readonly gatewayIpConfiguration: ApplicationGatewayGatewayIpConfiguration[];
    /**
     * http_listener block.
     */
    readonly httpListener: ApplicationGatewayHttpListener[];
    /**
     * identity block.
     */
    readonly identity?: ApplicationGatewayIdentity[];
    /**
     * probe block.
     */
    readonly probe?: ApplicationGatewayProbe[];
    /**
     * redirect_configuration block.
     */
    readonly redirectConfiguration?: ApplicationGatewayRedirectConfiguration[];
    /**
     * request_routing_rule block.
     */
    readonly requestRoutingRule: ApplicationGatewayRequestRoutingRule[];
    /**
     * rewrite_rule_set block.
     */
    readonly rewriteRuleSet?: ApplicationGatewayRewriteRuleSet[];
    /**
     * sku block.
     */
    readonly sku: ApplicationGatewaySku[];
    /**
     * ssl_certificate block.
     */
    readonly sslCertificate?: ApplicationGatewaySslCertificate[];
    /**
     * ssl_policy block.
     */
    readonly sslPolicy?: ApplicationGatewaySslPolicy[];
    /**
     * timeouts block.
     */
    readonly timeouts?: ApplicationGatewayTimeouts;
    /**
     * trusted_root_certificate block.
     */
    readonly trustedRootCertificate?: ApplicationGatewayTrustedRootCertificate[];
    /**
     * url_path_map block.
     */
    readonly urlPathMap?: ApplicationGatewayUrlPathMap[];
    /**
     * waf_configuration block.
     */
    readonly wafConfiguration?: ApplicationGatewayWafConfiguration[];
}
export interface ApplicationGatewayAuthenticationCertificate {
    readonly data: string;
    readonly name: string;
}
export interface ApplicationGatewayAutoscaleConfiguration {
    readonly maxCapacity?: number;
    readonly minCapacity: number;
}
export interface ApplicationGatewayBackendAddressPool {
    readonly fqdns?: string[];
    readonly ipAddresses?: string[];
    readonly name: string;
}
export interface ApplicationGatewayBackendHttpSettingsAuthenticationCertificate {
    readonly name: string;
}
export interface ApplicationGatewayBackendHttpSettingsConnectionDraining {
    readonly drainTimeoutSec: number;
    readonly enabled: boolean;
}
export interface ApplicationGatewayBackendHttpSettings {
    readonly affinityCookieName?: string;
    readonly cookieBasedAffinity: string;
    readonly hostName?: string;
    readonly name: string;
    readonly path?: string;
    readonly pickHostNameFromBackendAddress?: boolean;
    readonly port: number;
    readonly probeName?: string;
    readonly protocol: string;
    readonly requestTimeout?: number;
    readonly trustedRootCertificateNames?: string[];
    /**
     * authentication_certificate block.
     */
    readonly authenticationCertificate?: ApplicationGatewayBackendHttpSettingsAuthenticationCertificate[];
    /**
     * connection_draining block.
     */
    readonly connectionDraining?: ApplicationGatewayBackendHttpSettingsConnectionDraining[];
}
export interface ApplicationGatewayCustomErrorConfiguration {
    readonly customErrorPageUrl: string;
    readonly statusCode: string;
}
export interface ApplicationGatewayFrontendIpConfiguration {
    readonly name: string;
    readonly privateIpAddress?: string;
    readonly privateIpAddressAllocation?: string;
    readonly publicIpAddressId?: string;
    readonly subnetId?: string;
}
export interface ApplicationGatewayFrontendPort {
    readonly name: string;
    readonly port: number;
}
export interface ApplicationGatewayGatewayIpConfiguration {
    readonly name: string;
    readonly subnetId: string;
}
export interface ApplicationGatewayHttpListenerCustomErrorConfiguration {
    readonly customErrorPageUrl: string;
    readonly statusCode: string;
}
export interface ApplicationGatewayHttpListener {
    readonly firewallPolicyId?: string;
    readonly frontendIpConfigurationName: string;
    readonly frontendPortName: string;
    readonly hostName?: string;
    readonly hostNames?: string[];
    readonly name: string;
    readonly protocol: string;
    readonly requireSni?: boolean;
    readonly sslCertificateName?: string;
    /**
     * custom_error_configuration block.
     */
    readonly customErrorConfiguration?: ApplicationGatewayHttpListenerCustomErrorConfiguration[];
}
export interface ApplicationGatewayIdentity {
    readonly identityIds: string[];
    readonly type?: string;
}
export interface ApplicationGatewayProbeMatch {
    readonly body?: string;
    readonly statusCode?: string[];
}
export interface ApplicationGatewayProbe {
    readonly host?: string;
    readonly interval: number;
    readonly minimumServers?: number;
    readonly name: string;
    readonly path: string;
    readonly pickHostNameFromBackendHttpSettings?: boolean;
    readonly port?: number;
    readonly protocol: string;
    readonly timeout: number;
    readonly unhealthyThreshold: number;
    /**
     * match block.
     */
    readonly match?: ApplicationGatewayProbeMatch[];
}
export interface ApplicationGatewayRedirectConfiguration {
    readonly includePath?: boolean;
    readonly includeQueryString?: boolean;
    readonly name: string;
    readonly redirectType: string;
    readonly targetListenerName?: string;
    readonly targetUrl?: string;
}
export interface ApplicationGatewayRequestRoutingRule {
    readonly backendAddressPoolName?: string;
    readonly backendHttpSettingsName?: string;
    readonly httpListenerName: string;
    readonly name: string;
    readonly redirectConfigurationName?: string;
    readonly rewriteRuleSetName?: string;
    readonly ruleType: string;
    readonly urlPathMapName?: string;
}
export interface ApplicationGatewayRewriteRuleSetRewriteRuleCondition {
    readonly ignoreCase?: boolean;
    readonly negate?: boolean;
    readonly pattern: string;
    readonly variable: string;
}
export interface ApplicationGatewayRewriteRuleSetRewriteRuleRequestHeaderConfiguration {
    readonly headerName: string;
    readonly headerValue: string;
}
export interface ApplicationGatewayRewriteRuleSetRewriteRuleResponseHeaderConfiguration {
    readonly headerName: string;
    readonly headerValue: string;
}
export interface ApplicationGatewayRewriteRuleSetRewriteRule {
    readonly name: string;
    readonly ruleSequence: number;
    /**
     * condition block.
     */
    readonly condition?: ApplicationGatewayRewriteRuleSetRewriteRuleCondition[];
    /**
     * request_header_configuration block.
     */
    readonly requestHeaderConfiguration?: ApplicationGatewayRewriteRuleSetRewriteRuleRequestHeaderConfiguration[];
    /**
     * response_header_configuration block.
     */
    readonly responseHeaderConfiguration?: ApplicationGatewayRewriteRuleSetRewriteRuleResponseHeaderConfiguration[];
}
export interface ApplicationGatewayRewriteRuleSet {
    readonly name: string;
    /**
     * rewrite_rule block.
     */
    readonly rewriteRule?: ApplicationGatewayRewriteRuleSetRewriteRule[];
}
export interface ApplicationGatewaySku {
    readonly capacity?: number;
    readonly name: string;
    readonly tier: string;
}
export interface ApplicationGatewaySslCertificate {
    readonly data?: string;
    readonly keyVaultSecretId?: string;
    readonly name: string;
    readonly password?: string;
}
export interface ApplicationGatewaySslPolicy {
    readonly cipherSuites?: string[];
    readonly disabledProtocols?: string[];
    readonly minProtocolVersion?: string;
    readonly policyName?: string;
    readonly policyType?: string;
}
export interface ApplicationGatewayTimeouts {
    readonly create?: string;
    readonly delete?: string;
    readonly read?: string;
    readonly update?: string;
}
export interface ApplicationGatewayTrustedRootCertificate {
    readonly data: string;
    readonly name: string;
}
export interface ApplicationGatewayUrlPathMapPathRule {
    readonly backendAddressPoolName?: string;
    readonly backendHttpSettingsName?: string;
    readonly name: string;
    readonly paths: string[];
    readonly redirectConfigurationName?: string;
    readonly rewriteRuleSetName?: string;
}
export interface ApplicationGatewayUrlPathMap {
    readonly defaultBackendAddressPoolName?: string;
    readonly defaultBackendHttpSettingsName?: string;
    readonly defaultRedirectConfigurationName?: string;
    readonly defaultRewriteRuleSetName?: string;
    readonly name: string;
    /**
     * path_rule block.
     */
    readonly pathRule: ApplicationGatewayUrlPathMapPathRule[];
}
export interface ApplicationGatewayWafConfigurationDisabledRuleGroup {
    readonly ruleGroupName: string;
    readonly rules?: number[];
}
export interface ApplicationGatewayWafConfigurationExclusion {
    readonly matchVariable: string;
    readonly selector?: string;
    readonly selectorMatchOperator?: string;
}
export interface ApplicationGatewayWafConfiguration {
    readonly enabled: boolean;
    readonly fileUploadLimitMb?: number;
    readonly firewallMode: string;
    readonly maxRequestBodySizeKb?: number;
    readonly requestBodyCheck?: boolean;
    readonly ruleSetType?: string;
    readonly ruleSetVersion: string;
    /**
     * disabled_rule_group block.
     */
    readonly disabledRuleGroup?: ApplicationGatewayWafConfigurationDisabledRuleGroup[];
    /**
     * exclusion block.
     */
    readonly exclusion?: ApplicationGatewayWafConfigurationExclusion[];
}
export declare class ApplicationGateway extends cdktf.TerraformResource {
    constructor(scope: Construct, id: string, config: ApplicationGatewayConfig);
    private _enableHttp2?;
    get enableHttp2(): boolean;
    set enableHttp2(value: boolean);
    resetEnableHttp2(): void;
    get enableHttp2Input(): boolean | undefined;
    private _firewallPolicyId?;
    get firewallPolicyId(): string;
    set firewallPolicyId(value: string);
    resetFirewallPolicyId(): void;
    get firewallPolicyIdInput(): string | undefined;
    get id(): string;
    private _location;
    get location(): string;
    set location(value: string);
    get locationInput(): string;
    private _name;
    get name(): string;
    set name(value: string);
    get nameInput(): string;
    private _resourceGroupName;
    get resourceGroupName(): string;
    set resourceGroupName(value: string);
    get resourceGroupNameInput(): string;
    private _tags?;
    get tags(): {
        [key: string]: string;
    };
    set tags(value: {
        [key: string]: string;
    });
    resetTags(): void;
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _zones?;
    get zones(): string[];
    set zones(value: string[]);
    resetZones(): void;
    get zonesInput(): string[] | undefined;
    private _authenticationCertificate?;
    get authenticationCertificate(): ApplicationGatewayAuthenticationCertificate[];
    set authenticationCertificate(value: ApplicationGatewayAuthenticationCertificate[]);
    resetAuthenticationCertificate(): void;
    get authenticationCertificateInput(): ApplicationGatewayAuthenticationCertificate[] | undefined;
    private _autoscaleConfiguration?;
    get autoscaleConfiguration(): ApplicationGatewayAutoscaleConfiguration[];
    set autoscaleConfiguration(value: ApplicationGatewayAutoscaleConfiguration[]);
    resetAutoscaleConfiguration(): void;
    get autoscaleConfigurationInput(): ApplicationGatewayAutoscaleConfiguration[] | undefined;
    private _backendAddressPool;
    get backendAddressPool(): ApplicationGatewayBackendAddressPool[];
    set backendAddressPool(value: ApplicationGatewayBackendAddressPool[]);
    get backendAddressPoolInput(): ApplicationGatewayBackendAddressPool[];
    private _backendHttpSettings;
    get backendHttpSettings(): ApplicationGatewayBackendHttpSettings[];
    set backendHttpSettings(value: ApplicationGatewayBackendHttpSettings[]);
    get backendHttpSettingsInput(): ApplicationGatewayBackendHttpSettings[];
    private _customErrorConfiguration?;
    get customErrorConfiguration(): ApplicationGatewayCustomErrorConfiguration[];
    set customErrorConfiguration(value: ApplicationGatewayCustomErrorConfiguration[]);
    resetCustomErrorConfiguration(): void;
    get customErrorConfigurationInput(): ApplicationGatewayCustomErrorConfiguration[] | undefined;
    private _frontendIpConfiguration;
    get frontendIpConfiguration(): ApplicationGatewayFrontendIpConfiguration[];
    set frontendIpConfiguration(value: ApplicationGatewayFrontendIpConfiguration[]);
    get frontendIpConfigurationInput(): ApplicationGatewayFrontendIpConfiguration[];
    private _frontendPort;
    get frontendPort(): ApplicationGatewayFrontendPort[];
    set frontendPort(value: ApplicationGatewayFrontendPort[]);
    get frontendPortInput(): ApplicationGatewayFrontendPort[];
    private _gatewayIpConfiguration;
    get gatewayIpConfiguration(): ApplicationGatewayGatewayIpConfiguration[];
    set gatewayIpConfiguration(value: ApplicationGatewayGatewayIpConfiguration[]);
    get gatewayIpConfigurationInput(): ApplicationGatewayGatewayIpConfiguration[];
    private _httpListener;
    get httpListener(): ApplicationGatewayHttpListener[];
    set httpListener(value: ApplicationGatewayHttpListener[]);
    get httpListenerInput(): ApplicationGatewayHttpListener[];
    private _identity?;
    get identity(): ApplicationGatewayIdentity[];
    set identity(value: ApplicationGatewayIdentity[]);
    resetIdentity(): void;
    get identityInput(): ApplicationGatewayIdentity[] | undefined;
    private _probe?;
    get probe(): ApplicationGatewayProbe[];
    set probe(value: ApplicationGatewayProbe[]);
    resetProbe(): void;
    get probeInput(): ApplicationGatewayProbe[] | undefined;
    private _redirectConfiguration?;
    get redirectConfiguration(): ApplicationGatewayRedirectConfiguration[];
    set redirectConfiguration(value: ApplicationGatewayRedirectConfiguration[]);
    resetRedirectConfiguration(): void;
    get redirectConfigurationInput(): ApplicationGatewayRedirectConfiguration[] | undefined;
    private _requestRoutingRule;
    get requestRoutingRule(): ApplicationGatewayRequestRoutingRule[];
    set requestRoutingRule(value: ApplicationGatewayRequestRoutingRule[]);
    get requestRoutingRuleInput(): ApplicationGatewayRequestRoutingRule[];
    private _rewriteRuleSet?;
    get rewriteRuleSet(): ApplicationGatewayRewriteRuleSet[];
    set rewriteRuleSet(value: ApplicationGatewayRewriteRuleSet[]);
    resetRewriteRuleSet(): void;
    get rewriteRuleSetInput(): ApplicationGatewayRewriteRuleSet[] | undefined;
    private _sku;
    get sku(): ApplicationGatewaySku[];
    set sku(value: ApplicationGatewaySku[]);
    get skuInput(): ApplicationGatewaySku[];
    private _sslCertificate?;
    get sslCertificate(): ApplicationGatewaySslCertificate[];
    set sslCertificate(value: ApplicationGatewaySslCertificate[]);
    resetSslCertificate(): void;
    get sslCertificateInput(): ApplicationGatewaySslCertificate[] | undefined;
    private _sslPolicy?;
    get sslPolicy(): ApplicationGatewaySslPolicy[];
    set sslPolicy(value: ApplicationGatewaySslPolicy[]);
    resetSslPolicy(): void;
    get sslPolicyInput(): ApplicationGatewaySslPolicy[] | undefined;
    private _timeouts?;
    get timeouts(): ApplicationGatewayTimeouts;
    set timeouts(value: ApplicationGatewayTimeouts);
    resetTimeouts(): void;
    get timeoutsInput(): ApplicationGatewayTimeouts | undefined;
    private _trustedRootCertificate?;
    get trustedRootCertificate(): ApplicationGatewayTrustedRootCertificate[];
    set trustedRootCertificate(value: ApplicationGatewayTrustedRootCertificate[]);
    resetTrustedRootCertificate(): void;
    get trustedRootCertificateInput(): ApplicationGatewayTrustedRootCertificate[] | undefined;
    private _urlPathMap?;
    get urlPathMap(): ApplicationGatewayUrlPathMap[];
    set urlPathMap(value: ApplicationGatewayUrlPathMap[]);
    resetUrlPathMap(): void;
    get urlPathMapInput(): ApplicationGatewayUrlPathMap[] | undefined;
    private _wafConfiguration?;
    get wafConfiguration(): ApplicationGatewayWafConfiguration[];
    set wafConfiguration(value: ApplicationGatewayWafConfiguration[]);
    resetWafConfiguration(): void;
    get wafConfigurationInput(): ApplicationGatewayWafConfiguration[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
