import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface AzurermProviderConfig {
    readonly auxiliaryTenantIds?: string[];
    /**
     * The password associated with the Client Certificate.
     *
     * For use when authenticating as a Service Principal using a Client Certificate
     */
    readonly clientCertificatePassword?: string;
    /**
     * The path to the Client Certificate associated with the Service Principal for use when authenticating as a Service Principal using a Client Certificate.
     */
    readonly clientCertificatePath?: string;
    /**
     * The Client ID which should be used.
     */
    readonly clientId?: string;
    /**
     * The Client Secret which should be used.
     *
     * For use When authenticating as a Service Principal using a Client Secret.
     */
    readonly clientSecret?: string;
    /**
     * This will disable the x-ms-correlation-request-id header.
     */
    readonly disableCorrelationRequestId?: boolean;
    /**
     * This will disable the Terraform Partner ID which is used if a custom `partner_id` isn't specified.
     */
    readonly disableTerraformPartnerId?: boolean;
    /**
     * The Cloud Environment which should be used.
     *
     * Possible values are public, usgovernment, german, and china. Defaults to public.
     */
    readonly environment?: string;
    /**
     * The Hostname which should be used for the Azure Metadata Service.
     */
    readonly metadataHost?: string;
    /**
     * Deprecated - replaced by `metadata_host`.
     */
    readonly metadataUrl?: string;
    /**
     * The path to a custom endpoint for Managed Service Identity - in most circumstances this should be detected automatically.
     */
    readonly msiEndpoint?: string;
    /**
     * A GUID/UUID that is registered with Microsoft to facilitate partner resource usage attribution.
     */
    readonly partnerId?: string;
    /**
     * This will cause the AzureRM Provider to skip verifying the credentials being used are valid.
     */
    readonly skipCredentialsValidation?: boolean;
    /**
     * Should the AzureRM Provider skip registering all of the Resource Providers that it supports, if they're not already registered?
     */
    readonly skipProviderRegistration?: boolean;
    /**
     * Should the AzureRM Provider use AzureAD to access the Storage Data Plane API's?
     */
    readonly storageUseAzuread?: boolean;
    /**
     * The Subscription ID which should be used.
     */
    readonly subscriptionId?: string;
    /**
     * The Tenant ID which should be used.
     */
    readonly tenantId?: string;
    /**
     * Allowed Managed Service Identity be used for Authentication.
     */
    readonly useMsi?: boolean;
    /**
     * Alias name.
     */
    readonly alias?: string;
    /**
     * features block.
     */
    readonly features: AzurermProviderFeatures[];
}
export interface AzurermProviderFeaturesKeyVault {
    readonly purgeSoftDeleteOnDestroy?: boolean;
    readonly recoverSoftDeletedKeyVaults?: boolean;
}
export interface AzurermProviderFeaturesNetwork {
    readonly relaxedLocking: boolean;
}
export interface AzurermProviderFeaturesTemplateDeployment {
    readonly deleteNestedItemsDuringDeletion: boolean;
}
export interface AzurermProviderFeaturesVirtualMachine {
    readonly deleteOsDiskOnDeletion?: boolean;
    readonly gracefulShutdown?: boolean;
}
export interface AzurermProviderFeaturesVirtualMachineScaleSet {
    readonly rollInstancesWhenRequired: boolean;
}
export interface AzurermProviderFeatures {
    /**
     * key_vault block.
     */
    readonly keyVault?: AzurermProviderFeaturesKeyVault[];
    /**
     * network block.
     */
    readonly network?: AzurermProviderFeaturesNetwork[];
    /**
     * template_deployment block.
     */
    readonly templateDeployment?: AzurermProviderFeaturesTemplateDeployment[];
    /**
     * virtual_machine block.
     */
    readonly virtualMachine?: AzurermProviderFeaturesVirtualMachine[];
    /**
     * virtual_machine_scale_set block.
     */
    readonly virtualMachineScaleSet?: AzurermProviderFeaturesVirtualMachineScaleSet[];
}
export declare class AzurermProvider extends cdktf.TerraformProvider {
    constructor(scope: Construct, id: string, config: AzurermProviderConfig);
    private _auxiliaryTenantIds?;
    get auxiliaryTenantIds(): string[] | undefined;
    set auxiliaryTenantIds(value: string[] | undefined);
    resetAuxiliaryTenantIds(): void;
    get auxiliaryTenantIdsInput(): string[] | undefined;
    private _clientCertificatePassword?;
    get clientCertificatePassword(): string | undefined;
    set clientCertificatePassword(value: string | undefined);
    resetClientCertificatePassword(): void;
    get clientCertificatePasswordInput(): string | undefined;
    private _clientCertificatePath?;
    get clientCertificatePath(): string | undefined;
    set clientCertificatePath(value: string | undefined);
    resetClientCertificatePath(): void;
    get clientCertificatePathInput(): string | undefined;
    private _clientId?;
    get clientId(): string | undefined;
    set clientId(value: string | undefined);
    resetClientId(): void;
    get clientIdInput(): string | undefined;
    private _clientSecret?;
    get clientSecret(): string | undefined;
    set clientSecret(value: string | undefined);
    resetClientSecret(): void;
    get clientSecretInput(): string | undefined;
    private _disableCorrelationRequestId?;
    get disableCorrelationRequestId(): boolean | undefined;
    set disableCorrelationRequestId(value: boolean | undefined);
    resetDisableCorrelationRequestId(): void;
    get disableCorrelationRequestIdInput(): boolean | undefined;
    private _disableTerraformPartnerId?;
    get disableTerraformPartnerId(): boolean | undefined;
    set disableTerraformPartnerId(value: boolean | undefined);
    resetDisableTerraformPartnerId(): void;
    get disableTerraformPartnerIdInput(): boolean | undefined;
    private _environment?;
    get environment(): string | undefined;
    set environment(value: string | undefined);
    resetEnvironment(): void;
    get environmentInput(): string | undefined;
    private _metadataHost?;
    get metadataHost(): string | undefined;
    set metadataHost(value: string | undefined);
    resetMetadataHost(): void;
    get metadataHostInput(): string | undefined;
    private _metadataUrl?;
    get metadataUrl(): string | undefined;
    set metadataUrl(value: string | undefined);
    resetMetadataUrl(): void;
    get metadataUrlInput(): string | undefined;
    private _msiEndpoint?;
    get msiEndpoint(): string | undefined;
    set msiEndpoint(value: string | undefined);
    resetMsiEndpoint(): void;
    get msiEndpointInput(): string | undefined;
    private _partnerId?;
    get partnerId(): string | undefined;
    set partnerId(value: string | undefined);
    resetPartnerId(): void;
    get partnerIdInput(): string | undefined;
    private _skipCredentialsValidation?;
    get skipCredentialsValidation(): boolean | undefined;
    set skipCredentialsValidation(value: boolean | undefined);
    resetSkipCredentialsValidation(): void;
    get skipCredentialsValidationInput(): boolean | undefined;
    private _skipProviderRegistration?;
    get skipProviderRegistration(): boolean | undefined;
    set skipProviderRegistration(value: boolean | undefined);
    resetSkipProviderRegistration(): void;
    get skipProviderRegistrationInput(): boolean | undefined;
    private _storageUseAzuread?;
    get storageUseAzuread(): boolean | undefined;
    set storageUseAzuread(value: boolean | undefined);
    resetStorageUseAzuread(): void;
    get storageUseAzureadInput(): boolean | undefined;
    private _subscriptionId?;
    get subscriptionId(): string | undefined;
    set subscriptionId(value: string | undefined);
    resetSubscriptionId(): void;
    get subscriptionIdInput(): string | undefined;
    private _tenantId?;
    get tenantId(): string | undefined;
    set tenantId(value: string | undefined);
    resetTenantId(): void;
    get tenantIdInput(): string | undefined;
    private _useMsi?;
    get useMsi(): boolean | undefined;
    set useMsi(value: boolean | undefined);
    resetUseMsi(): void;
    get useMsiInput(): boolean | undefined;
    private _alias?;
    get alias(): string | undefined;
    set alias(value: string | undefined);
    resetAlias(): void;
    get aliasInput(): string | undefined;
    private _features;
    get features(): AzurermProviderFeatures[];
    set features(value: AzurermProviderFeatures[]);
    get featuresInput(): AzurermProviderFeatures[];
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
