import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface BatchPoolConfig extends cdktf.TerraformMetaArguments {
    readonly accountName: string;
    readonly displayName?: string;
    readonly maxTasksPerNode?: number;
    readonly metadata?: {
        [key: string]: string;
    };
    readonly name: string;
    readonly nodeAgentSkuId: string;
    readonly resourceGroupName: string;
    readonly stopPendingResizeOperation?: boolean;
    readonly vmSize: string;
    /**
     * auto_scale block.
     */
    readonly autoScale?: BatchPoolAutoScale[];
    /**
     * certificate block.
     */
    readonly certificate?: BatchPoolCertificate[];
    /**
     * container_configuration block.
     */
    readonly containerConfiguration?: BatchPoolContainerConfiguration[];
    /**
     * fixed_scale block.
     */
    readonly fixedScale?: BatchPoolFixedScale[];
    /**
     * network_configuration block.
     */
    readonly networkConfiguration?: BatchPoolNetworkConfiguration[];
    /**
     * start_task block.
     */
    readonly startTask?: BatchPoolStartTask[];
    /**
     * storage_image_reference block.
     */
    readonly storageImageReference: BatchPoolStorageImageReference[];
    /**
     * timeouts block.
     */
    readonly timeouts?: BatchPoolTimeouts;
}
export interface BatchPoolAutoScale {
    readonly evaluationInterval?: string;
    readonly formula: string;
}
export interface BatchPoolCertificate {
    readonly id: string;
    readonly storeLocation: string;
    readonly storeName?: string;
    readonly visibility?: string[];
}
export interface BatchPoolContainerConfigurationContainerRegistries {
    readonly password?: string;
    readonly registryServer?: string;
    readonly userName?: string;
}
export interface BatchPoolContainerConfiguration {
    readonly containerImageNames?: string[];
    readonly containerRegistries?: BatchPoolContainerConfigurationContainerRegistries[];
    readonly type?: string;
}
export interface BatchPoolFixedScale {
    readonly resizeTimeout?: string;
    readonly targetDedicatedNodes?: number;
    readonly targetLowPriorityNodes?: number;
}
export interface BatchPoolNetworkConfigurationEndpointConfigurationNetworkSecurityGroupRules {
    readonly access: string;
    readonly priority: number;
    readonly sourceAddressPrefix: string;
}
export interface BatchPoolNetworkConfigurationEndpointConfiguration {
    readonly backendPort: number;
    readonly frontendPortRange: string;
    readonly name: string;
    readonly protocol: string;
    /**
     * network_security_group_rules block.
     */
    readonly networkSecurityGroupRules?: BatchPoolNetworkConfigurationEndpointConfigurationNetworkSecurityGroupRules[];
}
export interface BatchPoolNetworkConfiguration {
    readonly publicIps?: string[];
    readonly subnetId: string;
    /**
     * endpoint_configuration block.
     */
    readonly endpointConfiguration?: BatchPoolNetworkConfigurationEndpointConfiguration[];
}
export interface BatchPoolStartTaskResourceFile {
    readonly autoStorageContainerName?: string;
    readonly blobPrefix?: string;
    readonly fileMode?: string;
    readonly filePath?: string;
    readonly httpUrl?: string;
    readonly storageContainerUrl?: string;
}
export interface BatchPoolStartTaskUserIdentityAutoUser {
    readonly elevationLevel?: string;
    readonly scope?: string;
}
export interface BatchPoolStartTaskUserIdentity {
    readonly userName?: string;
    /**
     * auto_user block.
     */
    readonly autoUser?: BatchPoolStartTaskUserIdentityAutoUser[];
}
export interface BatchPoolStartTask {
    readonly commandLine: string;
    readonly environment?: {
        [key: string]: string;
    };
    readonly maxTaskRetryCount?: number;
    readonly waitForSuccess?: boolean;
    /**
     * resource_file block.
     */
    readonly resourceFile?: BatchPoolStartTaskResourceFile[];
    /**
     * user_identity block.
     */
    readonly userIdentity: BatchPoolStartTaskUserIdentity[];
}
export interface BatchPoolStorageImageReference {
    readonly id?: string;
    readonly offer?: string;
    readonly publisher?: string;
    readonly sku?: string;
    readonly version?: string;
}
export interface BatchPoolTimeouts {
    readonly create?: string;
    readonly delete?: string;
    readonly read?: string;
    readonly update?: string;
}
export declare class BatchPool extends cdktf.TerraformResource {
    constructor(scope: Construct, id: string, config: BatchPoolConfig);
    private _accountName;
    get accountName(): string;
    set accountName(value: string);
    get accountNameInput(): string;
    private _displayName?;
    get displayName(): string;
    set displayName(value: string);
    resetDisplayName(): void;
    get displayNameInput(): string | undefined;
    get id(): string;
    private _maxTasksPerNode?;
    get maxTasksPerNode(): number;
    set maxTasksPerNode(value: number);
    resetMaxTasksPerNode(): void;
    get maxTasksPerNodeInput(): number | undefined;
    private _metadata?;
    get metadata(): {
        [key: string]: string;
    };
    set metadata(value: {
        [key: string]: string;
    });
    resetMetadata(): void;
    get metadataInput(): {
        [key: string]: string;
    } | undefined;
    private _name;
    get name(): string;
    set name(value: string);
    get nameInput(): string;
    private _nodeAgentSkuId;
    get nodeAgentSkuId(): string;
    set nodeAgentSkuId(value: string);
    get nodeAgentSkuIdInput(): string;
    private _resourceGroupName;
    get resourceGroupName(): string;
    set resourceGroupName(value: string);
    get resourceGroupNameInput(): string;
    private _stopPendingResizeOperation?;
    get stopPendingResizeOperation(): boolean;
    set stopPendingResizeOperation(value: boolean);
    resetStopPendingResizeOperation(): void;
    get stopPendingResizeOperationInput(): boolean | undefined;
    private _vmSize;
    get vmSize(): string;
    set vmSize(value: string);
    get vmSizeInput(): string;
    private _autoScale?;
    get autoScale(): BatchPoolAutoScale[];
    set autoScale(value: BatchPoolAutoScale[]);
    resetAutoScale(): void;
    get autoScaleInput(): BatchPoolAutoScale[] | undefined;
    private _certificate?;
    get certificate(): BatchPoolCertificate[];
    set certificate(value: BatchPoolCertificate[]);
    resetCertificate(): void;
    get certificateInput(): BatchPoolCertificate[] | undefined;
    private _containerConfiguration?;
    get containerConfiguration(): BatchPoolContainerConfiguration[];
    set containerConfiguration(value: BatchPoolContainerConfiguration[]);
    resetContainerConfiguration(): void;
    get containerConfigurationInput(): BatchPoolContainerConfiguration[] | undefined;
    private _fixedScale?;
    get fixedScale(): BatchPoolFixedScale[];
    set fixedScale(value: BatchPoolFixedScale[]);
    resetFixedScale(): void;
    get fixedScaleInput(): BatchPoolFixedScale[] | undefined;
    private _networkConfiguration?;
    get networkConfiguration(): BatchPoolNetworkConfiguration[];
    set networkConfiguration(value: BatchPoolNetworkConfiguration[]);
    resetNetworkConfiguration(): void;
    get networkConfigurationInput(): BatchPoolNetworkConfiguration[] | undefined;
    private _startTask?;
    get startTask(): BatchPoolStartTask[];
    set startTask(value: BatchPoolStartTask[]);
    resetStartTask(): void;
    get startTaskInput(): BatchPoolStartTask[] | undefined;
    private _storageImageReference;
    get storageImageReference(): BatchPoolStorageImageReference[];
    set storageImageReference(value: BatchPoolStorageImageReference[]);
    get storageImageReferenceInput(): BatchPoolStorageImageReference[];
    private _timeouts?;
    get timeouts(): BatchPoolTimeouts;
    set timeouts(value: BatchPoolTimeouts);
    resetTimeouts(): void;
    get timeoutsInput(): BatchPoolTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
