import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface ContainerGroupConfig extends cdktf.TerraformMetaArguments {
    readonly dnsNameLabel?: string;
    readonly ipAddressType?: string;
    readonly location: string;
    readonly name: string;
    readonly networkProfileId?: string;
    readonly osType: string;
    readonly resourceGroupName: string;
    readonly restartPolicy?: string;
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * container block.
     */
    readonly container: ContainerGroupContainer[];
    /**
     * diagnostics block.
     */
    readonly diagnostics?: ContainerGroupDiagnostics[];
    /**
     * dns_config block.
     */
    readonly dnsConfig?: ContainerGroupDnsConfig[];
    /**
     * identity block.
     */
    readonly identity?: ContainerGroupIdentity[];
    /**
     * image_registry_credential block.
     */
    readonly imageRegistryCredential?: ContainerGroupImageRegistryCredential[];
    /**
     * timeouts block.
     */
    readonly timeouts?: ContainerGroupTimeouts;
}
export interface ContainerGroupContainerGpu {
    readonly count?: number;
    readonly sku?: string;
}
export interface ContainerGroupContainerLivenessProbeHttpGet {
    readonly path?: string;
    readonly port?: number;
    readonly scheme?: string;
}
export interface ContainerGroupContainerLivenessProbe {
    readonly exec?: string[];
    readonly failureThreshold?: number;
    readonly initialDelaySeconds?: number;
    readonly periodSeconds?: number;
    readonly successThreshold?: number;
    readonly timeoutSeconds?: number;
    /**
     * http_get block.
     */
    readonly httpGet?: ContainerGroupContainerLivenessProbeHttpGet[];
}
export interface ContainerGroupContainerPorts {
    readonly port?: number;
    readonly protocol?: string;
}
export interface ContainerGroupContainerReadinessProbeHttpGet {
    readonly path?: string;
    readonly port?: number;
    readonly scheme?: string;
}
export interface ContainerGroupContainerReadinessProbe {
    readonly exec?: string[];
    readonly failureThreshold?: number;
    readonly initialDelaySeconds?: number;
    readonly periodSeconds?: number;
    readonly successThreshold?: number;
    readonly timeoutSeconds?: number;
    /**
     * http_get block.
     */
    readonly httpGet?: ContainerGroupContainerReadinessProbeHttpGet[];
}
export interface ContainerGroupContainerVolumeGitRepo {
    readonly directory?: string;
    readonly revision?: string;
    readonly url: string;
}
export interface ContainerGroupContainerVolume {
    readonly mountPath: string;
    readonly name: string;
    readonly readOnly?: boolean;
    readonly secret?: {
        [key: string]: string;
    };
    readonly shareName?: string;
    readonly storageAccountKey?: string;
    readonly storageAccountName?: string;
    /**
     * git_repo block.
     */
    readonly gitRepo?: ContainerGroupContainerVolumeGitRepo[];
}
export interface ContainerGroupContainer {
    readonly commands?: string[];
    readonly cpu: number;
    readonly environmentVariables?: {
        [key: string]: string;
    };
    readonly image: string;
    readonly memory: number;
    readonly name: string;
    readonly secureEnvironmentVariables?: {
        [key: string]: string;
    };
    /**
     * gpu block.
     */
    readonly gpu?: ContainerGroupContainerGpu[];
    /**
     * liveness_probe block.
     */
    readonly livenessProbe?: ContainerGroupContainerLivenessProbe[];
    /**
     * ports block.
     */
    readonly ports?: ContainerGroupContainerPorts[];
    /**
     * readiness_probe block.
     */
    readonly readinessProbe?: ContainerGroupContainerReadinessProbe[];
    /**
     * volume block.
     */
    readonly volume?: ContainerGroupContainerVolume[];
}
export interface ContainerGroupDiagnosticsLogAnalytics {
    readonly logType?: string;
    readonly metadata?: {
        [key: string]: string;
    };
    readonly workspaceId: string;
    readonly workspaceKey: string;
}
export interface ContainerGroupDiagnostics {
    /**
     * log_analytics block.
     */
    readonly logAnalytics: ContainerGroupDiagnosticsLogAnalytics[];
}
export interface ContainerGroupDnsConfig {
    readonly nameservers: string[];
    readonly options: string[];
    readonly searchDomains: string[];
}
export interface ContainerGroupIdentity {
    readonly identityIds?: string[];
    readonly type: string;
}
export interface ContainerGroupImageRegistryCredential {
    readonly password: string;
    readonly server: string;
    readonly username: string;
}
export interface ContainerGroupTimeouts {
    readonly create?: string;
    readonly delete?: string;
    readonly read?: string;
    readonly update?: string;
}
export declare class ContainerGroup extends cdktf.TerraformResource {
    constructor(scope: Construct, id: string, config: ContainerGroupConfig);
    private _dnsNameLabel?;
    get dnsNameLabel(): string;
    set dnsNameLabel(value: string);
    resetDnsNameLabel(): void;
    get dnsNameLabelInput(): string | undefined;
    get fqdn(): string;
    get id(): string;
    get ipAddress(): string;
    private _ipAddressType?;
    get ipAddressType(): string;
    set ipAddressType(value: string);
    resetIpAddressType(): void;
    get ipAddressTypeInput(): string | undefined;
    private _location;
    get location(): string;
    set location(value: string);
    get locationInput(): string;
    private _name;
    get name(): string;
    set name(value: string);
    get nameInput(): string;
    private _networkProfileId?;
    get networkProfileId(): string;
    set networkProfileId(value: string);
    resetNetworkProfileId(): void;
    get networkProfileIdInput(): string | undefined;
    private _osType;
    get osType(): string;
    set osType(value: string);
    get osTypeInput(): string;
    private _resourceGroupName;
    get resourceGroupName(): string;
    set resourceGroupName(value: string);
    get resourceGroupNameInput(): string;
    private _restartPolicy?;
    get restartPolicy(): string;
    set restartPolicy(value: string);
    resetRestartPolicy(): void;
    get restartPolicyInput(): string | undefined;
    private _tags?;
    get tags(): {
        [key: string]: string;
    };
    set tags(value: {
        [key: string]: string;
    });
    resetTags(): void;
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _container;
    get container(): ContainerGroupContainer[];
    set container(value: ContainerGroupContainer[]);
    get containerInput(): ContainerGroupContainer[];
    private _diagnostics?;
    get diagnostics(): ContainerGroupDiagnostics[];
    set diagnostics(value: ContainerGroupDiagnostics[]);
    resetDiagnostics(): void;
    get diagnosticsInput(): ContainerGroupDiagnostics[] | undefined;
    private _dnsConfig?;
    get dnsConfig(): ContainerGroupDnsConfig[];
    set dnsConfig(value: ContainerGroupDnsConfig[]);
    resetDnsConfig(): void;
    get dnsConfigInput(): ContainerGroupDnsConfig[] | undefined;
    private _identity?;
    get identity(): ContainerGroupIdentity[];
    set identity(value: ContainerGroupIdentity[]);
    resetIdentity(): void;
    get identityInput(): ContainerGroupIdentity[] | undefined;
    private _imageRegistryCredential?;
    get imageRegistryCredential(): ContainerGroupImageRegistryCredential[];
    set imageRegistryCredential(value: ContainerGroupImageRegistryCredential[]);
    resetImageRegistryCredential(): void;
    get imageRegistryCredentialInput(): ContainerGroupImageRegistryCredential[] | undefined;
    private _timeouts?;
    get timeouts(): ContainerGroupTimeouts;
    set timeouts(value: ContainerGroupTimeouts);
    resetTimeouts(): void;
    get timeoutsInput(): ContainerGroupTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
