import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface CosmosdbAccountConfig extends cdktf.TerraformMetaArguments {
    readonly enableAutomaticFailover?: boolean;
    readonly enableFreeTier?: boolean;
    readonly enableMultipleWriteLocations?: boolean;
    readonly ipRangeFilter?: string;
    readonly isVirtualNetworkFilterEnabled?: boolean;
    readonly keyVaultKeyId?: string;
    readonly kind?: string;
    readonly location: string;
    readonly name: string;
    readonly offerType: string;
    readonly publicNetworkAccessEnabled?: boolean;
    readonly resourceGroupName: string;
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * capabilities block.
     */
    readonly capabilities?: CosmosdbAccountCapabilities[];
    /**
     * consistency_policy block.
     */
    readonly consistencyPolicy: CosmosdbAccountConsistencyPolicy[];
    /**
     * geo_location block.
     */
    readonly geoLocation: CosmosdbAccountGeoLocation[];
    /**
     * timeouts block.
     */
    readonly timeouts?: CosmosdbAccountTimeouts;
    /**
     * virtual_network_rule block.
     */
    readonly virtualNetworkRule?: CosmosdbAccountVirtualNetworkRule[];
}
export interface CosmosdbAccountCapabilities {
    readonly name: string;
}
export interface CosmosdbAccountConsistencyPolicy {
    readonly consistencyLevel: string;
    readonly maxIntervalInSeconds?: number;
    readonly maxStalenessPrefix?: number;
}
export interface CosmosdbAccountGeoLocation {
    readonly failoverPriority: number;
    readonly location: string;
    readonly prefix?: string;
    readonly zoneRedundant?: boolean;
}
export interface CosmosdbAccountTimeouts {
    readonly create?: string;
    readonly delete?: string;
    readonly read?: string;
    readonly update?: string;
}
export interface CosmosdbAccountVirtualNetworkRule {
    readonly id: string;
    readonly ignoreMissingVnetServiceEndpoint?: boolean;
}
export declare class CosmosdbAccount extends cdktf.TerraformResource {
    constructor(scope: Construct, id: string, config: CosmosdbAccountConfig);
    get connectionStrings(): string[];
    private _enableAutomaticFailover?;
    get enableAutomaticFailover(): boolean;
    set enableAutomaticFailover(value: boolean);
    resetEnableAutomaticFailover(): void;
    get enableAutomaticFailoverInput(): boolean | undefined;
    private _enableFreeTier?;
    get enableFreeTier(): boolean;
    set enableFreeTier(value: boolean);
    resetEnableFreeTier(): void;
    get enableFreeTierInput(): boolean | undefined;
    private _enableMultipleWriteLocations?;
    get enableMultipleWriteLocations(): boolean;
    set enableMultipleWriteLocations(value: boolean);
    resetEnableMultipleWriteLocations(): void;
    get enableMultipleWriteLocationsInput(): boolean | undefined;
    get endpoint(): string;
    get id(): string;
    private _ipRangeFilter?;
    get ipRangeFilter(): string;
    set ipRangeFilter(value: string);
    resetIpRangeFilter(): void;
    get ipRangeFilterInput(): string | undefined;
    private _isVirtualNetworkFilterEnabled?;
    get isVirtualNetworkFilterEnabled(): boolean;
    set isVirtualNetworkFilterEnabled(value: boolean);
    resetIsVirtualNetworkFilterEnabled(): void;
    get isVirtualNetworkFilterEnabledInput(): boolean | undefined;
    private _keyVaultKeyId?;
    get keyVaultKeyId(): string;
    set keyVaultKeyId(value: string);
    resetKeyVaultKeyId(): void;
    get keyVaultKeyIdInput(): string | undefined;
    private _kind?;
    get kind(): string;
    set kind(value: string);
    resetKind(): void;
    get kindInput(): string | undefined;
    private _location;
    get location(): string;
    set location(value: string);
    get locationInput(): string;
    private _name;
    get name(): string;
    set name(value: string);
    get nameInput(): string;
    private _offerType;
    get offerType(): string;
    set offerType(value: string);
    get offerTypeInput(): string;
    get primaryKey(): string;
    get primaryMasterKey(): string;
    get primaryReadonlyKey(): string;
    get primaryReadonlyMasterKey(): string;
    private _publicNetworkAccessEnabled?;
    get publicNetworkAccessEnabled(): boolean;
    set publicNetworkAccessEnabled(value: boolean);
    resetPublicNetworkAccessEnabled(): void;
    get publicNetworkAccessEnabledInput(): boolean | undefined;
    get readEndpoints(): string[];
    private _resourceGroupName;
    get resourceGroupName(): string;
    set resourceGroupName(value: string);
    get resourceGroupNameInput(): string;
    get secondaryKey(): string;
    get secondaryMasterKey(): string;
    get secondaryReadonlyKey(): string;
    get secondaryReadonlyMasterKey(): string;
    private _tags?;
    get tags(): {
        [key: string]: string;
    };
    set tags(value: {
        [key: string]: string;
    });
    resetTags(): void;
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    get writeEndpoints(): string[];
    private _capabilities?;
    get capabilities(): CosmosdbAccountCapabilities[];
    set capabilities(value: CosmosdbAccountCapabilities[]);
    resetCapabilities(): void;
    get capabilitiesInput(): CosmosdbAccountCapabilities[] | undefined;
    private _consistencyPolicy;
    get consistencyPolicy(): CosmosdbAccountConsistencyPolicy[];
    set consistencyPolicy(value: CosmosdbAccountConsistencyPolicy[]);
    get consistencyPolicyInput(): CosmosdbAccountConsistencyPolicy[];
    private _geoLocation;
    get geoLocation(): CosmosdbAccountGeoLocation[];
    set geoLocation(value: CosmosdbAccountGeoLocation[]);
    get geoLocationInput(): CosmosdbAccountGeoLocation[];
    private _timeouts?;
    get timeouts(): CosmosdbAccountTimeouts;
    set timeouts(value: CosmosdbAccountTimeouts);
    resetTimeouts(): void;
    get timeoutsInput(): CosmosdbAccountTimeouts | undefined;
    private _virtualNetworkRule?;
    get virtualNetworkRule(): CosmosdbAccountVirtualNetworkRule[];
    set virtualNetworkRule(value: CosmosdbAccountVirtualNetworkRule[]);
    resetVirtualNetworkRule(): void;
    get virtualNetworkRuleInput(): CosmosdbAccountVirtualNetworkRule[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
