import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface EventgridEventSubscriptionConfig extends cdktf.TerraformMetaArguments {
    readonly eventDeliverySchema?: string;
    readonly eventhubEndpointId?: string;
    readonly expirationTimeUtc?: string;
    readonly hybridConnectionEndpointId?: string;
    readonly includedEventTypes?: string[];
    readonly labels?: string[];
    readonly name: string;
    readonly scope: string;
    readonly serviceBusQueueEndpointId?: string;
    readonly serviceBusTopicEndpointId?: string;
    readonly topicName?: string;
    /**
     * advanced_filter block.
     */
    readonly advancedFilter?: EventgridEventSubscriptionAdvancedFilter[];
    /**
     * azure_function_endpoint block.
     */
    readonly azureFunctionEndpoint?: EventgridEventSubscriptionAzureFunctionEndpoint[];
    /**
     * eventhub_endpoint block.
     */
    readonly eventhubEndpoint?: EventgridEventSubscriptionEventhubEndpoint[];
    /**
     * hybrid_connection_endpoint block.
     */
    readonly hybridConnectionEndpoint?: EventgridEventSubscriptionHybridConnectionEndpoint[];
    /**
     * retry_policy block.
     */
    readonly retryPolicy?: EventgridEventSubscriptionRetryPolicy[];
    /**
     * storage_blob_dead_letter_destination block.
     */
    readonly storageBlobDeadLetterDestination?: EventgridEventSubscriptionStorageBlobDeadLetterDestination[];
    /**
     * storage_queue_endpoint block.
     */
    readonly storageQueueEndpoint?: EventgridEventSubscriptionStorageQueueEndpoint[];
    /**
     * subject_filter block.
     */
    readonly subjectFilter?: EventgridEventSubscriptionSubjectFilter[];
    /**
     * timeouts block.
     */
    readonly timeouts?: EventgridEventSubscriptionTimeouts;
    /**
     * webhook_endpoint block.
     */
    readonly webhookEndpoint?: EventgridEventSubscriptionWebhookEndpoint[];
}
export interface EventgridEventSubscriptionAdvancedFilterBoolEquals {
    readonly key: string;
    readonly value: boolean;
}
export interface EventgridEventSubscriptionAdvancedFilterNumberGreaterThan {
    readonly key: string;
    readonly value: number;
}
export interface EventgridEventSubscriptionAdvancedFilterNumberGreaterThanOrEquals {
    readonly key: string;
    readonly value: number;
}
export interface EventgridEventSubscriptionAdvancedFilterNumberIn {
    readonly key: string;
    readonly values: number[];
}
export interface EventgridEventSubscriptionAdvancedFilterNumberLessThan {
    readonly key: string;
    readonly value: number;
}
export interface EventgridEventSubscriptionAdvancedFilterNumberLessThanOrEquals {
    readonly key: string;
    readonly value: number;
}
export interface EventgridEventSubscriptionAdvancedFilterNumberNotIn {
    readonly key: string;
    readonly values: number[];
}
export interface EventgridEventSubscriptionAdvancedFilterStringBeginsWith {
    readonly key: string;
    readonly values: string[];
}
export interface EventgridEventSubscriptionAdvancedFilterStringContains {
    readonly key: string;
    readonly values: string[];
}
export interface EventgridEventSubscriptionAdvancedFilterStringEndsWith {
    readonly key: string;
    readonly values: string[];
}
export interface EventgridEventSubscriptionAdvancedFilterStringIn {
    readonly key: string;
    readonly values: string[];
}
export interface EventgridEventSubscriptionAdvancedFilterStringNotIn {
    readonly key: string;
    readonly values: string[];
}
export interface EventgridEventSubscriptionAdvancedFilter {
    /**
     * bool_equals block.
     */
    readonly boolEquals?: EventgridEventSubscriptionAdvancedFilterBoolEquals[];
    /**
     * number_greater_than block.
     */
    readonly numberGreaterThan?: EventgridEventSubscriptionAdvancedFilterNumberGreaterThan[];
    /**
     * number_greater_than_or_equals block.
     */
    readonly numberGreaterThanOrEquals?: EventgridEventSubscriptionAdvancedFilterNumberGreaterThanOrEquals[];
    /**
     * number_in block.
     */
    readonly numberIn?: EventgridEventSubscriptionAdvancedFilterNumberIn[];
    /**
     * number_less_than block.
     */
    readonly numberLessThan?: EventgridEventSubscriptionAdvancedFilterNumberLessThan[];
    /**
     * number_less_than_or_equals block.
     */
    readonly numberLessThanOrEquals?: EventgridEventSubscriptionAdvancedFilterNumberLessThanOrEquals[];
    /**
     * number_not_in block.
     */
    readonly numberNotIn?: EventgridEventSubscriptionAdvancedFilterNumberNotIn[];
    /**
     * string_begins_with block.
     */
    readonly stringBeginsWith?: EventgridEventSubscriptionAdvancedFilterStringBeginsWith[];
    /**
     * string_contains block.
     */
    readonly stringContains?: EventgridEventSubscriptionAdvancedFilterStringContains[];
    /**
     * string_ends_with block.
     */
    readonly stringEndsWith?: EventgridEventSubscriptionAdvancedFilterStringEndsWith[];
    /**
     * string_in block.
     */
    readonly stringIn?: EventgridEventSubscriptionAdvancedFilterStringIn[];
    /**
     * string_not_in block.
     */
    readonly stringNotIn?: EventgridEventSubscriptionAdvancedFilterStringNotIn[];
}
export interface EventgridEventSubscriptionAzureFunctionEndpoint {
    readonly functionId: string;
    readonly maxEventsPerBatch?: number;
    readonly preferredBatchSizeInKilobytes?: number;
}
export interface EventgridEventSubscriptionEventhubEndpoint {
    readonly eventhubId?: string;
}
export interface EventgridEventSubscriptionHybridConnectionEndpoint {
    readonly hybridConnectionId?: string;
}
export interface EventgridEventSubscriptionRetryPolicy {
    readonly eventTimeToLive: number;
    readonly maxDeliveryAttempts: number;
}
export interface EventgridEventSubscriptionStorageBlobDeadLetterDestination {
    readonly storageAccountId: string;
    readonly storageBlobContainerName: string;
}
export interface EventgridEventSubscriptionStorageQueueEndpoint {
    readonly queueName: string;
    readonly storageAccountId: string;
}
export interface EventgridEventSubscriptionSubjectFilter {
    readonly caseSensitive?: boolean;
    readonly subjectBeginsWith?: string;
    readonly subjectEndsWith?: string;
}
export interface EventgridEventSubscriptionTimeouts {
    readonly create?: string;
    readonly delete?: string;
    readonly read?: string;
    readonly update?: string;
}
export interface EventgridEventSubscriptionWebhookEndpoint {
    readonly activeDirectoryAppIdOrUri?: string;
    readonly activeDirectoryTenantId?: string;
    readonly maxEventsPerBatch?: number;
    readonly preferredBatchSizeInKilobytes?: number;
    readonly url: string;
}
export declare class EventgridEventSubscription extends cdktf.TerraformResource {
    constructor(scope: Construct, id: string, config: EventgridEventSubscriptionConfig);
    private _eventDeliverySchema?;
    get eventDeliverySchema(): string;
    set eventDeliverySchema(value: string);
    resetEventDeliverySchema(): void;
    get eventDeliverySchemaInput(): string | undefined;
    private _eventhubEndpointId?;
    get eventhubEndpointId(): string;
    set eventhubEndpointId(value: string);
    resetEventhubEndpointId(): void;
    get eventhubEndpointIdInput(): string | undefined;
    private _expirationTimeUtc?;
    get expirationTimeUtc(): string;
    set expirationTimeUtc(value: string);
    resetExpirationTimeUtc(): void;
    get expirationTimeUtcInput(): string | undefined;
    private _hybridConnectionEndpointId?;
    get hybridConnectionEndpointId(): string;
    set hybridConnectionEndpointId(value: string);
    resetHybridConnectionEndpointId(): void;
    get hybridConnectionEndpointIdInput(): string | undefined;
    get id(): string;
    private _includedEventTypes?;
    get includedEventTypes(): string[];
    set includedEventTypes(value: string[]);
    resetIncludedEventTypes(): void;
    get includedEventTypesInput(): string[] | undefined;
    private _labels?;
    get labels(): string[];
    set labels(value: string[]);
    resetLabels(): void;
    get labelsInput(): string[] | undefined;
    private _name;
    get name(): string;
    set name(value: string);
    get nameInput(): string;
    private _scope;
    get scope(): string;
    set scope(value: string);
    get scopeInput(): string;
    private _serviceBusQueueEndpointId?;
    get serviceBusQueueEndpointId(): string;
    set serviceBusQueueEndpointId(value: string);
    resetServiceBusQueueEndpointId(): void;
    get serviceBusQueueEndpointIdInput(): string | undefined;
    private _serviceBusTopicEndpointId?;
    get serviceBusTopicEndpointId(): string;
    set serviceBusTopicEndpointId(value: string);
    resetServiceBusTopicEndpointId(): void;
    get serviceBusTopicEndpointIdInput(): string | undefined;
    private _topicName?;
    get topicName(): string;
    set topicName(value: string);
    resetTopicName(): void;
    get topicNameInput(): string | undefined;
    private _advancedFilter?;
    get advancedFilter(): EventgridEventSubscriptionAdvancedFilter[];
    set advancedFilter(value: EventgridEventSubscriptionAdvancedFilter[]);
    resetAdvancedFilter(): void;
    get advancedFilterInput(): EventgridEventSubscriptionAdvancedFilter[] | undefined;
    private _azureFunctionEndpoint?;
    get azureFunctionEndpoint(): EventgridEventSubscriptionAzureFunctionEndpoint[];
    set azureFunctionEndpoint(value: EventgridEventSubscriptionAzureFunctionEndpoint[]);
    resetAzureFunctionEndpoint(): void;
    get azureFunctionEndpointInput(): EventgridEventSubscriptionAzureFunctionEndpoint[] | undefined;
    private _eventhubEndpoint?;
    get eventhubEndpoint(): EventgridEventSubscriptionEventhubEndpoint[];
    set eventhubEndpoint(value: EventgridEventSubscriptionEventhubEndpoint[]);
    resetEventhubEndpoint(): void;
    get eventhubEndpointInput(): EventgridEventSubscriptionEventhubEndpoint[] | undefined;
    private _hybridConnectionEndpoint?;
    get hybridConnectionEndpoint(): EventgridEventSubscriptionHybridConnectionEndpoint[];
    set hybridConnectionEndpoint(value: EventgridEventSubscriptionHybridConnectionEndpoint[]);
    resetHybridConnectionEndpoint(): void;
    get hybridConnectionEndpointInput(): EventgridEventSubscriptionHybridConnectionEndpoint[] | undefined;
    private _retryPolicy?;
    get retryPolicy(): EventgridEventSubscriptionRetryPolicy[];
    set retryPolicy(value: EventgridEventSubscriptionRetryPolicy[]);
    resetRetryPolicy(): void;
    get retryPolicyInput(): EventgridEventSubscriptionRetryPolicy[] | undefined;
    private _storageBlobDeadLetterDestination?;
    get storageBlobDeadLetterDestination(): EventgridEventSubscriptionStorageBlobDeadLetterDestination[];
    set storageBlobDeadLetterDestination(value: EventgridEventSubscriptionStorageBlobDeadLetterDestination[]);
    resetStorageBlobDeadLetterDestination(): void;
    get storageBlobDeadLetterDestinationInput(): EventgridEventSubscriptionStorageBlobDeadLetterDestination[] | undefined;
    private _storageQueueEndpoint?;
    get storageQueueEndpoint(): EventgridEventSubscriptionStorageQueueEndpoint[];
    set storageQueueEndpoint(value: EventgridEventSubscriptionStorageQueueEndpoint[]);
    resetStorageQueueEndpoint(): void;
    get storageQueueEndpointInput(): EventgridEventSubscriptionStorageQueueEndpoint[] | undefined;
    private _subjectFilter?;
    get subjectFilter(): EventgridEventSubscriptionSubjectFilter[];
    set subjectFilter(value: EventgridEventSubscriptionSubjectFilter[]);
    resetSubjectFilter(): void;
    get subjectFilterInput(): EventgridEventSubscriptionSubjectFilter[] | undefined;
    private _timeouts?;
    get timeouts(): EventgridEventSubscriptionTimeouts;
    set timeouts(value: EventgridEventSubscriptionTimeouts);
    resetTimeouts(): void;
    get timeoutsInput(): EventgridEventSubscriptionTimeouts | undefined;
    private _webhookEndpoint?;
    get webhookEndpoint(): EventgridEventSubscriptionWebhookEndpoint[];
    set webhookEndpoint(value: EventgridEventSubscriptionWebhookEndpoint[]);
    resetWebhookEndpoint(): void;
    get webhookEndpointInput(): EventgridEventSubscriptionWebhookEndpoint[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
