import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface FrontdoorConfig extends cdktf.TerraformMetaArguments {
    readonly backendPoolsSendReceiveTimeoutSeconds?: number;
    readonly enforceBackendPoolsCertificateNameCheck: boolean;
    readonly friendlyName?: string;
    readonly loadBalancerEnabled?: boolean;
    readonly location?: string;
    readonly name: string;
    readonly resourceGroupName: string;
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * backend_pool block.
     */
    readonly backendPool: FrontdoorBackendPool[];
    /**
     * backend_pool_health_probe block.
     */
    readonly backendPoolHealthProbe: FrontdoorBackendPoolHealthProbe[];
    /**
     * backend_pool_load_balancing block.
     */
    readonly backendPoolLoadBalancing: FrontdoorBackendPoolLoadBalancing[];
    /**
     * frontend_endpoint block.
     */
    readonly frontendEndpoint: FrontdoorFrontendEndpoint[];
    /**
     * routing_rule block.
     */
    readonly routingRule: FrontdoorRoutingRule[];
    /**
     * timeouts block.
     */
    readonly timeouts?: FrontdoorTimeouts;
}
export interface FrontdoorBackendPoolBackend {
    readonly address: string;
    readonly enabled?: boolean;
    readonly hostHeader: string;
    readonly httpPort: number;
    readonly httpsPort: number;
    readonly priority?: number;
    readonly weight?: number;
}
export interface FrontdoorBackendPool {
    readonly healthProbeName: string;
    readonly loadBalancingName: string;
    readonly name: string;
    /**
     * backend block.
     */
    readonly backend: FrontdoorBackendPoolBackend[];
}
export interface FrontdoorBackendPoolHealthProbe {
    readonly enabled?: boolean;
    readonly intervalInSeconds?: number;
    readonly name: string;
    readonly path?: string;
    readonly probeMethod?: string;
    readonly protocol?: string;
}
export interface FrontdoorBackendPoolLoadBalancing {
    readonly additionalLatencyMilliseconds?: number;
    readonly name: string;
    readonly sampleSize?: number;
    readonly successfulSamplesRequired?: number;
}
export interface FrontdoorFrontendEndpointCustomHttpsConfiguration {
    readonly azureKeyVaultCertificateSecretName?: string;
    readonly azureKeyVaultCertificateSecretVersion?: string;
    readonly azureKeyVaultCertificateVaultId?: string;
    readonly certificateSource?: string;
}
export interface FrontdoorFrontendEndpoint {
    readonly customHttpsProvisioningEnabled?: boolean;
    readonly hostName: string;
    readonly name: string;
    readonly sessionAffinityEnabled?: boolean;
    readonly sessionAffinityTtlSeconds?: number;
    readonly webApplicationFirewallPolicyLinkId?: string;
    /**
     * custom_https_configuration block.
     */
    readonly customHttpsConfiguration?: FrontdoorFrontendEndpointCustomHttpsConfiguration[];
}
export interface FrontdoorRoutingRuleForwardingConfiguration {
    readonly backendPoolName: string;
    readonly cacheEnabled?: boolean;
    readonly cacheQueryParameterStripDirective?: string;
    readonly cacheUseDynamicCompression?: boolean;
    readonly customForwardingPath?: string;
    readonly forwardingProtocol?: string;
}
export interface FrontdoorRoutingRuleRedirectConfiguration {
    readonly customFragment?: string;
    readonly customHost?: string;
    readonly customPath?: string;
    readonly customQueryString?: string;
    readonly redirectProtocol: string;
    readonly redirectType: string;
}
export interface FrontdoorRoutingRule {
    readonly acceptedProtocols: string[];
    readonly enabled?: boolean;
    readonly frontendEndpoints: string[];
    readonly name: string;
    readonly patternsToMatch: string[];
    /**
     * forwarding_configuration block.
     */
    readonly forwardingConfiguration?: FrontdoorRoutingRuleForwardingConfiguration[];
    /**
     * redirect_configuration block.
     */
    readonly redirectConfiguration?: FrontdoorRoutingRuleRedirectConfiguration[];
}
export interface FrontdoorTimeouts {
    readonly create?: string;
    readonly delete?: string;
    readonly read?: string;
    readonly update?: string;
}
export declare class Frontdoor extends cdktf.TerraformResource {
    constructor(scope: Construct, id: string, config: FrontdoorConfig);
    private _backendPoolsSendReceiveTimeoutSeconds?;
    get backendPoolsSendReceiveTimeoutSeconds(): number;
    set backendPoolsSendReceiveTimeoutSeconds(value: number);
    resetBackendPoolsSendReceiveTimeoutSeconds(): void;
    get backendPoolsSendReceiveTimeoutSecondsInput(): number | undefined;
    get cname(): string;
    private _enforceBackendPoolsCertificateNameCheck;
    get enforceBackendPoolsCertificateNameCheck(): boolean;
    set enforceBackendPoolsCertificateNameCheck(value: boolean);
    get enforceBackendPoolsCertificateNameCheckInput(): boolean;
    private _friendlyName?;
    get friendlyName(): string;
    set friendlyName(value: string);
    resetFriendlyName(): void;
    get friendlyNameInput(): string | undefined;
    get headerFrontdoorId(): string;
    get id(): string;
    private _loadBalancerEnabled?;
    get loadBalancerEnabled(): boolean;
    set loadBalancerEnabled(value: boolean);
    resetLoadBalancerEnabled(): void;
    get loadBalancerEnabledInput(): boolean | undefined;
    private _location?;
    get location(): string;
    set location(value: string);
    resetLocation(): void;
    get locationInput(): string | undefined;
    private _name;
    get name(): string;
    set name(value: string);
    get nameInput(): string;
    private _resourceGroupName;
    get resourceGroupName(): string;
    set resourceGroupName(value: string);
    get resourceGroupNameInput(): string;
    private _tags?;
    get tags(): {
        [key: string]: string;
    };
    set tags(value: {
        [key: string]: string;
    });
    resetTags(): void;
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _backendPool;
    get backendPool(): FrontdoorBackendPool[];
    set backendPool(value: FrontdoorBackendPool[]);
    get backendPoolInput(): FrontdoorBackendPool[];
    private _backendPoolHealthProbe;
    get backendPoolHealthProbe(): FrontdoorBackendPoolHealthProbe[];
    set backendPoolHealthProbe(value: FrontdoorBackendPoolHealthProbe[]);
    get backendPoolHealthProbeInput(): FrontdoorBackendPoolHealthProbe[];
    private _backendPoolLoadBalancing;
    get backendPoolLoadBalancing(): FrontdoorBackendPoolLoadBalancing[];
    set backendPoolLoadBalancing(value: FrontdoorBackendPoolLoadBalancing[]);
    get backendPoolLoadBalancingInput(): FrontdoorBackendPoolLoadBalancing[];
    private _frontendEndpoint;
    get frontendEndpoint(): FrontdoorFrontendEndpoint[];
    set frontendEndpoint(value: FrontdoorFrontendEndpoint[]);
    get frontendEndpointInput(): FrontdoorFrontendEndpoint[];
    private _routingRule;
    get routingRule(): FrontdoorRoutingRule[];
    set routingRule(value: FrontdoorRoutingRule[]);
    get routingRuleInput(): FrontdoorRoutingRule[];
    private _timeouts?;
    get timeouts(): FrontdoorTimeouts;
    set timeouts(value: FrontdoorTimeouts);
    resetTimeouts(): void;
    get timeoutsInput(): FrontdoorTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
