import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface FunctionAppSlotConfig extends cdktf.TerraformMetaArguments {
    readonly appServicePlanId: string;
    readonly appSettings?: {
        [key: string]: string;
    };
    readonly clientAffinityEnabled?: boolean;
    readonly dailyMemoryTimeQuota?: number;
    readonly enableBuiltinLogging?: boolean;
    readonly enabled?: boolean;
    readonly functionAppName: string;
    readonly httpsOnly?: boolean;
    readonly location: string;
    readonly name: string;
    readonly osType?: string;
    readonly resourceGroupName: string;
    readonly storageAccountAccessKey: string;
    readonly storageAccountName: string;
    readonly tags?: {
        [key: string]: string;
    };
    readonly version?: string;
    /**
     * auth_settings block.
     */
    readonly authSettings?: FunctionAppSlotAuthSettings[];
    /**
     * connection_string block.
     */
    readonly connectionString?: FunctionAppSlotConnectionString[];
    /**
     * identity block.
     */
    readonly identity?: FunctionAppSlotIdentity[];
    /**
     * site_config block.
     */
    readonly siteConfig?: FunctionAppSlotSiteConfig[];
    /**
     * timeouts block.
     */
    readonly timeouts?: FunctionAppSlotTimeouts;
}
export declare class FunctionAppSlotSiteCredential extends cdktf.ComplexComputedList {
    get password(): string;
    get username(): string;
}
export interface FunctionAppSlotAuthSettingsActiveDirectory {
    readonly allowedAudiences?: string[];
    readonly clientId: string;
    readonly clientSecret?: string;
}
export interface FunctionAppSlotAuthSettingsFacebook {
    readonly appId: string;
    readonly appSecret: string;
    readonly oauthScopes?: string[];
}
export interface FunctionAppSlotAuthSettingsGoogle {
    readonly clientId: string;
    readonly clientSecret: string;
    readonly oauthScopes?: string[];
}
export interface FunctionAppSlotAuthSettingsMicrosoft {
    readonly clientId: string;
    readonly clientSecret: string;
    readonly oauthScopes?: string[];
}
export interface FunctionAppSlotAuthSettingsTwitter {
    readonly consumerKey: string;
    readonly consumerSecret: string;
}
export interface FunctionAppSlotAuthSettings {
    readonly additionalLoginParams?: {
        [key: string]: string;
    };
    readonly allowedExternalRedirectUrls?: string[];
    readonly defaultProvider?: string;
    readonly enabled: boolean;
    readonly issuer?: string;
    readonly runtimeVersion?: string;
    readonly tokenRefreshExtensionHours?: number;
    readonly tokenStoreEnabled?: boolean;
    readonly unauthenticatedClientAction?: string;
    /**
     * active_directory block.
     */
    readonly activeDirectory?: FunctionAppSlotAuthSettingsActiveDirectory[];
    /**
     * facebook block.
     */
    readonly facebook?: FunctionAppSlotAuthSettingsFacebook[];
    /**
     * google block.
     */
    readonly google?: FunctionAppSlotAuthSettingsGoogle[];
    /**
     * microsoft block.
     */
    readonly microsoft?: FunctionAppSlotAuthSettingsMicrosoft[];
    /**
     * twitter block.
     */
    readonly twitter?: FunctionAppSlotAuthSettingsTwitter[];
}
export interface FunctionAppSlotConnectionString {
    readonly name: string;
    readonly type: string;
    readonly value: string;
}
export interface FunctionAppSlotIdentity {
    readonly identityIds?: string[];
    readonly type: string;
}
export interface FunctionAppSlotSiteConfigIpRestriction {
    readonly action?: string;
    readonly ipAddress?: string;
    readonly name?: string;
    readonly priority?: number;
    readonly subnetId?: string;
    readonly virtualNetworkSubnetId?: string;
}
export interface FunctionAppSlotSiteConfigScmIpRestriction {
    readonly action?: string;
    readonly ipAddress?: string;
    readonly name?: string;
    readonly priority?: number;
    readonly subnetId?: string;
    readonly virtualNetworkSubnetId?: string;
}
export interface FunctionAppSlotSiteConfigCors {
    readonly allowedOrigins: string[];
    readonly supportCredentials?: boolean;
}
export interface FunctionAppSlotSiteConfig {
    readonly alwaysOn?: boolean;
    readonly autoSwapSlotName?: string;
    readonly ftpsState?: string;
    readonly healthCheckPath?: string;
    readonly http2Enabled?: boolean;
    readonly ipRestriction?: FunctionAppSlotSiteConfigIpRestriction[];
    readonly linuxFxVersion?: string;
    readonly minTlsVersion?: string;
    readonly preWarmedInstanceCount?: number;
    readonly scmIpRestriction?: FunctionAppSlotSiteConfigScmIpRestriction[];
    readonly scmType?: string;
    readonly scmUseMainIpRestriction?: boolean;
    readonly use32BitWorkerProcess?: boolean;
    readonly websocketsEnabled?: boolean;
    /**
     * cors block.
     */
    readonly cors?: FunctionAppSlotSiteConfigCors[];
}
export interface FunctionAppSlotTimeouts {
    readonly create?: string;
    readonly delete?: string;
    readonly read?: string;
    readonly update?: string;
}
export declare class FunctionAppSlot extends cdktf.TerraformResource {
    constructor(scope: Construct, id: string, config: FunctionAppSlotConfig);
    private _appServicePlanId;
    get appServicePlanId(): string;
    set appServicePlanId(value: string);
    get appServicePlanIdInput(): string;
    private _appSettings?;
    get appSettings(): {
        [key: string]: string;
    };
    set appSettings(value: {
        [key: string]: string;
    });
    resetAppSettings(): void;
    get appSettingsInput(): {
        [key: string]: string;
    } | undefined;
    private _clientAffinityEnabled?;
    get clientAffinityEnabled(): boolean;
    set clientAffinityEnabled(value: boolean);
    resetClientAffinityEnabled(): void;
    get clientAffinityEnabledInput(): boolean | undefined;
    private _dailyMemoryTimeQuota?;
    get dailyMemoryTimeQuota(): number;
    set dailyMemoryTimeQuota(value: number);
    resetDailyMemoryTimeQuota(): void;
    get dailyMemoryTimeQuotaInput(): number | undefined;
    get defaultHostname(): string;
    private _enableBuiltinLogging?;
    get enableBuiltinLogging(): boolean;
    set enableBuiltinLogging(value: boolean);
    resetEnableBuiltinLogging(): void;
    get enableBuiltinLoggingInput(): boolean | undefined;
    private _enabled?;
    get enabled(): boolean;
    set enabled(value: boolean);
    resetEnabled(): void;
    get enabledInput(): boolean | undefined;
    private _functionAppName;
    get functionAppName(): string;
    set functionAppName(value: string);
    get functionAppNameInput(): string;
    private _httpsOnly?;
    get httpsOnly(): boolean;
    set httpsOnly(value: boolean);
    resetHttpsOnly(): void;
    get httpsOnlyInput(): boolean | undefined;
    get id(): string;
    get kind(): string;
    private _location;
    get location(): string;
    set location(value: string);
    get locationInput(): string;
    private _name;
    get name(): string;
    set name(value: string);
    get nameInput(): string;
    private _osType?;
    get osType(): string;
    set osType(value: string);
    resetOsType(): void;
    get osTypeInput(): string | undefined;
    get outboundIpAddresses(): string;
    get possibleOutboundIpAddresses(): string;
    private _resourceGroupName;
    get resourceGroupName(): string;
    set resourceGroupName(value: string);
    get resourceGroupNameInput(): string;
    siteCredential(index: string): FunctionAppSlotSiteCredential;
    private _storageAccountAccessKey;
    get storageAccountAccessKey(): string;
    set storageAccountAccessKey(value: string);
    get storageAccountAccessKeyInput(): string;
    private _storageAccountName;
    get storageAccountName(): string;
    set storageAccountName(value: string);
    get storageAccountNameInput(): string;
    private _tags?;
    get tags(): {
        [key: string]: string;
    };
    set tags(value: {
        [key: string]: string;
    });
    resetTags(): void;
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _version?;
    get version(): string;
    set version(value: string);
    resetVersion(): void;
    get versionInput(): string | undefined;
    private _authSettings?;
    get authSettings(): FunctionAppSlotAuthSettings[];
    set authSettings(value: FunctionAppSlotAuthSettings[]);
    resetAuthSettings(): void;
    get authSettingsInput(): FunctionAppSlotAuthSettings[] | undefined;
    private _connectionString?;
    get connectionString(): FunctionAppSlotConnectionString[];
    set connectionString(value: FunctionAppSlotConnectionString[]);
    resetConnectionString(): void;
    get connectionStringInput(): FunctionAppSlotConnectionString[] | undefined;
    private _identity?;
    get identity(): FunctionAppSlotIdentity[];
    set identity(value: FunctionAppSlotIdentity[]);
    resetIdentity(): void;
    get identityInput(): FunctionAppSlotIdentity[] | undefined;
    private _siteConfig?;
    get siteConfig(): FunctionAppSlotSiteConfig[];
    set siteConfig(value: FunctionAppSlotSiteConfig[]);
    resetSiteConfig(): void;
    get siteConfigInput(): FunctionAppSlotSiteConfig[] | undefined;
    private _timeouts?;
    get timeouts(): FunctionAppSlotTimeouts;
    set timeouts(value: FunctionAppSlotTimeouts);
    resetTimeouts(): void;
    get timeoutsInput(): FunctionAppSlotTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
