import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface FunctionAppConfig extends cdktf.TerraformMetaArguments {
    readonly appServicePlanId: string;
    readonly appSettings?: {
        [key: string]: string;
    };
    readonly clientAffinityEnabled?: boolean;
    readonly dailyMemoryTimeQuota?: number;
    readonly enableBuiltinLogging?: boolean;
    readonly enabled?: boolean;
    readonly httpsOnly?: boolean;
    readonly location: string;
    readonly name: string;
    readonly osType?: string;
    readonly resourceGroupName: string;
    readonly storageAccountAccessKey?: string;
    readonly storageAccountName?: string;
    readonly storageConnectionString?: string;
    readonly tags?: {
        [key: string]: string;
    };
    readonly version?: string;
    /**
     * auth_settings block.
     */
    readonly authSettings?: FunctionAppAuthSettings[];
    /**
     * connection_string block.
     */
    readonly connectionString?: FunctionAppConnectionString[];
    /**
     * identity block.
     */
    readonly identity?: FunctionAppIdentity[];
    /**
     * site_config block.
     */
    readonly siteConfig?: FunctionAppSiteConfig[];
    /**
     * source_control block.
     */
    readonly sourceControl?: FunctionAppSourceControl[];
    /**
     * timeouts block.
     */
    readonly timeouts?: FunctionAppTimeouts;
}
export declare class FunctionAppSiteCredential extends cdktf.ComplexComputedList {
    get password(): string;
    get username(): string;
}
export interface FunctionAppAuthSettingsActiveDirectory {
    readonly allowedAudiences?: string[];
    readonly clientId: string;
    readonly clientSecret?: string;
}
export interface FunctionAppAuthSettingsFacebook {
    readonly appId: string;
    readonly appSecret: string;
    readonly oauthScopes?: string[];
}
export interface FunctionAppAuthSettingsGoogle {
    readonly clientId: string;
    readonly clientSecret: string;
    readonly oauthScopes?: string[];
}
export interface FunctionAppAuthSettingsMicrosoft {
    readonly clientId: string;
    readonly clientSecret: string;
    readonly oauthScopes?: string[];
}
export interface FunctionAppAuthSettingsTwitter {
    readonly consumerKey: string;
    readonly consumerSecret: string;
}
export interface FunctionAppAuthSettings {
    readonly additionalLoginParams?: {
        [key: string]: string;
    };
    readonly allowedExternalRedirectUrls?: string[];
    readonly defaultProvider?: string;
    readonly enabled: boolean;
    readonly issuer?: string;
    readonly runtimeVersion?: string;
    readonly tokenRefreshExtensionHours?: number;
    readonly tokenStoreEnabled?: boolean;
    readonly unauthenticatedClientAction?: string;
    /**
     * active_directory block.
     */
    readonly activeDirectory?: FunctionAppAuthSettingsActiveDirectory[];
    /**
     * facebook block.
     */
    readonly facebook?: FunctionAppAuthSettingsFacebook[];
    /**
     * google block.
     */
    readonly google?: FunctionAppAuthSettingsGoogle[];
    /**
     * microsoft block.
     */
    readonly microsoft?: FunctionAppAuthSettingsMicrosoft[];
    /**
     * twitter block.
     */
    readonly twitter?: FunctionAppAuthSettingsTwitter[];
}
export interface FunctionAppConnectionString {
    readonly name: string;
    readonly type: string;
    readonly value: string;
}
export interface FunctionAppIdentity {
    readonly identityIds?: string[];
    readonly type: string;
}
export interface FunctionAppSiteConfigIpRestriction {
    readonly action?: string;
    readonly ipAddress?: string;
    readonly name?: string;
    readonly priority?: number;
    readonly subnetId?: string;
    readonly virtualNetworkSubnetId?: string;
}
export interface FunctionAppSiteConfigScmIpRestriction {
    readonly action?: string;
    readonly ipAddress?: string;
    readonly name?: string;
    readonly priority?: number;
    readonly subnetId?: string;
    readonly virtualNetworkSubnetId?: string;
}
export interface FunctionAppSiteConfigCors {
    readonly allowedOrigins: string[];
    readonly supportCredentials?: boolean;
}
export interface FunctionAppSiteConfig {
    readonly alwaysOn?: boolean;
    readonly autoSwapSlotName?: string;
    readonly ftpsState?: string;
    readonly healthCheckPath?: string;
    readonly http2Enabled?: boolean;
    readonly ipRestriction?: FunctionAppSiteConfigIpRestriction[];
    readonly linuxFxVersion?: string;
    readonly minTlsVersion?: string;
    readonly preWarmedInstanceCount?: number;
    readonly scmIpRestriction?: FunctionAppSiteConfigScmIpRestriction[];
    readonly scmType?: string;
    readonly scmUseMainIpRestriction?: boolean;
    readonly use32BitWorkerProcess?: boolean;
    readonly websocketsEnabled?: boolean;
    /**
     * cors block.
     */
    readonly cors?: FunctionAppSiteConfigCors[];
}
export interface FunctionAppSourceControl {
    readonly branch?: string;
    readonly manualIntegration?: boolean;
    readonly repoUrl?: string;
    readonly rollbackEnabled?: boolean;
    readonly useMercurial?: boolean;
}
export interface FunctionAppTimeouts {
    readonly create?: string;
    readonly delete?: string;
    readonly read?: string;
    readonly update?: string;
}
export declare class FunctionApp extends cdktf.TerraformResource {
    constructor(scope: Construct, id: string, config: FunctionAppConfig);
    private _appServicePlanId;
    get appServicePlanId(): string;
    set appServicePlanId(value: string);
    get appServicePlanIdInput(): string;
    private _appSettings?;
    get appSettings(): {
        [key: string]: string;
    };
    set appSettings(value: {
        [key: string]: string;
    });
    resetAppSettings(): void;
    get appSettingsInput(): {
        [key: string]: string;
    } | undefined;
    private _clientAffinityEnabled?;
    get clientAffinityEnabled(): boolean;
    set clientAffinityEnabled(value: boolean);
    resetClientAffinityEnabled(): void;
    get clientAffinityEnabledInput(): boolean | undefined;
    get customDomainVerificationId(): string;
    private _dailyMemoryTimeQuota?;
    get dailyMemoryTimeQuota(): number;
    set dailyMemoryTimeQuota(value: number);
    resetDailyMemoryTimeQuota(): void;
    get dailyMemoryTimeQuotaInput(): number | undefined;
    get defaultHostname(): string;
    private _enableBuiltinLogging?;
    get enableBuiltinLogging(): boolean;
    set enableBuiltinLogging(value: boolean);
    resetEnableBuiltinLogging(): void;
    get enableBuiltinLoggingInput(): boolean | undefined;
    private _enabled?;
    get enabled(): boolean;
    set enabled(value: boolean);
    resetEnabled(): void;
    get enabledInput(): boolean | undefined;
    private _httpsOnly?;
    get httpsOnly(): boolean;
    set httpsOnly(value: boolean);
    resetHttpsOnly(): void;
    get httpsOnlyInput(): boolean | undefined;
    get id(): string;
    get kind(): string;
    private _location;
    get location(): string;
    set location(value: string);
    get locationInput(): string;
    private _name;
    get name(): string;
    set name(value: string);
    get nameInput(): string;
    private _osType?;
    get osType(): string;
    set osType(value: string);
    resetOsType(): void;
    get osTypeInput(): string | undefined;
    get outboundIpAddresses(): string;
    get possibleOutboundIpAddresses(): string;
    private _resourceGroupName;
    get resourceGroupName(): string;
    set resourceGroupName(value: string);
    get resourceGroupNameInput(): string;
    siteCredential(index: string): FunctionAppSiteCredential;
    private _storageAccountAccessKey?;
    get storageAccountAccessKey(): string;
    set storageAccountAccessKey(value: string);
    resetStorageAccountAccessKey(): void;
    get storageAccountAccessKeyInput(): string | undefined;
    private _storageAccountName?;
    get storageAccountName(): string;
    set storageAccountName(value: string);
    resetStorageAccountName(): void;
    get storageAccountNameInput(): string | undefined;
    private _storageConnectionString?;
    get storageConnectionString(): string;
    set storageConnectionString(value: string);
    resetStorageConnectionString(): void;
    get storageConnectionStringInput(): string | undefined;
    private _tags?;
    get tags(): {
        [key: string]: string;
    };
    set tags(value: {
        [key: string]: string;
    });
    resetTags(): void;
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _version?;
    get version(): string;
    set version(value: string);
    resetVersion(): void;
    get versionInput(): string | undefined;
    private _authSettings?;
    get authSettings(): FunctionAppAuthSettings[];
    set authSettings(value: FunctionAppAuthSettings[]);
    resetAuthSettings(): void;
    get authSettingsInput(): FunctionAppAuthSettings[] | undefined;
    private _connectionString?;
    get connectionString(): FunctionAppConnectionString[];
    set connectionString(value: FunctionAppConnectionString[]);
    resetConnectionString(): void;
    get connectionStringInput(): FunctionAppConnectionString[] | undefined;
    private _identity?;
    get identity(): FunctionAppIdentity[];
    set identity(value: FunctionAppIdentity[]);
    resetIdentity(): void;
    get identityInput(): FunctionAppIdentity[] | undefined;
    private _siteConfig?;
    get siteConfig(): FunctionAppSiteConfig[];
    set siteConfig(value: FunctionAppSiteConfig[]);
    resetSiteConfig(): void;
    get siteConfigInput(): FunctionAppSiteConfig[] | undefined;
    private _sourceControl?;
    get sourceControl(): FunctionAppSourceControl[];
    set sourceControl(value: FunctionAppSourceControl[]);
    resetSourceControl(): void;
    get sourceControlInput(): FunctionAppSourceControl[] | undefined;
    private _timeouts?;
    get timeouts(): FunctionAppTimeouts;
    set timeouts(value: FunctionAppTimeouts);
    resetTimeouts(): void;
    get timeoutsInput(): FunctionAppTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
