import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface HdinsightHbaseClusterConfig extends cdktf.TerraformMetaArguments {
    readonly clusterVersion: string;
    readonly location: string;
    readonly name: string;
    readonly resourceGroupName: string;
    readonly tags?: {
        [key: string]: string;
    };
    readonly tier: string;
    readonly tlsMinVersion?: string;
    /**
     * component_version block.
     */
    readonly componentVersion: HdinsightHbaseClusterComponentVersion[];
    /**
     * gateway block.
     */
    readonly gateway: HdinsightHbaseClusterGateway[];
    /**
     * metastores block.
     */
    readonly metastores?: HdinsightHbaseClusterMetastores[];
    /**
     * monitor block.
     */
    readonly monitor?: HdinsightHbaseClusterMonitor[];
    /**
     * roles block.
     */
    readonly roles: HdinsightHbaseClusterRoles[];
    /**
     * storage_account block.
     */
    readonly storageAccount?: HdinsightHbaseClusterStorageAccount[];
    /**
     * storage_account_gen2 block.
     */
    readonly storageAccountGen2?: HdinsightHbaseClusterStorageAccountGen2[];
    /**
     * timeouts block.
     */
    readonly timeouts?: HdinsightHbaseClusterTimeouts;
}
export interface HdinsightHbaseClusterComponentVersion {
    readonly hbase: string;
}
export interface HdinsightHbaseClusterGateway {
    readonly enabled?: boolean;
    readonly password: string;
    readonly username: string;
}
export interface HdinsightHbaseClusterMetastoresAmbari {
    readonly databaseName: string;
    readonly password: string;
    readonly server: string;
    readonly username: string;
}
export interface HdinsightHbaseClusterMetastoresHive {
    readonly databaseName: string;
    readonly password: string;
    readonly server: string;
    readonly username: string;
}
export interface HdinsightHbaseClusterMetastoresOozie {
    readonly databaseName: string;
    readonly password: string;
    readonly server: string;
    readonly username: string;
}
export interface HdinsightHbaseClusterMetastores {
    /**
     * ambari block.
     */
    readonly ambari?: HdinsightHbaseClusterMetastoresAmbari[];
    /**
     * hive block.
     */
    readonly hive?: HdinsightHbaseClusterMetastoresHive[];
    /**
     * oozie block.
     */
    readonly oozie?: HdinsightHbaseClusterMetastoresOozie[];
}
export interface HdinsightHbaseClusterMonitor {
    readonly logAnalyticsWorkspaceId: string;
    readonly primaryKey: string;
}
export interface HdinsightHbaseClusterRolesHeadNode {
    readonly password?: string;
    readonly sshKeys?: string[];
    readonly subnetId?: string;
    readonly username: string;
    readonly virtualNetworkId?: string;
    readonly vmSize: string;
}
export interface HdinsightHbaseClusterRolesWorkerNode {
    readonly minInstanceCount?: number;
    readonly password?: string;
    readonly sshKeys?: string[];
    readonly subnetId?: string;
    readonly targetInstanceCount: number;
    readonly username: string;
    readonly virtualNetworkId?: string;
    readonly vmSize: string;
}
export interface HdinsightHbaseClusterRolesZookeeperNode {
    readonly password?: string;
    readonly sshKeys?: string[];
    readonly subnetId?: string;
    readonly username: string;
    readonly virtualNetworkId?: string;
    readonly vmSize: string;
}
export interface HdinsightHbaseClusterRoles {
    /**
     * head_node block.
     */
    readonly headNode: HdinsightHbaseClusterRolesHeadNode[];
    /**
     * worker_node block.
     */
    readonly workerNode: HdinsightHbaseClusterRolesWorkerNode[];
    /**
     * zookeeper_node block.
     */
    readonly zookeeperNode: HdinsightHbaseClusterRolesZookeeperNode[];
}
export interface HdinsightHbaseClusterStorageAccount {
    readonly isDefault: boolean;
    readonly storageAccountKey: string;
    readonly storageContainerId: string;
}
export interface HdinsightHbaseClusterStorageAccountGen2 {
    readonly filesystemId: string;
    readonly isDefault: boolean;
    readonly managedIdentityResourceId: string;
    readonly storageResourceId: string;
}
export interface HdinsightHbaseClusterTimeouts {
    readonly create?: string;
    readonly delete?: string;
    readonly read?: string;
    readonly update?: string;
}
export declare class HdinsightHbaseCluster extends cdktf.TerraformResource {
    constructor(scope: Construct, id: string, config: HdinsightHbaseClusterConfig);
    private _clusterVersion;
    get clusterVersion(): string;
    set clusterVersion(value: string);
    get clusterVersionInput(): string;
    get httpsEndpoint(): string;
    get id(): string;
    private _location;
    get location(): string;
    set location(value: string);
    get locationInput(): string;
    private _name;
    get name(): string;
    set name(value: string);
    get nameInput(): string;
    private _resourceGroupName;
    get resourceGroupName(): string;
    set resourceGroupName(value: string);
    get resourceGroupNameInput(): string;
    get sshEndpoint(): string;
    private _tags?;
    get tags(): {
        [key: string]: string;
    };
    set tags(value: {
        [key: string]: string;
    });
    resetTags(): void;
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _tier;
    get tier(): string;
    set tier(value: string);
    get tierInput(): string;
    private _tlsMinVersion?;
    get tlsMinVersion(): string;
    set tlsMinVersion(value: string);
    resetTlsMinVersion(): void;
    get tlsMinVersionInput(): string | undefined;
    private _componentVersion;
    get componentVersion(): HdinsightHbaseClusterComponentVersion[];
    set componentVersion(value: HdinsightHbaseClusterComponentVersion[]);
    get componentVersionInput(): HdinsightHbaseClusterComponentVersion[];
    private _gateway;
    get gateway(): HdinsightHbaseClusterGateway[];
    set gateway(value: HdinsightHbaseClusterGateway[]);
    get gatewayInput(): HdinsightHbaseClusterGateway[];
    private _metastores?;
    get metastores(): HdinsightHbaseClusterMetastores[];
    set metastores(value: HdinsightHbaseClusterMetastores[]);
    resetMetastores(): void;
    get metastoresInput(): HdinsightHbaseClusterMetastores[] | undefined;
    private _monitor?;
    get monitor(): HdinsightHbaseClusterMonitor[];
    set monitor(value: HdinsightHbaseClusterMonitor[]);
    resetMonitor(): void;
    get monitorInput(): HdinsightHbaseClusterMonitor[] | undefined;
    private _roles;
    get roles(): HdinsightHbaseClusterRoles[];
    set roles(value: HdinsightHbaseClusterRoles[]);
    get rolesInput(): HdinsightHbaseClusterRoles[];
    private _storageAccount?;
    get storageAccount(): HdinsightHbaseClusterStorageAccount[];
    set storageAccount(value: HdinsightHbaseClusterStorageAccount[]);
    resetStorageAccount(): void;
    get storageAccountInput(): HdinsightHbaseClusterStorageAccount[] | undefined;
    private _storageAccountGen2?;
    get storageAccountGen2(): HdinsightHbaseClusterStorageAccountGen2[];
    set storageAccountGen2(value: HdinsightHbaseClusterStorageAccountGen2[]);
    resetStorageAccountGen2(): void;
    get storageAccountGen2Input(): HdinsightHbaseClusterStorageAccountGen2[] | undefined;
    private _timeouts?;
    get timeouts(): HdinsightHbaseClusterTimeouts;
    set timeouts(value: HdinsightHbaseClusterTimeouts);
    resetTimeouts(): void;
    get timeoutsInput(): HdinsightHbaseClusterTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
