import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface HdinsightKafkaClusterConfig extends cdktf.TerraformMetaArguments {
    readonly clusterVersion: string;
    readonly location: string;
    readonly name: string;
    readonly resourceGroupName: string;
    readonly tags?: {
        [key: string]: string;
    };
    readonly tier: string;
    readonly tlsMinVersion?: string;
    /**
     * component_version block.
     */
    readonly componentVersion: HdinsightKafkaClusterComponentVersion[];
    /**
     * gateway block.
     */
    readonly gateway: HdinsightKafkaClusterGateway[];
    /**
     * metastores block.
     */
    readonly metastores?: HdinsightKafkaClusterMetastores[];
    /**
     * monitor block.
     */
    readonly monitor?: HdinsightKafkaClusterMonitor[];
    /**
     * roles block.
     */
    readonly roles: HdinsightKafkaClusterRoles[];
    /**
     * storage_account block.
     */
    readonly storageAccount?: HdinsightKafkaClusterStorageAccount[];
    /**
     * storage_account_gen2 block.
     */
    readonly storageAccountGen2?: HdinsightKafkaClusterStorageAccountGen2[];
    /**
     * timeouts block.
     */
    readonly timeouts?: HdinsightKafkaClusterTimeouts;
}
export interface HdinsightKafkaClusterComponentVersion {
    readonly kafka: string;
}
export interface HdinsightKafkaClusterGateway {
    readonly enabled?: boolean;
    readonly password: string;
    readonly username: string;
}
export interface HdinsightKafkaClusterMetastoresAmbari {
    readonly databaseName: string;
    readonly password: string;
    readonly server: string;
    readonly username: string;
}
export interface HdinsightKafkaClusterMetastoresHive {
    readonly databaseName: string;
    readonly password: string;
    readonly server: string;
    readonly username: string;
}
export interface HdinsightKafkaClusterMetastoresOozie {
    readonly databaseName: string;
    readonly password: string;
    readonly server: string;
    readonly username: string;
}
export interface HdinsightKafkaClusterMetastores {
    /**
     * ambari block.
     */
    readonly ambari?: HdinsightKafkaClusterMetastoresAmbari[];
    /**
     * hive block.
     */
    readonly hive?: HdinsightKafkaClusterMetastoresHive[];
    /**
     * oozie block.
     */
    readonly oozie?: HdinsightKafkaClusterMetastoresOozie[];
}
export interface HdinsightKafkaClusterMonitor {
    readonly logAnalyticsWorkspaceId: string;
    readonly primaryKey: string;
}
export interface HdinsightKafkaClusterRolesHeadNode {
    readonly password?: string;
    readonly sshKeys?: string[];
    readonly subnetId?: string;
    readonly username: string;
    readonly virtualNetworkId?: string;
    readonly vmSize: string;
}
export interface HdinsightKafkaClusterRolesWorkerNode {
    readonly minInstanceCount?: number;
    readonly numberOfDisksPerNode: number;
    readonly password?: string;
    readonly sshKeys?: string[];
    readonly subnetId?: string;
    readonly targetInstanceCount: number;
    readonly username: string;
    readonly virtualNetworkId?: string;
    readonly vmSize: string;
}
export interface HdinsightKafkaClusterRolesZookeeperNode {
    readonly password?: string;
    readonly sshKeys?: string[];
    readonly subnetId?: string;
    readonly username: string;
    readonly virtualNetworkId?: string;
    readonly vmSize: string;
}
export interface HdinsightKafkaClusterRoles {
    /**
     * head_node block.
     */
    readonly headNode: HdinsightKafkaClusterRolesHeadNode[];
    /**
     * worker_node block.
     */
    readonly workerNode: HdinsightKafkaClusterRolesWorkerNode[];
    /**
     * zookeeper_node block.
     */
    readonly zookeeperNode: HdinsightKafkaClusterRolesZookeeperNode[];
}
export interface HdinsightKafkaClusterStorageAccount {
    readonly isDefault: boolean;
    readonly storageAccountKey: string;
    readonly storageContainerId: string;
}
export interface HdinsightKafkaClusterStorageAccountGen2 {
    readonly filesystemId: string;
    readonly isDefault: boolean;
    readonly managedIdentityResourceId: string;
    readonly storageResourceId: string;
}
export interface HdinsightKafkaClusterTimeouts {
    readonly create?: string;
    readonly delete?: string;
    readonly read?: string;
    readonly update?: string;
}
export declare class HdinsightKafkaCluster extends cdktf.TerraformResource {
    constructor(scope: Construct, id: string, config: HdinsightKafkaClusterConfig);
    private _clusterVersion;
    get clusterVersion(): string;
    set clusterVersion(value: string);
    get clusterVersionInput(): string;
    get httpsEndpoint(): string;
    get id(): string;
    private _location;
    get location(): string;
    set location(value: string);
    get locationInput(): string;
    private _name;
    get name(): string;
    set name(value: string);
    get nameInput(): string;
    private _resourceGroupName;
    get resourceGroupName(): string;
    set resourceGroupName(value: string);
    get resourceGroupNameInput(): string;
    get sshEndpoint(): string;
    private _tags?;
    get tags(): {
        [key: string]: string;
    };
    set tags(value: {
        [key: string]: string;
    });
    resetTags(): void;
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _tier;
    get tier(): string;
    set tier(value: string);
    get tierInput(): string;
    private _tlsMinVersion?;
    get tlsMinVersion(): string;
    set tlsMinVersion(value: string);
    resetTlsMinVersion(): void;
    get tlsMinVersionInput(): string | undefined;
    private _componentVersion;
    get componentVersion(): HdinsightKafkaClusterComponentVersion[];
    set componentVersion(value: HdinsightKafkaClusterComponentVersion[]);
    get componentVersionInput(): HdinsightKafkaClusterComponentVersion[];
    private _gateway;
    get gateway(): HdinsightKafkaClusterGateway[];
    set gateway(value: HdinsightKafkaClusterGateway[]);
    get gatewayInput(): HdinsightKafkaClusterGateway[];
    private _metastores?;
    get metastores(): HdinsightKafkaClusterMetastores[];
    set metastores(value: HdinsightKafkaClusterMetastores[]);
    resetMetastores(): void;
    get metastoresInput(): HdinsightKafkaClusterMetastores[] | undefined;
    private _monitor?;
    get monitor(): HdinsightKafkaClusterMonitor[];
    set monitor(value: HdinsightKafkaClusterMonitor[]);
    resetMonitor(): void;
    get monitorInput(): HdinsightKafkaClusterMonitor[] | undefined;
    private _roles;
    get roles(): HdinsightKafkaClusterRoles[];
    set roles(value: HdinsightKafkaClusterRoles[]);
    get rolesInput(): HdinsightKafkaClusterRoles[];
    private _storageAccount?;
    get storageAccount(): HdinsightKafkaClusterStorageAccount[];
    set storageAccount(value: HdinsightKafkaClusterStorageAccount[]);
    resetStorageAccount(): void;
    get storageAccountInput(): HdinsightKafkaClusterStorageAccount[] | undefined;
    private _storageAccountGen2?;
    get storageAccountGen2(): HdinsightKafkaClusterStorageAccountGen2[];
    set storageAccountGen2(value: HdinsightKafkaClusterStorageAccountGen2[]);
    resetStorageAccountGen2(): void;
    get storageAccountGen2Input(): HdinsightKafkaClusterStorageAccountGen2[] | undefined;
    private _timeouts?;
    get timeouts(): HdinsightKafkaClusterTimeouts;
    set timeouts(value: HdinsightKafkaClusterTimeouts);
    resetTimeouts(): void;
    get timeoutsInput(): HdinsightKafkaClusterTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
