import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface HdinsightSparkClusterConfig extends cdktf.TerraformMetaArguments {
    readonly clusterVersion: string;
    readonly location: string;
    readonly name: string;
    readonly resourceGroupName: string;
    readonly tags?: {
        [key: string]: string;
    };
    readonly tier: string;
    readonly tlsMinVersion?: string;
    /**
     * component_version block.
     */
    readonly componentVersion: HdinsightSparkClusterComponentVersion[];
    /**
     * gateway block.
     */
    readonly gateway: HdinsightSparkClusterGateway[];
    /**
     * metastores block.
     */
    readonly metastores?: HdinsightSparkClusterMetastores[];
    /**
     * monitor block.
     */
    readonly monitor?: HdinsightSparkClusterMonitor[];
    /**
     * roles block.
     */
    readonly roles: HdinsightSparkClusterRoles[];
    /**
     * storage_account block.
     */
    readonly storageAccount?: HdinsightSparkClusterStorageAccount[];
    /**
     * storage_account_gen2 block.
     */
    readonly storageAccountGen2?: HdinsightSparkClusterStorageAccountGen2[];
    /**
     * timeouts block.
     */
    readonly timeouts?: HdinsightSparkClusterTimeouts;
}
export interface HdinsightSparkClusterComponentVersion {
    readonly spark: string;
}
export interface HdinsightSparkClusterGateway {
    readonly enabled?: boolean;
    readonly password: string;
    readonly username: string;
}
export interface HdinsightSparkClusterMetastoresAmbari {
    readonly databaseName: string;
    readonly password: string;
    readonly server: string;
    readonly username: string;
}
export interface HdinsightSparkClusterMetastoresHive {
    readonly databaseName: string;
    readonly password: string;
    readonly server: string;
    readonly username: string;
}
export interface HdinsightSparkClusterMetastoresOozie {
    readonly databaseName: string;
    readonly password: string;
    readonly server: string;
    readonly username: string;
}
export interface HdinsightSparkClusterMetastores {
    /**
     * ambari block.
     */
    readonly ambari?: HdinsightSparkClusterMetastoresAmbari[];
    /**
     * hive block.
     */
    readonly hive?: HdinsightSparkClusterMetastoresHive[];
    /**
     * oozie block.
     */
    readonly oozie?: HdinsightSparkClusterMetastoresOozie[];
}
export interface HdinsightSparkClusterMonitor {
    readonly logAnalyticsWorkspaceId: string;
    readonly primaryKey: string;
}
export interface HdinsightSparkClusterRolesHeadNode {
    readonly password?: string;
    readonly sshKeys?: string[];
    readonly subnetId?: string;
    readonly username: string;
    readonly virtualNetworkId?: string;
    readonly vmSize: string;
}
export interface HdinsightSparkClusterRolesWorkerNode {
    readonly minInstanceCount?: number;
    readonly password?: string;
    readonly sshKeys?: string[];
    readonly subnetId?: string;
    readonly targetInstanceCount: number;
    readonly username: string;
    readonly virtualNetworkId?: string;
    readonly vmSize: string;
}
export interface HdinsightSparkClusterRolesZookeeperNode {
    readonly password?: string;
    readonly sshKeys?: string[];
    readonly subnetId?: string;
    readonly username: string;
    readonly virtualNetworkId?: string;
    readonly vmSize: string;
}
export interface HdinsightSparkClusterRoles {
    /**
     * head_node block.
     */
    readonly headNode: HdinsightSparkClusterRolesHeadNode[];
    /**
     * worker_node block.
     */
    readonly workerNode: HdinsightSparkClusterRolesWorkerNode[];
    /**
     * zookeeper_node block.
     */
    readonly zookeeperNode: HdinsightSparkClusterRolesZookeeperNode[];
}
export interface HdinsightSparkClusterStorageAccount {
    readonly isDefault: boolean;
    readonly storageAccountKey: string;
    readonly storageContainerId: string;
}
export interface HdinsightSparkClusterStorageAccountGen2 {
    readonly filesystemId: string;
    readonly isDefault: boolean;
    readonly managedIdentityResourceId: string;
    readonly storageResourceId: string;
}
export interface HdinsightSparkClusterTimeouts {
    readonly create?: string;
    readonly delete?: string;
    readonly read?: string;
    readonly update?: string;
}
export declare class HdinsightSparkCluster extends cdktf.TerraformResource {
    constructor(scope: Construct, id: string, config: HdinsightSparkClusterConfig);
    private _clusterVersion;
    get clusterVersion(): string;
    set clusterVersion(value: string);
    get clusterVersionInput(): string;
    get httpsEndpoint(): string;
    get id(): string;
    private _location;
    get location(): string;
    set location(value: string);
    get locationInput(): string;
    private _name;
    get name(): string;
    set name(value: string);
    get nameInput(): string;
    private _resourceGroupName;
    get resourceGroupName(): string;
    set resourceGroupName(value: string);
    get resourceGroupNameInput(): string;
    get sshEndpoint(): string;
    private _tags?;
    get tags(): {
        [key: string]: string;
    };
    set tags(value: {
        [key: string]: string;
    });
    resetTags(): void;
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _tier;
    get tier(): string;
    set tier(value: string);
    get tierInput(): string;
    private _tlsMinVersion?;
    get tlsMinVersion(): string;
    set tlsMinVersion(value: string);
    resetTlsMinVersion(): void;
    get tlsMinVersionInput(): string | undefined;
    private _componentVersion;
    get componentVersion(): HdinsightSparkClusterComponentVersion[];
    set componentVersion(value: HdinsightSparkClusterComponentVersion[]);
    get componentVersionInput(): HdinsightSparkClusterComponentVersion[];
    private _gateway;
    get gateway(): HdinsightSparkClusterGateway[];
    set gateway(value: HdinsightSparkClusterGateway[]);
    get gatewayInput(): HdinsightSparkClusterGateway[];
    private _metastores?;
    get metastores(): HdinsightSparkClusterMetastores[];
    set metastores(value: HdinsightSparkClusterMetastores[]);
    resetMetastores(): void;
    get metastoresInput(): HdinsightSparkClusterMetastores[] | undefined;
    private _monitor?;
    get monitor(): HdinsightSparkClusterMonitor[];
    set monitor(value: HdinsightSparkClusterMonitor[]);
    resetMonitor(): void;
    get monitorInput(): HdinsightSparkClusterMonitor[] | undefined;
    private _roles;
    get roles(): HdinsightSparkClusterRoles[];
    set roles(value: HdinsightSparkClusterRoles[]);
    get rolesInput(): HdinsightSparkClusterRoles[];
    private _storageAccount?;
    get storageAccount(): HdinsightSparkClusterStorageAccount[];
    set storageAccount(value: HdinsightSparkClusterStorageAccount[]);
    resetStorageAccount(): void;
    get storageAccountInput(): HdinsightSparkClusterStorageAccount[] | undefined;
    private _storageAccountGen2?;
    get storageAccountGen2(): HdinsightSparkClusterStorageAccountGen2[];
    set storageAccountGen2(value: HdinsightSparkClusterStorageAccountGen2[]);
    resetStorageAccountGen2(): void;
    get storageAccountGen2Input(): HdinsightSparkClusterStorageAccountGen2[] | undefined;
    private _timeouts?;
    get timeouts(): HdinsightSparkClusterTimeouts;
    set timeouts(value: HdinsightSparkClusterTimeouts);
    resetTimeouts(): void;
    get timeoutsInput(): HdinsightSparkClusterTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
