import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface HdinsightStormClusterConfig extends cdktf.TerraformMetaArguments {
    readonly clusterVersion: string;
    readonly location: string;
    readonly name: string;
    readonly resourceGroupName: string;
    readonly tags?: {
        [key: string]: string;
    };
    readonly tier: string;
    readonly tlsMinVersion?: string;
    /**
     * component_version block.
     */
    readonly componentVersion: HdinsightStormClusterComponentVersion[];
    /**
     * gateway block.
     */
    readonly gateway: HdinsightStormClusterGateway[];
    /**
     * metastores block.
     */
    readonly metastores?: HdinsightStormClusterMetastores[];
    /**
     * monitor block.
     */
    readonly monitor?: HdinsightStormClusterMonitor[];
    /**
     * roles block.
     */
    readonly roles: HdinsightStormClusterRoles[];
    /**
     * storage_account block.
     */
    readonly storageAccount?: HdinsightStormClusterStorageAccount[];
    /**
     * timeouts block.
     */
    readonly timeouts?: HdinsightStormClusterTimeouts;
}
export interface HdinsightStormClusterComponentVersion {
    readonly storm: string;
}
export interface HdinsightStormClusterGateway {
    readonly enabled?: boolean;
    readonly password: string;
    readonly username: string;
}
export interface HdinsightStormClusterMetastoresAmbari {
    readonly databaseName: string;
    readonly password: string;
    readonly server: string;
    readonly username: string;
}
export interface HdinsightStormClusterMetastoresHive {
    readonly databaseName: string;
    readonly password: string;
    readonly server: string;
    readonly username: string;
}
export interface HdinsightStormClusterMetastoresOozie {
    readonly databaseName: string;
    readonly password: string;
    readonly server: string;
    readonly username: string;
}
export interface HdinsightStormClusterMetastores {
    /**
     * ambari block.
     */
    readonly ambari?: HdinsightStormClusterMetastoresAmbari[];
    /**
     * hive block.
     */
    readonly hive?: HdinsightStormClusterMetastoresHive[];
    /**
     * oozie block.
     */
    readonly oozie?: HdinsightStormClusterMetastoresOozie[];
}
export interface HdinsightStormClusterMonitor {
    readonly logAnalyticsWorkspaceId: string;
    readonly primaryKey: string;
}
export interface HdinsightStormClusterRolesHeadNode {
    readonly password?: string;
    readonly sshKeys?: string[];
    readonly subnetId?: string;
    readonly username: string;
    readonly virtualNetworkId?: string;
    readonly vmSize: string;
}
export interface HdinsightStormClusterRolesWorkerNode {
    readonly minInstanceCount?: number;
    readonly password?: string;
    readonly sshKeys?: string[];
    readonly subnetId?: string;
    readonly targetInstanceCount: number;
    readonly username: string;
    readonly virtualNetworkId?: string;
    readonly vmSize: string;
}
export interface HdinsightStormClusterRolesZookeeperNode {
    readonly password?: string;
    readonly sshKeys?: string[];
    readonly subnetId?: string;
    readonly username: string;
    readonly virtualNetworkId?: string;
    readonly vmSize: string;
}
export interface HdinsightStormClusterRoles {
    /**
     * head_node block.
     */
    readonly headNode: HdinsightStormClusterRolesHeadNode[];
    /**
     * worker_node block.
     */
    readonly workerNode: HdinsightStormClusterRolesWorkerNode[];
    /**
     * zookeeper_node block.
     */
    readonly zookeeperNode: HdinsightStormClusterRolesZookeeperNode[];
}
export interface HdinsightStormClusterStorageAccount {
    readonly isDefault: boolean;
    readonly storageAccountKey: string;
    readonly storageContainerId: string;
}
export interface HdinsightStormClusterTimeouts {
    readonly create?: string;
    readonly delete?: string;
    readonly read?: string;
    readonly update?: string;
}
export declare class HdinsightStormCluster extends cdktf.TerraformResource {
    constructor(scope: Construct, id: string, config: HdinsightStormClusterConfig);
    private _clusterVersion;
    get clusterVersion(): string;
    set clusterVersion(value: string);
    get clusterVersionInput(): string;
    get httpsEndpoint(): string;
    get id(): string;
    private _location;
    get location(): string;
    set location(value: string);
    get locationInput(): string;
    private _name;
    get name(): string;
    set name(value: string);
    get nameInput(): string;
    private _resourceGroupName;
    get resourceGroupName(): string;
    set resourceGroupName(value: string);
    get resourceGroupNameInput(): string;
    get sshEndpoint(): string;
    private _tags?;
    get tags(): {
        [key: string]: string;
    };
    set tags(value: {
        [key: string]: string;
    });
    resetTags(): void;
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _tier;
    get tier(): string;
    set tier(value: string);
    get tierInput(): string;
    private _tlsMinVersion?;
    get tlsMinVersion(): string;
    set tlsMinVersion(value: string);
    resetTlsMinVersion(): void;
    get tlsMinVersionInput(): string | undefined;
    private _componentVersion;
    get componentVersion(): HdinsightStormClusterComponentVersion[];
    set componentVersion(value: HdinsightStormClusterComponentVersion[]);
    get componentVersionInput(): HdinsightStormClusterComponentVersion[];
    private _gateway;
    get gateway(): HdinsightStormClusterGateway[];
    set gateway(value: HdinsightStormClusterGateway[]);
    get gatewayInput(): HdinsightStormClusterGateway[];
    private _metastores?;
    get metastores(): HdinsightStormClusterMetastores[];
    set metastores(value: HdinsightStormClusterMetastores[]);
    resetMetastores(): void;
    get metastoresInput(): HdinsightStormClusterMetastores[] | undefined;
    private _monitor?;
    get monitor(): HdinsightStormClusterMonitor[];
    set monitor(value: HdinsightStormClusterMonitor[]);
    resetMonitor(): void;
    get monitorInput(): HdinsightStormClusterMonitor[] | undefined;
    private _roles;
    get roles(): HdinsightStormClusterRoles[];
    set roles(value: HdinsightStormClusterRoles[]);
    get rolesInput(): HdinsightStormClusterRoles[];
    private _storageAccount?;
    get storageAccount(): HdinsightStormClusterStorageAccount[];
    set storageAccount(value: HdinsightStormClusterStorageAccount[]);
    resetStorageAccount(): void;
    get storageAccountInput(): HdinsightStormClusterStorageAccount[] | undefined;
    private _timeouts?;
    get timeouts(): HdinsightStormClusterTimeouts;
    set timeouts(value: HdinsightStormClusterTimeouts);
    resetTimeouts(): void;
    get timeoutsInput(): HdinsightStormClusterTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
