import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface IothubConfig extends cdktf.TerraformMetaArguments {
    readonly endpoint?: IothubEndpoint[];
    readonly eventHubPartitionCount?: number;
    readonly eventHubRetentionInDays?: number;
    readonly location: string;
    readonly minTlsVersion?: string;
    readonly name: string;
    readonly publicNetworkAccessEnabled?: boolean;
    readonly resourceGroupName: string;
    readonly route?: IothubRoute[];
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * fallback_route block.
     */
    readonly fallbackRoute?: IothubFallbackRoute[];
    /**
     * file_upload block.
     */
    readonly fileUpload?: IothubFileUpload[];
    /**
     * ip_filter_rule block.
     */
    readonly ipFilterRule?: IothubIpFilterRule[];
    /**
     * sku block.
     */
    readonly sku: IothubSku[];
    /**
     * timeouts block.
     */
    readonly timeouts?: IothubTimeouts;
}
export interface IothubEndpoint {
    readonly batchFrequencyInSeconds?: number;
    readonly connectionString?: string;
    readonly containerName?: string;
    readonly encoding?: string;
    readonly fileNameFormat?: string;
    readonly maxChunkSizeInBytes?: number;
    readonly name?: string;
    readonly resourceGroupName?: string;
    readonly type?: string;
}
export interface IothubRoute {
    readonly condition?: string;
    readonly enabled?: boolean;
    readonly endpointNames?: string[];
    readonly name?: string;
    readonly source?: string;
}
export declare class IothubSharedAccessPolicy extends cdktf.ComplexComputedList {
    get keyName(): string;
    get permissions(): string;
    get primaryKey(): string;
    get secondaryKey(): string;
}
export interface IothubFallbackRoute {
    readonly condition?: string;
    readonly enabled?: boolean;
    readonly endpointNames?: string[];
    readonly source?: string;
}
export interface IothubFileUpload {
    readonly connectionString: string;
    readonly containerName: string;
    readonly defaultTtl?: string;
    readonly lockDuration?: string;
    readonly maxDeliveryCount?: number;
    readonly notifications?: boolean;
    readonly sasTtl?: string;
}
export interface IothubIpFilterRule {
    readonly action: string;
    readonly ipMask: string;
    readonly name: string;
}
export interface IothubSku {
    readonly capacity: number;
    readonly name: string;
}
export interface IothubTimeouts {
    readonly create?: string;
    readonly delete?: string;
    readonly read?: string;
    readonly update?: string;
}
export declare class Iothub extends cdktf.TerraformResource {
    constructor(scope: Construct, id: string, config: IothubConfig);
    private _endpoint?;
    get endpoint(): IothubEndpoint[];
    set endpoint(value: IothubEndpoint[]);
    resetEndpoint(): void;
    get endpointInput(): IothubEndpoint[] | undefined;
    get eventHubEventsEndpoint(): string;
    get eventHubEventsPath(): string;
    get eventHubOperationsEndpoint(): string;
    get eventHubOperationsPath(): string;
    private _eventHubPartitionCount?;
    get eventHubPartitionCount(): number;
    set eventHubPartitionCount(value: number);
    resetEventHubPartitionCount(): void;
    get eventHubPartitionCountInput(): number | undefined;
    private _eventHubRetentionInDays?;
    get eventHubRetentionInDays(): number;
    set eventHubRetentionInDays(value: number);
    resetEventHubRetentionInDays(): void;
    get eventHubRetentionInDaysInput(): number | undefined;
    get hostname(): string;
    get id(): string;
    private _location;
    get location(): string;
    set location(value: string);
    get locationInput(): string;
    private _minTlsVersion?;
    get minTlsVersion(): string;
    set minTlsVersion(value: string);
    resetMinTlsVersion(): void;
    get minTlsVersionInput(): string | undefined;
    private _name;
    get name(): string;
    set name(value: string);
    get nameInput(): string;
    private _publicNetworkAccessEnabled?;
    get publicNetworkAccessEnabled(): boolean;
    set publicNetworkAccessEnabled(value: boolean);
    resetPublicNetworkAccessEnabled(): void;
    get publicNetworkAccessEnabledInput(): boolean | undefined;
    private _resourceGroupName;
    get resourceGroupName(): string;
    set resourceGroupName(value: string);
    get resourceGroupNameInput(): string;
    private _route?;
    get route(): IothubRoute[];
    set route(value: IothubRoute[]);
    resetRoute(): void;
    get routeInput(): IothubRoute[] | undefined;
    sharedAccessPolicy(index: string): IothubSharedAccessPolicy;
    private _tags?;
    get tags(): {
        [key: string]: string;
    };
    set tags(value: {
        [key: string]: string;
    });
    resetTags(): void;
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    get type(): string;
    private _fallbackRoute?;
    get fallbackRoute(): IothubFallbackRoute[];
    set fallbackRoute(value: IothubFallbackRoute[]);
    resetFallbackRoute(): void;
    get fallbackRouteInput(): IothubFallbackRoute[] | undefined;
    private _fileUpload?;
    get fileUpload(): IothubFileUpload[];
    set fileUpload(value: IothubFileUpload[]);
    resetFileUpload(): void;
    get fileUploadInput(): IothubFileUpload[] | undefined;
    private _ipFilterRule?;
    get ipFilterRule(): IothubIpFilterRule[];
    set ipFilterRule(value: IothubIpFilterRule[]);
    resetIpFilterRule(): void;
    get ipFilterRuleInput(): IothubIpFilterRule[] | undefined;
    private _sku;
    get sku(): IothubSku[];
    set sku(value: IothubSku[]);
    get skuInput(): IothubSku[];
    private _timeouts?;
    get timeouts(): IothubTimeouts;
    set timeouts(value: IothubTimeouts);
    resetTimeouts(): void;
    get timeoutsInput(): IothubTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
