import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface KeyVaultConfig extends cdktf.TerraformMetaArguments {
    readonly accessPolicy?: KeyVaultAccessPolicy[];
    readonly enableRbacAuthorization?: boolean;
    readonly enabledForDeployment?: boolean;
    readonly enabledForDiskEncryption?: boolean;
    readonly enabledForTemplateDeployment?: boolean;
    readonly location: string;
    readonly name: string;
    readonly purgeProtectionEnabled?: boolean;
    readonly resourceGroupName: string;
    readonly skuName: string;
    readonly softDeleteEnabled?: boolean;
    readonly softDeleteRetentionDays?: number;
    readonly tags?: {
        [key: string]: string;
    };
    readonly tenantId: string;
    /**
     * contact block.
     */
    readonly contact?: KeyVaultContact[];
    /**
     * network_acls block.
     */
    readonly networkAcls?: KeyVaultNetworkAcls[];
    /**
     * timeouts block.
     */
    readonly timeouts?: KeyVaultTimeouts;
}
export interface KeyVaultAccessPolicy {
    readonly applicationId?: string;
    readonly certificatePermissions?: string[];
    readonly keyPermissions?: string[];
    readonly objectId?: string;
    readonly secretPermissions?: string[];
    readonly storagePermissions?: string[];
    readonly tenantId?: string;
}
export interface KeyVaultContact {
    readonly email: string;
    readonly name?: string;
    readonly phone?: string;
}
export interface KeyVaultNetworkAcls {
    readonly bypass: string;
    readonly defaultAction: string;
    readonly ipRules?: string[];
    readonly virtualNetworkSubnetIds?: string[];
}
export interface KeyVaultTimeouts {
    readonly create?: string;
    readonly delete?: string;
    readonly read?: string;
    readonly update?: string;
}
export declare class KeyVault extends cdktf.TerraformResource {
    constructor(scope: Construct, id: string, config: KeyVaultConfig);
    private _accessPolicy?;
    get accessPolicy(): KeyVaultAccessPolicy[];
    set accessPolicy(value: KeyVaultAccessPolicy[]);
    resetAccessPolicy(): void;
    get accessPolicyInput(): KeyVaultAccessPolicy[] | undefined;
    private _enableRbacAuthorization?;
    get enableRbacAuthorization(): boolean;
    set enableRbacAuthorization(value: boolean);
    resetEnableRbacAuthorization(): void;
    get enableRbacAuthorizationInput(): boolean | undefined;
    private _enabledForDeployment?;
    get enabledForDeployment(): boolean;
    set enabledForDeployment(value: boolean);
    resetEnabledForDeployment(): void;
    get enabledForDeploymentInput(): boolean | undefined;
    private _enabledForDiskEncryption?;
    get enabledForDiskEncryption(): boolean;
    set enabledForDiskEncryption(value: boolean);
    resetEnabledForDiskEncryption(): void;
    get enabledForDiskEncryptionInput(): boolean | undefined;
    private _enabledForTemplateDeployment?;
    get enabledForTemplateDeployment(): boolean;
    set enabledForTemplateDeployment(value: boolean);
    resetEnabledForTemplateDeployment(): void;
    get enabledForTemplateDeploymentInput(): boolean | undefined;
    get id(): string;
    private _location;
    get location(): string;
    set location(value: string);
    get locationInput(): string;
    private _name;
    get name(): string;
    set name(value: string);
    get nameInput(): string;
    private _purgeProtectionEnabled?;
    get purgeProtectionEnabled(): boolean;
    set purgeProtectionEnabled(value: boolean);
    resetPurgeProtectionEnabled(): void;
    get purgeProtectionEnabledInput(): boolean | undefined;
    private _resourceGroupName;
    get resourceGroupName(): string;
    set resourceGroupName(value: string);
    get resourceGroupNameInput(): string;
    private _skuName;
    get skuName(): string;
    set skuName(value: string);
    get skuNameInput(): string;
    private _softDeleteEnabled?;
    get softDeleteEnabled(): boolean;
    set softDeleteEnabled(value: boolean);
    resetSoftDeleteEnabled(): void;
    get softDeleteEnabledInput(): boolean | undefined;
    private _softDeleteRetentionDays?;
    get softDeleteRetentionDays(): number;
    set softDeleteRetentionDays(value: number);
    resetSoftDeleteRetentionDays(): void;
    get softDeleteRetentionDaysInput(): number | undefined;
    private _tags?;
    get tags(): {
        [key: string]: string;
    };
    set tags(value: {
        [key: string]: string;
    });
    resetTags(): void;
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _tenantId;
    get tenantId(): string;
    set tenantId(value: string);
    get tenantIdInput(): string;
    get vaultUri(): string;
    private _contact?;
    get contact(): KeyVaultContact[];
    set contact(value: KeyVaultContact[]);
    resetContact(): void;
    get contactInput(): KeyVaultContact[] | undefined;
    private _networkAcls?;
    get networkAcls(): KeyVaultNetworkAcls[];
    set networkAcls(value: KeyVaultNetworkAcls[]);
    resetNetworkAcls(): void;
    get networkAclsInput(): KeyVaultNetworkAcls[] | undefined;
    private _timeouts?;
    get timeouts(): KeyVaultTimeouts;
    set timeouts(value: KeyVaultTimeouts);
    resetTimeouts(): void;
    get timeoutsInput(): KeyVaultTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
