import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface KubernetesClusterConfig extends cdktf.TerraformMetaArguments {
    readonly apiServerAuthorizedIpRanges?: string[];
    readonly diskEncryptionSetId?: string;
    readonly dnsPrefix: string;
    readonly enablePodSecurityPolicy?: boolean;
    readonly kubernetesVersion?: string;
    readonly location: string;
    readonly name: string;
    readonly nodeResourceGroup?: string;
    readonly privateClusterEnabled?: boolean;
    readonly privateLinkEnabled?: boolean;
    readonly resourceGroupName: string;
    readonly skuTier?: string;
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * addon_profile block.
     */
    readonly addonProfile?: KubernetesClusterAddonProfile[];
    /**
     * auto_scaler_profile block.
     */
    readonly autoScalerProfile?: KubernetesClusterAutoScalerProfile[];
    /**
     * default_node_pool block.
     */
    readonly defaultNodePool: KubernetesClusterDefaultNodePool[];
    /**
     * identity block.
     */
    readonly identity?: KubernetesClusterIdentity[];
    /**
     * linux_profile block.
     */
    readonly linuxProfile?: KubernetesClusterLinuxProfile[];
    /**
     * network_profile block.
     */
    readonly networkProfile?: KubernetesClusterNetworkProfile[];
    /**
     * role_based_access_control block.
     */
    readonly roleBasedAccessControl?: KubernetesClusterRoleBasedAccessControl[];
    /**
     * service_principal block.
     */
    readonly servicePrincipal?: KubernetesClusterServicePrincipal[];
    /**
     * timeouts block.
     */
    readonly timeouts?: KubernetesClusterTimeouts;
    /**
     * windows_profile block.
     */
    readonly windowsProfile?: KubernetesClusterWindowsProfile[];
}
export declare class KubernetesClusterKubeAdminConfig extends cdktf.ComplexComputedList {
    get clientCertificate(): string;
    get clientKey(): string;
    get clusterCaCertificate(): string;
    get host(): string;
    get password(): string;
    get username(): string;
}
export declare class KubernetesClusterKubeConfig extends cdktf.ComplexComputedList {
    get clientCertificate(): string;
    get clientKey(): string;
    get clusterCaCertificate(): string;
    get host(): string;
    get password(): string;
    get username(): string;
}
export declare class KubernetesClusterKubeletIdentity extends cdktf.ComplexComputedList {
    get clientId(): string;
    get objectId(): string;
    get userAssignedIdentityId(): string;
}
export interface KubernetesClusterAddonProfileAciConnectorLinux {
    readonly enabled: boolean;
    readonly subnetName?: string;
}
export interface KubernetesClusterAddonProfileAzurePolicy {
    readonly enabled: boolean;
}
export interface KubernetesClusterAddonProfileHttpApplicationRouting {
    readonly enabled: boolean;
}
export interface KubernetesClusterAddonProfileKubeDashboard {
    readonly enabled: boolean;
}
export interface KubernetesClusterAddonProfileOmsAgent {
    readonly enabled: boolean;
    readonly logAnalyticsWorkspaceId?: string;
}
export interface KubernetesClusterAddonProfile {
    /**
     * aci_connector_linux block.
     */
    readonly aciConnectorLinux?: KubernetesClusterAddonProfileAciConnectorLinux[];
    /**
     * azure_policy block.
     */
    readonly azurePolicy?: KubernetesClusterAddonProfileAzurePolicy[];
    /**
     * http_application_routing block.
     */
    readonly httpApplicationRouting?: KubernetesClusterAddonProfileHttpApplicationRouting[];
    /**
     * kube_dashboard block.
     */
    readonly kubeDashboard?: KubernetesClusterAddonProfileKubeDashboard[];
    /**
     * oms_agent block.
     */
    readonly omsAgent?: KubernetesClusterAddonProfileOmsAgent[];
}
export interface KubernetesClusterAutoScalerProfile {
    readonly balanceSimilarNodeGroups?: boolean;
    readonly maxGracefulTerminationSec?: string;
    readonly scaleDownDelayAfterAdd?: string;
    readonly scaleDownDelayAfterDelete?: string;
    readonly scaleDownDelayAfterFailure?: string;
    readonly scaleDownUnneeded?: string;
    readonly scaleDownUnready?: string;
    readonly scaleDownUtilizationThreshold?: string;
    readonly scanInterval?: string;
}
export interface KubernetesClusterDefaultNodePool {
    readonly availabilityZones?: string[];
    readonly enableAutoScaling?: boolean;
    readonly enableNodePublicIp?: boolean;
    readonly maxCount?: number;
    readonly maxPods?: number;
    readonly minCount?: number;
    readonly name: string;
    readonly nodeCount?: number;
    readonly nodeLabels?: {
        [key: string]: string;
    };
    readonly nodeTaints?: string[];
    readonly orchestratorVersion?: string;
    readonly osDiskSizeGb?: number;
    readonly osDiskType?: string;
    readonly proximityPlacementGroupId?: string;
    readonly tags?: {
        [key: string]: string;
    };
    readonly type?: string;
    readonly vmSize: string;
    readonly vnetSubnetId?: string;
}
export interface KubernetesClusterIdentity {
    readonly type: string;
}
export interface KubernetesClusterLinuxProfileSshKey {
    readonly keyData: string;
}
export interface KubernetesClusterLinuxProfile {
    readonly adminUsername: string;
    /**
     * ssh_key block.
     */
    readonly sshKey: KubernetesClusterLinuxProfileSshKey[];
}
export interface KubernetesClusterNetworkProfileLoadBalancerProfile {
    readonly idleTimeoutInMinutes?: number;
    readonly managedOutboundIpCount?: number;
    readonly outboundIpAddressIds?: string[];
    readonly outboundIpPrefixIds?: string[];
    readonly outboundPortsAllocated?: number;
}
export interface KubernetesClusterNetworkProfile {
    readonly dnsServiceIp?: string;
    readonly dockerBridgeCidr?: string;
    readonly loadBalancerSku?: string;
    readonly networkPlugin: string;
    readonly networkPolicy?: string;
    readonly outboundType?: string;
    readonly podCidr?: string;
    readonly serviceCidr?: string;
    /**
     * load_balancer_profile block.
     */
    readonly loadBalancerProfile?: KubernetesClusterNetworkProfileLoadBalancerProfile[];
}
export interface KubernetesClusterRoleBasedAccessControlAzureActiveDirectory {
    readonly adminGroupObjectIds?: string[];
    readonly clientAppId?: string;
    readonly managed?: boolean;
    readonly serverAppId?: string;
    readonly serverAppSecret?: string;
    readonly tenantId?: string;
}
export interface KubernetesClusterRoleBasedAccessControl {
    readonly enabled: boolean;
    /**
     * azure_active_directory block.
     */
    readonly azureActiveDirectory?: KubernetesClusterRoleBasedAccessControlAzureActiveDirectory[];
}
export interface KubernetesClusterServicePrincipal {
    readonly clientId: string;
    readonly clientSecret: string;
}
export interface KubernetesClusterTimeouts {
    readonly create?: string;
    readonly delete?: string;
    readonly read?: string;
    readonly update?: string;
}
export interface KubernetesClusterWindowsProfile {
    readonly adminPassword?: string;
    readonly adminUsername: string;
}
export declare class KubernetesCluster extends cdktf.TerraformResource {
    constructor(scope: Construct, id: string, config: KubernetesClusterConfig);
    private _apiServerAuthorizedIpRanges?;
    get apiServerAuthorizedIpRanges(): string[];
    set apiServerAuthorizedIpRanges(value: string[]);
    resetApiServerAuthorizedIpRanges(): void;
    get apiServerAuthorizedIpRangesInput(): string[] | undefined;
    private _diskEncryptionSetId?;
    get diskEncryptionSetId(): string;
    set diskEncryptionSetId(value: string);
    resetDiskEncryptionSetId(): void;
    get diskEncryptionSetIdInput(): string | undefined;
    private _dnsPrefix;
    get dnsPrefix(): string;
    set dnsPrefix(value: string);
    get dnsPrefixInput(): string;
    private _enablePodSecurityPolicy?;
    get enablePodSecurityPolicy(): boolean;
    set enablePodSecurityPolicy(value: boolean);
    resetEnablePodSecurityPolicy(): void;
    get enablePodSecurityPolicyInput(): boolean | undefined;
    get fqdn(): string;
    get id(): string;
    kubeAdminConfig(index: string): KubernetesClusterKubeAdminConfig;
    get kubeAdminConfigRaw(): string;
    kubeConfig(index: string): KubernetesClusterKubeConfig;
    get kubeConfigRaw(): string;
    kubeletIdentity(index: string): KubernetesClusterKubeletIdentity;
    private _kubernetesVersion?;
    get kubernetesVersion(): string;
    set kubernetesVersion(value: string);
    resetKubernetesVersion(): void;
    get kubernetesVersionInput(): string | undefined;
    private _location;
    get location(): string;
    set location(value: string);
    get locationInput(): string;
    private _name;
    get name(): string;
    set name(value: string);
    get nameInput(): string;
    private _nodeResourceGroup?;
    get nodeResourceGroup(): string;
    set nodeResourceGroup(value: string);
    resetNodeResourceGroup(): void;
    get nodeResourceGroupInput(): string | undefined;
    private _privateClusterEnabled?;
    get privateClusterEnabled(): boolean;
    set privateClusterEnabled(value: boolean);
    resetPrivateClusterEnabled(): void;
    get privateClusterEnabledInput(): boolean | undefined;
    get privateFqdn(): string;
    private _privateLinkEnabled?;
    get privateLinkEnabled(): boolean;
    set privateLinkEnabled(value: boolean);
    resetPrivateLinkEnabled(): void;
    get privateLinkEnabledInput(): boolean | undefined;
    private _resourceGroupName;
    get resourceGroupName(): string;
    set resourceGroupName(value: string);
    get resourceGroupNameInput(): string;
    private _skuTier?;
    get skuTier(): string;
    set skuTier(value: string);
    resetSkuTier(): void;
    get skuTierInput(): string | undefined;
    private _tags?;
    get tags(): {
        [key: string]: string;
    };
    set tags(value: {
        [key: string]: string;
    });
    resetTags(): void;
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _addonProfile?;
    get addonProfile(): KubernetesClusterAddonProfile[];
    set addonProfile(value: KubernetesClusterAddonProfile[]);
    resetAddonProfile(): void;
    get addonProfileInput(): KubernetesClusterAddonProfile[] | undefined;
    private _autoScalerProfile?;
    get autoScalerProfile(): KubernetesClusterAutoScalerProfile[];
    set autoScalerProfile(value: KubernetesClusterAutoScalerProfile[]);
    resetAutoScalerProfile(): void;
    get autoScalerProfileInput(): KubernetesClusterAutoScalerProfile[] | undefined;
    private _defaultNodePool;
    get defaultNodePool(): KubernetesClusterDefaultNodePool[];
    set defaultNodePool(value: KubernetesClusterDefaultNodePool[]);
    get defaultNodePoolInput(): KubernetesClusterDefaultNodePool[];
    private _identity?;
    get identity(): KubernetesClusterIdentity[];
    set identity(value: KubernetesClusterIdentity[]);
    resetIdentity(): void;
    get identityInput(): KubernetesClusterIdentity[] | undefined;
    private _linuxProfile?;
    get linuxProfile(): KubernetesClusterLinuxProfile[];
    set linuxProfile(value: KubernetesClusterLinuxProfile[]);
    resetLinuxProfile(): void;
    get linuxProfileInput(): KubernetesClusterLinuxProfile[] | undefined;
    private _networkProfile?;
    get networkProfile(): KubernetesClusterNetworkProfile[];
    set networkProfile(value: KubernetesClusterNetworkProfile[]);
    resetNetworkProfile(): void;
    get networkProfileInput(): KubernetesClusterNetworkProfile[] | undefined;
    private _roleBasedAccessControl?;
    get roleBasedAccessControl(): KubernetesClusterRoleBasedAccessControl[];
    set roleBasedAccessControl(value: KubernetesClusterRoleBasedAccessControl[]);
    resetRoleBasedAccessControl(): void;
    get roleBasedAccessControlInput(): KubernetesClusterRoleBasedAccessControl[] | undefined;
    private _servicePrincipal?;
    get servicePrincipal(): KubernetesClusterServicePrincipal[];
    set servicePrincipal(value: KubernetesClusterServicePrincipal[]);
    resetServicePrincipal(): void;
    get servicePrincipalInput(): KubernetesClusterServicePrincipal[] | undefined;
    private _timeouts?;
    get timeouts(): KubernetesClusterTimeouts;
    set timeouts(value: KubernetesClusterTimeouts);
    resetTimeouts(): void;
    get timeoutsInput(): KubernetesClusterTimeouts | undefined;
    private _windowsProfile?;
    get windowsProfile(): KubernetesClusterWindowsProfile[];
    set windowsProfile(value: KubernetesClusterWindowsProfile[]);
    resetWindowsProfile(): void;
    get windowsProfileInput(): KubernetesClusterWindowsProfile[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
