import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface KustoClusterConfig extends cdktf.TerraformMetaArguments {
    readonly enableDiskEncryption?: boolean;
    readonly enablePurge?: boolean;
    readonly enableStreamingIngest?: boolean;
    readonly engine?: string;
    readonly languageExtensions?: string[];
    readonly location: string;
    readonly name: string;
    readonly resourceGroupName: string;
    readonly tags?: {
        [key: string]: string;
    };
    readonly trustedExternalTenants?: string[];
    readonly zones?: string[];
    /**
     * identity block.
     */
    readonly identity?: KustoClusterIdentity[];
    /**
     * optimized_auto_scale block.
     */
    readonly optimizedAutoScale?: KustoClusterOptimizedAutoScale[];
    /**
     * sku block.
     */
    readonly sku: KustoClusterSku[];
    /**
     * timeouts block.
     */
    readonly timeouts?: KustoClusterTimeouts;
    /**
     * virtual_network_configuration block.
     */
    readonly virtualNetworkConfiguration?: KustoClusterVirtualNetworkConfiguration[];
}
export interface KustoClusterIdentity {
    readonly type: string;
}
export interface KustoClusterOptimizedAutoScale {
    readonly maximumInstances: number;
    readonly minimumInstances: number;
}
export interface KustoClusterSku {
    readonly capacity?: number;
    readonly name: string;
}
export interface KustoClusterTimeouts {
    readonly create?: string;
    readonly delete?: string;
    readonly read?: string;
    readonly update?: string;
}
export interface KustoClusterVirtualNetworkConfiguration {
    readonly dataManagementPublicIpId: string;
    readonly enginePublicIpId: string;
    readonly subnetId: string;
}
export declare class KustoCluster extends cdktf.TerraformResource {
    constructor(scope: Construct, id: string, config: KustoClusterConfig);
    get dataIngestionUri(): string;
    private _enableDiskEncryption?;
    get enableDiskEncryption(): boolean;
    set enableDiskEncryption(value: boolean);
    resetEnableDiskEncryption(): void;
    get enableDiskEncryptionInput(): boolean | undefined;
    private _enablePurge?;
    get enablePurge(): boolean;
    set enablePurge(value: boolean);
    resetEnablePurge(): void;
    get enablePurgeInput(): boolean | undefined;
    private _enableStreamingIngest?;
    get enableStreamingIngest(): boolean;
    set enableStreamingIngest(value: boolean);
    resetEnableStreamingIngest(): void;
    get enableStreamingIngestInput(): boolean | undefined;
    private _engine?;
    get engine(): string;
    set engine(value: string);
    resetEngine(): void;
    get engineInput(): string | undefined;
    get id(): string;
    private _languageExtensions?;
    get languageExtensions(): string[];
    set languageExtensions(value: string[]);
    resetLanguageExtensions(): void;
    get languageExtensionsInput(): string[] | undefined;
    private _location;
    get location(): string;
    set location(value: string);
    get locationInput(): string;
    private _name;
    get name(): string;
    set name(value: string);
    get nameInput(): string;
    private _resourceGroupName;
    get resourceGroupName(): string;
    set resourceGroupName(value: string);
    get resourceGroupNameInput(): string;
    private _tags?;
    get tags(): {
        [key: string]: string;
    };
    set tags(value: {
        [key: string]: string;
    });
    resetTags(): void;
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _trustedExternalTenants?;
    get trustedExternalTenants(): string[];
    set trustedExternalTenants(value: string[]);
    resetTrustedExternalTenants(): void;
    get trustedExternalTenantsInput(): string[] | undefined;
    get uri(): string;
    private _zones?;
    get zones(): string[];
    set zones(value: string[]);
    resetZones(): void;
    get zonesInput(): string[] | undefined;
    private _identity?;
    get identity(): KustoClusterIdentity[];
    set identity(value: KustoClusterIdentity[]);
    resetIdentity(): void;
    get identityInput(): KustoClusterIdentity[] | undefined;
    private _optimizedAutoScale?;
    get optimizedAutoScale(): KustoClusterOptimizedAutoScale[];
    set optimizedAutoScale(value: KustoClusterOptimizedAutoScale[]);
    resetOptimizedAutoScale(): void;
    get optimizedAutoScaleInput(): KustoClusterOptimizedAutoScale[] | undefined;
    private _sku;
    get sku(): KustoClusterSku[];
    set sku(value: KustoClusterSku[]);
    get skuInput(): KustoClusterSku[];
    private _timeouts?;
    get timeouts(): KustoClusterTimeouts;
    set timeouts(value: KustoClusterTimeouts);
    resetTimeouts(): void;
    get timeoutsInput(): KustoClusterTimeouts | undefined;
    private _virtualNetworkConfiguration?;
    get virtualNetworkConfiguration(): KustoClusterVirtualNetworkConfiguration[];
    set virtualNetworkConfiguration(value: KustoClusterVirtualNetworkConfiguration[]);
    resetVirtualNetworkConfiguration(): void;
    get virtualNetworkConfigurationInput(): KustoClusterVirtualNetworkConfiguration[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
