import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface LinuxVirtualMachineConfig extends cdktf.TerraformMetaArguments {
    readonly adminPassword?: string;
    readonly adminUsername: string;
    readonly allowExtensionOperations?: boolean;
    readonly availabilitySetId?: string;
    readonly computerName?: string;
    readonly customData?: string;
    readonly dedicatedHostId?: string;
    readonly disablePasswordAuthentication?: boolean;
    readonly encryptionAtHostEnabled?: boolean;
    readonly evictionPolicy?: string;
    readonly extensionsTimeBudget?: string;
    readonly location: string;
    readonly maxBidPrice?: number;
    readonly name: string;
    readonly networkInterfaceIds: string[];
    readonly priority?: string;
    readonly provisionVmAgent?: boolean;
    readonly proximityPlacementGroupId?: string;
    readonly resourceGroupName: string;
    readonly size: string;
    readonly sourceImageId?: string;
    readonly tags?: {
        [key: string]: string;
    };
    readonly virtualMachineScaleSetId?: string;
    readonly zone?: string;
    /**
     * additional_capabilities block.
     */
    readonly additionalCapabilities?: LinuxVirtualMachineAdditionalCapabilities[];
    /**
     * admin_ssh_key block.
     */
    readonly adminSshKey?: LinuxVirtualMachineAdminSshKey[];
    /**
     * boot_diagnostics block.
     */
    readonly bootDiagnostics?: LinuxVirtualMachineBootDiagnostics[];
    /**
     * identity block.
     */
    readonly identity?: LinuxVirtualMachineIdentity[];
    /**
     * os_disk block.
     */
    readonly osDisk: LinuxVirtualMachineOsDisk[];
    /**
     * plan block.
     */
    readonly plan?: LinuxVirtualMachinePlan[];
    /**
     * secret block.
     */
    readonly secret?: LinuxVirtualMachineSecret[];
    /**
     * source_image_reference block.
     */
    readonly sourceImageReference?: LinuxVirtualMachineSourceImageReference[];
    /**
     * timeouts block.
     */
    readonly timeouts?: LinuxVirtualMachineTimeouts;
}
export interface LinuxVirtualMachineAdditionalCapabilities {
    readonly ultraSsdEnabled?: boolean;
}
export interface LinuxVirtualMachineAdminSshKey {
    readonly publicKey: string;
    readonly username: string;
}
export interface LinuxVirtualMachineBootDiagnostics {
    readonly storageAccountUri?: string;
}
export interface LinuxVirtualMachineIdentity {
    readonly identityIds?: string[];
    readonly type: string;
}
export interface LinuxVirtualMachineOsDiskDiffDiskSettings {
    readonly option: string;
}
export interface LinuxVirtualMachineOsDisk {
    readonly caching: string;
    readonly diskEncryptionSetId?: string;
    readonly diskSizeGb?: number;
    readonly name?: string;
    readonly storageAccountType: string;
    readonly writeAcceleratorEnabled?: boolean;
    /**
     * diff_disk_settings block.
     */
    readonly diffDiskSettings?: LinuxVirtualMachineOsDiskDiffDiskSettings[];
}
export interface LinuxVirtualMachinePlan {
    readonly name: string;
    readonly product: string;
    readonly publisher: string;
}
export interface LinuxVirtualMachineSecretCertificate {
    readonly url: string;
}
export interface LinuxVirtualMachineSecret {
    readonly keyVaultId: string;
    /**
     * certificate block.
     */
    readonly certificate: LinuxVirtualMachineSecretCertificate[];
}
export interface LinuxVirtualMachineSourceImageReference {
    readonly offer: string;
    readonly publisher: string;
    readonly sku: string;
    readonly version: string;
}
export interface LinuxVirtualMachineTimeouts {
    readonly create?: string;
    readonly delete?: string;
    readonly read?: string;
    readonly update?: string;
}
export declare class LinuxVirtualMachine extends cdktf.TerraformResource {
    constructor(scope: Construct, id: string, config: LinuxVirtualMachineConfig);
    private _adminPassword?;
    get adminPassword(): string;
    set adminPassword(value: string);
    resetAdminPassword(): void;
    get adminPasswordInput(): string | undefined;
    private _adminUsername;
    get adminUsername(): string;
    set adminUsername(value: string);
    get adminUsernameInput(): string;
    private _allowExtensionOperations?;
    get allowExtensionOperations(): boolean;
    set allowExtensionOperations(value: boolean);
    resetAllowExtensionOperations(): void;
    get allowExtensionOperationsInput(): boolean | undefined;
    private _availabilitySetId?;
    get availabilitySetId(): string;
    set availabilitySetId(value: string);
    resetAvailabilitySetId(): void;
    get availabilitySetIdInput(): string | undefined;
    private _computerName?;
    get computerName(): string;
    set computerName(value: string);
    resetComputerName(): void;
    get computerNameInput(): string | undefined;
    private _customData?;
    get customData(): string;
    set customData(value: string);
    resetCustomData(): void;
    get customDataInput(): string | undefined;
    private _dedicatedHostId?;
    get dedicatedHostId(): string;
    set dedicatedHostId(value: string);
    resetDedicatedHostId(): void;
    get dedicatedHostIdInput(): string | undefined;
    private _disablePasswordAuthentication?;
    get disablePasswordAuthentication(): boolean;
    set disablePasswordAuthentication(value: boolean);
    resetDisablePasswordAuthentication(): void;
    get disablePasswordAuthenticationInput(): boolean | undefined;
    private _encryptionAtHostEnabled?;
    get encryptionAtHostEnabled(): boolean;
    set encryptionAtHostEnabled(value: boolean);
    resetEncryptionAtHostEnabled(): void;
    get encryptionAtHostEnabledInput(): boolean | undefined;
    private _evictionPolicy?;
    get evictionPolicy(): string;
    set evictionPolicy(value: string);
    resetEvictionPolicy(): void;
    get evictionPolicyInput(): string | undefined;
    private _extensionsTimeBudget?;
    get extensionsTimeBudget(): string;
    set extensionsTimeBudget(value: string);
    resetExtensionsTimeBudget(): void;
    get extensionsTimeBudgetInput(): string | undefined;
    get id(): string;
    private _location;
    get location(): string;
    set location(value: string);
    get locationInput(): string;
    private _maxBidPrice?;
    get maxBidPrice(): number;
    set maxBidPrice(value: number);
    resetMaxBidPrice(): void;
    get maxBidPriceInput(): number | undefined;
    private _name;
    get name(): string;
    set name(value: string);
    get nameInput(): string;
    private _networkInterfaceIds;
    get networkInterfaceIds(): string[];
    set networkInterfaceIds(value: string[]);
    get networkInterfaceIdsInput(): string[];
    private _priority?;
    get priority(): string;
    set priority(value: string);
    resetPriority(): void;
    get priorityInput(): string | undefined;
    get privateIpAddress(): string;
    get privateIpAddresses(): string[];
    private _provisionVmAgent?;
    get provisionVmAgent(): boolean;
    set provisionVmAgent(value: boolean);
    resetProvisionVmAgent(): void;
    get provisionVmAgentInput(): boolean | undefined;
    private _proximityPlacementGroupId?;
    get proximityPlacementGroupId(): string;
    set proximityPlacementGroupId(value: string);
    resetProximityPlacementGroupId(): void;
    get proximityPlacementGroupIdInput(): string | undefined;
    get publicIpAddress(): string;
    get publicIpAddresses(): string[];
    private _resourceGroupName;
    get resourceGroupName(): string;
    set resourceGroupName(value: string);
    get resourceGroupNameInput(): string;
    private _size;
    get size(): string;
    set size(value: string);
    get sizeInput(): string;
    private _sourceImageId?;
    get sourceImageId(): string;
    set sourceImageId(value: string);
    resetSourceImageId(): void;
    get sourceImageIdInput(): string | undefined;
    private _tags?;
    get tags(): {
        [key: string]: string;
    };
    set tags(value: {
        [key: string]: string;
    });
    resetTags(): void;
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    get virtualMachineId(): string;
    private _virtualMachineScaleSetId?;
    get virtualMachineScaleSetId(): string;
    set virtualMachineScaleSetId(value: string);
    resetVirtualMachineScaleSetId(): void;
    get virtualMachineScaleSetIdInput(): string | undefined;
    private _zone?;
    get zone(): string;
    set zone(value: string);
    resetZone(): void;
    get zoneInput(): string | undefined;
    private _additionalCapabilities?;
    get additionalCapabilities(): LinuxVirtualMachineAdditionalCapabilities[];
    set additionalCapabilities(value: LinuxVirtualMachineAdditionalCapabilities[]);
    resetAdditionalCapabilities(): void;
    get additionalCapabilitiesInput(): LinuxVirtualMachineAdditionalCapabilities[] | undefined;
    private _adminSshKey?;
    get adminSshKey(): LinuxVirtualMachineAdminSshKey[];
    set adminSshKey(value: LinuxVirtualMachineAdminSshKey[]);
    resetAdminSshKey(): void;
    get adminSshKeyInput(): LinuxVirtualMachineAdminSshKey[] | undefined;
    private _bootDiagnostics?;
    get bootDiagnostics(): LinuxVirtualMachineBootDiagnostics[];
    set bootDiagnostics(value: LinuxVirtualMachineBootDiagnostics[]);
    resetBootDiagnostics(): void;
    get bootDiagnosticsInput(): LinuxVirtualMachineBootDiagnostics[] | undefined;
    private _identity?;
    get identity(): LinuxVirtualMachineIdentity[];
    set identity(value: LinuxVirtualMachineIdentity[]);
    resetIdentity(): void;
    get identityInput(): LinuxVirtualMachineIdentity[] | undefined;
    private _osDisk;
    get osDisk(): LinuxVirtualMachineOsDisk[];
    set osDisk(value: LinuxVirtualMachineOsDisk[]);
    get osDiskInput(): LinuxVirtualMachineOsDisk[];
    private _plan?;
    get plan(): LinuxVirtualMachinePlan[];
    set plan(value: LinuxVirtualMachinePlan[]);
    resetPlan(): void;
    get planInput(): LinuxVirtualMachinePlan[] | undefined;
    private _secret?;
    get secret(): LinuxVirtualMachineSecret[];
    set secret(value: LinuxVirtualMachineSecret[]);
    resetSecret(): void;
    get secretInput(): LinuxVirtualMachineSecret[] | undefined;
    private _sourceImageReference?;
    get sourceImageReference(): LinuxVirtualMachineSourceImageReference[];
    set sourceImageReference(value: LinuxVirtualMachineSourceImageReference[]);
    resetSourceImageReference(): void;
    get sourceImageReferenceInput(): LinuxVirtualMachineSourceImageReference[] | undefined;
    private _timeouts?;
    get timeouts(): LinuxVirtualMachineTimeouts;
    set timeouts(value: LinuxVirtualMachineTimeouts);
    resetTimeouts(): void;
    get timeoutsInput(): LinuxVirtualMachineTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
