import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface MonitorMetricAlertConfig extends cdktf.TerraformMetaArguments {
    readonly autoMitigate?: boolean;
    readonly description?: string;
    readonly enabled?: boolean;
    readonly frequency?: string;
    readonly name: string;
    readonly resourceGroupName: string;
    readonly scopes: string[];
    readonly severity?: number;
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * The location of the target resource.
     *
     * Required when using subscription, resource group scope or multiple scopes.
     */
    readonly targetResourceLocation?: string;
    /**
     * The resource type (e.g. Microsoft.Compute/virtualMachines) of the target resource. Required when using subscription, resource group scope or multiple scopes.
     */
    readonly targetResourceType?: string;
    readonly windowSize?: string;
    /**
     * action block.
     */
    readonly action?: MonitorMetricAlertAction[];
    /**
     * application_insights_web_test_location_availability_criteria block.
     */
    readonly applicationInsightsWebTestLocationAvailabilityCriteria?: MonitorMetricAlertApplicationInsightsWebTestLocationAvailabilityCriteria[];
    /**
     * criteria block.
     */
    readonly criteria?: MonitorMetricAlertCriteria[];
    /**
     * dynamic_criteria block.
     */
    readonly dynamicCriteria?: MonitorMetricAlertDynamicCriteria[];
    /**
     * timeouts block.
     */
    readonly timeouts?: MonitorMetricAlertTimeouts;
}
export interface MonitorMetricAlertAction {
    readonly actionGroupId: string;
    readonly webhookProperties?: {
        [key: string]: string;
    };
}
export interface MonitorMetricAlertApplicationInsightsWebTestLocationAvailabilityCriteria {
    readonly componentId: string;
    readonly failedLocationCount: number;
    readonly webTestId: string;
}
export interface MonitorMetricAlertCriteriaDimension {
    readonly name: string;
    readonly operator: string;
    readonly values: string[];
}
export interface MonitorMetricAlertCriteria {
    readonly aggregation: string;
    readonly metricName: string;
    readonly metricNamespace: string;
    readonly operator: string;
    readonly threshold: number;
    /**
     * dimension block.
     */
    readonly dimension?: MonitorMetricAlertCriteriaDimension[];
}
export interface MonitorMetricAlertDynamicCriteriaDimension {
    readonly name: string;
    readonly operator: string;
    readonly values: string[];
}
export interface MonitorMetricAlertDynamicCriteria {
    readonly aggregation: string;
    readonly alertSensitivity: string;
    readonly evaluationFailureCount?: number;
    readonly evaluationTotalCount?: number;
    readonly ignoreDataBefore?: string;
    readonly metricName: string;
    readonly metricNamespace: string;
    readonly operator: string;
    /**
     * dimension block.
     */
    readonly dimension?: MonitorMetricAlertDynamicCriteriaDimension[];
}
export interface MonitorMetricAlertTimeouts {
    readonly create?: string;
    readonly delete?: string;
    readonly read?: string;
    readonly update?: string;
}
export declare class MonitorMetricAlert extends cdktf.TerraformResource {
    constructor(scope: Construct, id: string, config: MonitorMetricAlertConfig);
    private _autoMitigate?;
    get autoMitigate(): boolean;
    set autoMitigate(value: boolean);
    resetAutoMitigate(): void;
    get autoMitigateInput(): boolean | undefined;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _enabled?;
    get enabled(): boolean;
    set enabled(value: boolean);
    resetEnabled(): void;
    get enabledInput(): boolean | undefined;
    private _frequency?;
    get frequency(): string;
    set frequency(value: string);
    resetFrequency(): void;
    get frequencyInput(): string | undefined;
    get id(): string;
    private _name;
    get name(): string;
    set name(value: string);
    get nameInput(): string;
    private _resourceGroupName;
    get resourceGroupName(): string;
    set resourceGroupName(value: string);
    get resourceGroupNameInput(): string;
    private _scopes;
    get scopes(): string[];
    set scopes(value: string[]);
    get scopesInput(): string[];
    private _severity?;
    get severity(): number;
    set severity(value: number);
    resetSeverity(): void;
    get severityInput(): number | undefined;
    private _tags?;
    get tags(): {
        [key: string]: string;
    };
    set tags(value: {
        [key: string]: string;
    });
    resetTags(): void;
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _targetResourceLocation?;
    get targetResourceLocation(): string;
    set targetResourceLocation(value: string);
    resetTargetResourceLocation(): void;
    get targetResourceLocationInput(): string | undefined;
    private _targetResourceType?;
    get targetResourceType(): string;
    set targetResourceType(value: string);
    resetTargetResourceType(): void;
    get targetResourceTypeInput(): string | undefined;
    private _windowSize?;
    get windowSize(): string;
    set windowSize(value: string);
    resetWindowSize(): void;
    get windowSizeInput(): string | undefined;
    private _action?;
    get action(): MonitorMetricAlertAction[];
    set action(value: MonitorMetricAlertAction[]);
    resetAction(): void;
    get actionInput(): MonitorMetricAlertAction[] | undefined;
    private _applicationInsightsWebTestLocationAvailabilityCriteria?;
    get applicationInsightsWebTestLocationAvailabilityCriteria(): MonitorMetricAlertApplicationInsightsWebTestLocationAvailabilityCriteria[];
    set applicationInsightsWebTestLocationAvailabilityCriteria(value: MonitorMetricAlertApplicationInsightsWebTestLocationAvailabilityCriteria[]);
    resetApplicationInsightsWebTestLocationAvailabilityCriteria(): void;
    get applicationInsightsWebTestLocationAvailabilityCriteriaInput(): MonitorMetricAlertApplicationInsightsWebTestLocationAvailabilityCriteria[] | undefined;
    private _criteria?;
    get criteria(): MonitorMetricAlertCriteria[];
    set criteria(value: MonitorMetricAlertCriteria[]);
    resetCriteria(): void;
    get criteriaInput(): MonitorMetricAlertCriteria[] | undefined;
    private _dynamicCriteria?;
    get dynamicCriteria(): MonitorMetricAlertDynamicCriteria[];
    set dynamicCriteria(value: MonitorMetricAlertDynamicCriteria[]);
    resetDynamicCriteria(): void;
    get dynamicCriteriaInput(): MonitorMetricAlertDynamicCriteria[] | undefined;
    private _timeouts?;
    get timeouts(): MonitorMetricAlertTimeouts;
    set timeouts(value: MonitorMetricAlertTimeouts);
    resetTimeouts(): void;
    get timeoutsInput(): MonitorMetricAlertTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
