import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface MssqlDatabaseConfig extends cdktf.TerraformMetaArguments {
    readonly autoPauseDelayInMinutes?: number;
    readonly collation?: string;
    readonly createMode?: string;
    readonly creationSourceDatabaseId?: string;
    readonly elasticPoolId?: string;
    readonly extendedAuditingPolicy?: MssqlDatabaseExtendedAuditingPolicy[];
    readonly licenseType?: string;
    readonly maxSizeGb?: number;
    readonly minCapacity?: number;
    readonly name: string;
    readonly readReplicaCount?: number;
    readonly readScale?: boolean;
    readonly recoverDatabaseId?: string;
    readonly restoreDroppedDatabaseId?: string;
    readonly restorePointInTime?: string;
    readonly sampleName?: string;
    readonly serverId: string;
    readonly skuName?: string;
    readonly tags?: {
        [key: string]: string;
    };
    readonly zoneRedundant?: boolean;
    /**
     * long_term_retention_policy block.
     */
    readonly longTermRetentionPolicy?: MssqlDatabaseLongTermRetentionPolicy[];
    /**
     * short_term_retention_policy block.
     */
    readonly shortTermRetentionPolicy?: MssqlDatabaseShortTermRetentionPolicy[];
    /**
     * threat_detection_policy block.
     */
    readonly threatDetectionPolicy?: MssqlDatabaseThreatDetectionPolicy[];
    /**
     * timeouts block.
     */
    readonly timeouts?: MssqlDatabaseTimeouts;
}
export interface MssqlDatabaseExtendedAuditingPolicy {
    readonly retentionInDays?: number;
    readonly storageAccountAccessKey?: string;
    readonly storageAccountAccessKeyIsSecondary?: boolean;
    readonly storageEndpoint?: string;
}
export interface MssqlDatabaseLongTermRetentionPolicy {
    readonly monthlyRetention?: string;
    readonly weekOfYear?: number;
    readonly weeklyRetention?: string;
    readonly yearlyRetention?: string;
}
export interface MssqlDatabaseShortTermRetentionPolicy {
    readonly retentionDays: number;
}
export interface MssqlDatabaseThreatDetectionPolicy {
    readonly disabledAlerts?: string[];
    readonly emailAccountAdmins?: string;
    readonly emailAddresses?: string[];
    readonly retentionDays?: number;
    readonly state?: string;
    readonly storageAccountAccessKey?: string;
    readonly storageEndpoint?: string;
    readonly useServerDefault?: string;
}
export interface MssqlDatabaseTimeouts {
    readonly create?: string;
    readonly delete?: string;
    readonly read?: string;
    readonly update?: string;
}
export declare class MssqlDatabase extends cdktf.TerraformResource {
    constructor(scope: Construct, id: string, config: MssqlDatabaseConfig);
    private _autoPauseDelayInMinutes?;
    get autoPauseDelayInMinutes(): number;
    set autoPauseDelayInMinutes(value: number);
    resetAutoPauseDelayInMinutes(): void;
    get autoPauseDelayInMinutesInput(): number | undefined;
    private _collation?;
    get collation(): string;
    set collation(value: string);
    resetCollation(): void;
    get collationInput(): string | undefined;
    private _createMode?;
    get createMode(): string;
    set createMode(value: string);
    resetCreateMode(): void;
    get createModeInput(): string | undefined;
    private _creationSourceDatabaseId?;
    get creationSourceDatabaseId(): string;
    set creationSourceDatabaseId(value: string);
    resetCreationSourceDatabaseId(): void;
    get creationSourceDatabaseIdInput(): string | undefined;
    private _elasticPoolId?;
    get elasticPoolId(): string;
    set elasticPoolId(value: string);
    resetElasticPoolId(): void;
    get elasticPoolIdInput(): string | undefined;
    private _extendedAuditingPolicy?;
    get extendedAuditingPolicy(): MssqlDatabaseExtendedAuditingPolicy[];
    set extendedAuditingPolicy(value: MssqlDatabaseExtendedAuditingPolicy[]);
    resetExtendedAuditingPolicy(): void;
    get extendedAuditingPolicyInput(): MssqlDatabaseExtendedAuditingPolicy[] | undefined;
    get id(): string;
    private _licenseType?;
    get licenseType(): string;
    set licenseType(value: string);
    resetLicenseType(): void;
    get licenseTypeInput(): string | undefined;
    private _maxSizeGb?;
    get maxSizeGb(): number;
    set maxSizeGb(value: number);
    resetMaxSizeGb(): void;
    get maxSizeGbInput(): number | undefined;
    private _minCapacity?;
    get minCapacity(): number;
    set minCapacity(value: number);
    resetMinCapacity(): void;
    get minCapacityInput(): number | undefined;
    private _name;
    get name(): string;
    set name(value: string);
    get nameInput(): string;
    private _readReplicaCount?;
    get readReplicaCount(): number;
    set readReplicaCount(value: number);
    resetReadReplicaCount(): void;
    get readReplicaCountInput(): number | undefined;
    private _readScale?;
    get readScale(): boolean;
    set readScale(value: boolean);
    resetReadScale(): void;
    get readScaleInput(): boolean | undefined;
    private _recoverDatabaseId?;
    get recoverDatabaseId(): string;
    set recoverDatabaseId(value: string);
    resetRecoverDatabaseId(): void;
    get recoverDatabaseIdInput(): string | undefined;
    private _restoreDroppedDatabaseId?;
    get restoreDroppedDatabaseId(): string;
    set restoreDroppedDatabaseId(value: string);
    resetRestoreDroppedDatabaseId(): void;
    get restoreDroppedDatabaseIdInput(): string | undefined;
    private _restorePointInTime?;
    get restorePointInTime(): string;
    set restorePointInTime(value: string);
    resetRestorePointInTime(): void;
    get restorePointInTimeInput(): string | undefined;
    private _sampleName?;
    get sampleName(): string;
    set sampleName(value: string);
    resetSampleName(): void;
    get sampleNameInput(): string | undefined;
    private _serverId;
    get serverId(): string;
    set serverId(value: string);
    get serverIdInput(): string;
    private _skuName?;
    get skuName(): string;
    set skuName(value: string);
    resetSkuName(): void;
    get skuNameInput(): string | undefined;
    private _tags?;
    get tags(): {
        [key: string]: string;
    };
    set tags(value: {
        [key: string]: string;
    });
    resetTags(): void;
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _zoneRedundant?;
    get zoneRedundant(): boolean;
    set zoneRedundant(value: boolean);
    resetZoneRedundant(): void;
    get zoneRedundantInput(): boolean | undefined;
    private _longTermRetentionPolicy?;
    get longTermRetentionPolicy(): MssqlDatabaseLongTermRetentionPolicy[];
    set longTermRetentionPolicy(value: MssqlDatabaseLongTermRetentionPolicy[]);
    resetLongTermRetentionPolicy(): void;
    get longTermRetentionPolicyInput(): MssqlDatabaseLongTermRetentionPolicy[] | undefined;
    private _shortTermRetentionPolicy?;
    get shortTermRetentionPolicy(): MssqlDatabaseShortTermRetentionPolicy[];
    set shortTermRetentionPolicy(value: MssqlDatabaseShortTermRetentionPolicy[]);
    resetShortTermRetentionPolicy(): void;
    get shortTermRetentionPolicyInput(): MssqlDatabaseShortTermRetentionPolicy[] | undefined;
    private _threatDetectionPolicy?;
    get threatDetectionPolicy(): MssqlDatabaseThreatDetectionPolicy[];
    set threatDetectionPolicy(value: MssqlDatabaseThreatDetectionPolicy[]);
    resetThreatDetectionPolicy(): void;
    get threatDetectionPolicyInput(): MssqlDatabaseThreatDetectionPolicy[] | undefined;
    private _timeouts?;
    get timeouts(): MssqlDatabaseTimeouts;
    set timeouts(value: MssqlDatabaseTimeouts);
    resetTimeouts(): void;
    get timeoutsInput(): MssqlDatabaseTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
