import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface MssqlVirtualMachineConfig extends cdktf.TerraformMetaArguments {
    readonly rServicesEnabled?: boolean;
    readonly sqlConnectivityPort?: number;
    readonly sqlConnectivityType?: string;
    readonly sqlConnectivityUpdatePassword?: string;
    readonly sqlConnectivityUpdateUsername?: string;
    readonly sqlLicenseType: string;
    readonly tags?: {
        [key: string]: string;
    };
    readonly virtualMachineId: string;
    /**
     * auto_patching block.
     */
    readonly autoPatching?: MssqlVirtualMachineAutoPatching[];
    /**
     * key_vault_credential block.
     */
    readonly keyVaultCredential?: MssqlVirtualMachineKeyVaultCredential[];
    /**
     * storage_configuration block.
     */
    readonly storageConfiguration?: MssqlVirtualMachineStorageConfiguration[];
    /**
     * timeouts block.
     */
    readonly timeouts?: MssqlVirtualMachineTimeouts;
}
export interface MssqlVirtualMachineAutoPatching {
    readonly dayOfWeek: string;
    readonly maintenanceWindowDurationInMinutes: number;
    readonly maintenanceWindowStartingHour: number;
}
export interface MssqlVirtualMachineKeyVaultCredential {
    readonly keyVaultUrl: string;
    readonly name: string;
    readonly servicePrincipalName: string;
    readonly servicePrincipalSecret: string;
}
export interface MssqlVirtualMachineStorageConfigurationDataSettings {
    readonly defaultFilePath: string;
    readonly luns: number[];
}
export interface MssqlVirtualMachineStorageConfigurationLogSettings {
    readonly defaultFilePath: string;
    readonly luns: number[];
}
export interface MssqlVirtualMachineStorageConfigurationTempDbSettings {
    readonly defaultFilePath: string;
    readonly luns: number[];
}
export interface MssqlVirtualMachineStorageConfiguration {
    readonly diskType: string;
    readonly storageWorkloadType: string;
    /**
     * data_settings block.
     */
    readonly dataSettings?: MssqlVirtualMachineStorageConfigurationDataSettings[];
    /**
     * log_settings block.
     */
    readonly logSettings?: MssqlVirtualMachineStorageConfigurationLogSettings[];
    /**
     * temp_db_settings block.
     */
    readonly tempDbSettings?: MssqlVirtualMachineStorageConfigurationTempDbSettings[];
}
export interface MssqlVirtualMachineTimeouts {
    readonly create?: string;
    readonly delete?: string;
    readonly read?: string;
    readonly update?: string;
}
export declare class MssqlVirtualMachine extends cdktf.TerraformResource {
    constructor(scope: Construct, id: string, config: MssqlVirtualMachineConfig);
    get id(): string;
    private _rServicesEnabled?;
    get rServicesEnabled(): boolean;
    set rServicesEnabled(value: boolean);
    resetRServicesEnabled(): void;
    get rServicesEnabledInput(): boolean | undefined;
    private _sqlConnectivityPort?;
    get sqlConnectivityPort(): number;
    set sqlConnectivityPort(value: number);
    resetSqlConnectivityPort(): void;
    get sqlConnectivityPortInput(): number | undefined;
    private _sqlConnectivityType?;
    get sqlConnectivityType(): string;
    set sqlConnectivityType(value: string);
    resetSqlConnectivityType(): void;
    get sqlConnectivityTypeInput(): string | undefined;
    private _sqlConnectivityUpdatePassword?;
    get sqlConnectivityUpdatePassword(): string;
    set sqlConnectivityUpdatePassword(value: string);
    resetSqlConnectivityUpdatePassword(): void;
    get sqlConnectivityUpdatePasswordInput(): string | undefined;
    private _sqlConnectivityUpdateUsername?;
    get sqlConnectivityUpdateUsername(): string;
    set sqlConnectivityUpdateUsername(value: string);
    resetSqlConnectivityUpdateUsername(): void;
    get sqlConnectivityUpdateUsernameInput(): string | undefined;
    private _sqlLicenseType;
    get sqlLicenseType(): string;
    set sqlLicenseType(value: string);
    get sqlLicenseTypeInput(): string;
    private _tags?;
    get tags(): {
        [key: string]: string;
    };
    set tags(value: {
        [key: string]: string;
    });
    resetTags(): void;
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _virtualMachineId;
    get virtualMachineId(): string;
    set virtualMachineId(value: string);
    get virtualMachineIdInput(): string;
    private _autoPatching?;
    get autoPatching(): MssqlVirtualMachineAutoPatching[];
    set autoPatching(value: MssqlVirtualMachineAutoPatching[]);
    resetAutoPatching(): void;
    get autoPatchingInput(): MssqlVirtualMachineAutoPatching[] | undefined;
    private _keyVaultCredential?;
    get keyVaultCredential(): MssqlVirtualMachineKeyVaultCredential[];
    set keyVaultCredential(value: MssqlVirtualMachineKeyVaultCredential[]);
    resetKeyVaultCredential(): void;
    get keyVaultCredentialInput(): MssqlVirtualMachineKeyVaultCredential[] | undefined;
    private _storageConfiguration?;
    get storageConfiguration(): MssqlVirtualMachineStorageConfiguration[];
    set storageConfiguration(value: MssqlVirtualMachineStorageConfiguration[]);
    resetStorageConfiguration(): void;
    get storageConfigurationInput(): MssqlVirtualMachineStorageConfiguration[] | undefined;
    private _timeouts?;
    get timeouts(): MssqlVirtualMachineTimeouts;
    set timeouts(value: MssqlVirtualMachineTimeouts);
    resetTimeouts(): void;
    get timeoutsInput(): MssqlVirtualMachineTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
