import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface MysqlServerConfig extends cdktf.TerraformMetaArguments {
    readonly administratorLogin?: string;
    readonly administratorLoginPassword?: string;
    readonly autoGrowEnabled?: boolean;
    readonly backupRetentionDays?: number;
    readonly createMode?: string;
    readonly creationSourceServerId?: string;
    readonly geoRedundantBackupEnabled?: boolean;
    readonly infrastructureEncryptionEnabled?: boolean;
    readonly location: string;
    readonly name: string;
    readonly publicNetworkAccessEnabled?: boolean;
    readonly resourceGroupName: string;
    readonly restorePointInTime?: string;
    readonly skuName: string;
    readonly sslEnforcement?: string;
    readonly sslEnforcementEnabled?: boolean;
    readonly sslMinimalTlsVersionEnforced?: string;
    readonly storageMb?: number;
    readonly tags?: {
        [key: string]: string;
    };
    readonly version: string;
    /**
     * identity block.
     */
    readonly identity?: MysqlServerIdentity[];
    /**
     * storage_profile block.
     */
    readonly storageProfile?: MysqlServerStorageProfile[];
    /**
     * threat_detection_policy block.
     */
    readonly threatDetectionPolicy?: MysqlServerThreatDetectionPolicy[];
    /**
     * timeouts block.
     */
    readonly timeouts?: MysqlServerTimeouts;
}
export interface MysqlServerIdentity {
    readonly type: string;
}
export interface MysqlServerStorageProfile {
    readonly autoGrow?: string;
    readonly backupRetentionDays?: number;
    readonly geoRedundantBackup?: string;
    readonly storageMb?: number;
}
export interface MysqlServerThreatDetectionPolicy {
    readonly disabledAlerts?: string[];
    readonly emailAccountAdmins?: boolean;
    readonly emailAddresses?: string[];
    readonly enabled?: boolean;
    readonly retentionDays?: number;
    readonly storageAccountAccessKey?: string;
    readonly storageEndpoint?: string;
}
export interface MysqlServerTimeouts {
    readonly create?: string;
    readonly delete?: string;
    readonly read?: string;
    readonly update?: string;
}
export declare class MysqlServer extends cdktf.TerraformResource {
    constructor(scope: Construct, id: string, config: MysqlServerConfig);
    private _administratorLogin?;
    get administratorLogin(): string;
    set administratorLogin(value: string);
    resetAdministratorLogin(): void;
    get administratorLoginInput(): string | undefined;
    private _administratorLoginPassword?;
    get administratorLoginPassword(): string;
    set administratorLoginPassword(value: string);
    resetAdministratorLoginPassword(): void;
    get administratorLoginPasswordInput(): string | undefined;
    private _autoGrowEnabled?;
    get autoGrowEnabled(): boolean;
    set autoGrowEnabled(value: boolean);
    resetAutoGrowEnabled(): void;
    get autoGrowEnabledInput(): boolean | undefined;
    private _backupRetentionDays?;
    get backupRetentionDays(): number;
    set backupRetentionDays(value: number);
    resetBackupRetentionDays(): void;
    get backupRetentionDaysInput(): number | undefined;
    private _createMode?;
    get createMode(): string;
    set createMode(value: string);
    resetCreateMode(): void;
    get createModeInput(): string | undefined;
    private _creationSourceServerId?;
    get creationSourceServerId(): string;
    set creationSourceServerId(value: string);
    resetCreationSourceServerId(): void;
    get creationSourceServerIdInput(): string | undefined;
    get fqdn(): string;
    private _geoRedundantBackupEnabled?;
    get geoRedundantBackupEnabled(): boolean;
    set geoRedundantBackupEnabled(value: boolean);
    resetGeoRedundantBackupEnabled(): void;
    get geoRedundantBackupEnabledInput(): boolean | undefined;
    get id(): string;
    private _infrastructureEncryptionEnabled?;
    get infrastructureEncryptionEnabled(): boolean;
    set infrastructureEncryptionEnabled(value: boolean);
    resetInfrastructureEncryptionEnabled(): void;
    get infrastructureEncryptionEnabledInput(): boolean | undefined;
    private _location;
    get location(): string;
    set location(value: string);
    get locationInput(): string;
    private _name;
    get name(): string;
    set name(value: string);
    get nameInput(): string;
    private _publicNetworkAccessEnabled?;
    get publicNetworkAccessEnabled(): boolean;
    set publicNetworkAccessEnabled(value: boolean);
    resetPublicNetworkAccessEnabled(): void;
    get publicNetworkAccessEnabledInput(): boolean | undefined;
    private _resourceGroupName;
    get resourceGroupName(): string;
    set resourceGroupName(value: string);
    get resourceGroupNameInput(): string;
    private _restorePointInTime?;
    get restorePointInTime(): string;
    set restorePointInTime(value: string);
    resetRestorePointInTime(): void;
    get restorePointInTimeInput(): string | undefined;
    private _skuName;
    get skuName(): string;
    set skuName(value: string);
    get skuNameInput(): string;
    private _sslEnforcement?;
    get sslEnforcement(): string;
    set sslEnforcement(value: string);
    resetSslEnforcement(): void;
    get sslEnforcementInput(): string | undefined;
    private _sslEnforcementEnabled?;
    get sslEnforcementEnabled(): boolean;
    set sslEnforcementEnabled(value: boolean);
    resetSslEnforcementEnabled(): void;
    get sslEnforcementEnabledInput(): boolean | undefined;
    private _sslMinimalTlsVersionEnforced?;
    get sslMinimalTlsVersionEnforced(): string;
    set sslMinimalTlsVersionEnforced(value: string);
    resetSslMinimalTlsVersionEnforced(): void;
    get sslMinimalTlsVersionEnforcedInput(): string | undefined;
    private _storageMb?;
    get storageMb(): number;
    set storageMb(value: number);
    resetStorageMb(): void;
    get storageMbInput(): number | undefined;
    private _tags?;
    get tags(): {
        [key: string]: string;
    };
    set tags(value: {
        [key: string]: string;
    });
    resetTags(): void;
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _version;
    get version(): string;
    set version(value: string);
    get versionInput(): string;
    private _identity?;
    get identity(): MysqlServerIdentity[];
    set identity(value: MysqlServerIdentity[]);
    resetIdentity(): void;
    get identityInput(): MysqlServerIdentity[] | undefined;
    private _storageProfile?;
    get storageProfile(): MysqlServerStorageProfile[];
    set storageProfile(value: MysqlServerStorageProfile[]);
    resetStorageProfile(): void;
    get storageProfileInput(): MysqlServerStorageProfile[] | undefined;
    private _threatDetectionPolicy?;
    get threatDetectionPolicy(): MysqlServerThreatDetectionPolicy[];
    set threatDetectionPolicy(value: MysqlServerThreatDetectionPolicy[]);
    resetThreatDetectionPolicy(): void;
    get threatDetectionPolicyInput(): MysqlServerThreatDetectionPolicy[] | undefined;
    private _timeouts?;
    get timeouts(): MysqlServerTimeouts;
    set timeouts(value: MysqlServerTimeouts);
    resetTimeouts(): void;
    get timeoutsInput(): MysqlServerTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
