import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface NetworkConnectionMonitorConfig extends cdktf.TerraformMetaArguments {
    readonly autoStart?: boolean;
    readonly intervalInSeconds?: number;
    readonly location: string;
    readonly name: string;
    readonly networkWatcherId: string;
    readonly notes?: string;
    readonly outputWorkspaceResourceIds?: string[];
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * destination block.
     */
    readonly destination?: NetworkConnectionMonitorDestination[];
    /**
     * endpoint block.
     */
    readonly endpoint: NetworkConnectionMonitorEndpoint[];
    /**
     * source block.
     */
    readonly source?: NetworkConnectionMonitorSource[];
    /**
     * test_configuration block.
     */
    readonly testConfiguration: NetworkConnectionMonitorTestConfiguration[];
    /**
     * test_group block.
     */
    readonly testGroup: NetworkConnectionMonitorTestGroup[];
    /**
     * timeouts block.
     */
    readonly timeouts?: NetworkConnectionMonitorTimeouts;
}
export interface NetworkConnectionMonitorDestination {
    readonly address?: string;
    readonly port?: number;
    readonly virtualMachineId?: string;
}
export interface NetworkConnectionMonitorEndpointFilterItem {
    readonly address?: string;
    readonly type?: string;
}
export interface NetworkConnectionMonitorEndpointFilter {
    readonly type?: string;
    /**
     * item block.
     */
    readonly item?: NetworkConnectionMonitorEndpointFilterItem[];
}
export interface NetworkConnectionMonitorEndpoint {
    readonly address?: string;
    readonly name: string;
    readonly virtualMachineId?: string;
    /**
     * filter block.
     */
    readonly filter?: NetworkConnectionMonitorEndpointFilter[];
}
export interface NetworkConnectionMonitorSource {
    readonly port?: number;
    readonly virtualMachineId?: string;
}
export interface NetworkConnectionMonitorTestConfigurationHttpConfigurationRequestHeader {
    readonly name: string;
    readonly value: string;
}
export interface NetworkConnectionMonitorTestConfigurationHttpConfiguration {
    readonly method?: string;
    readonly path?: string;
    readonly port?: number;
    readonly preferHttps?: boolean;
    readonly validStatusCodeRanges?: string[];
    /**
     * request_header block.
     */
    readonly requestHeader?: NetworkConnectionMonitorTestConfigurationHttpConfigurationRequestHeader[];
}
export interface NetworkConnectionMonitorTestConfigurationIcmpConfiguration {
    readonly traceRouteEnabled?: boolean;
}
export interface NetworkConnectionMonitorTestConfigurationSuccessThreshold {
    readonly checksFailedPercent?: number;
    readonly roundTripTimeMs?: number;
}
export interface NetworkConnectionMonitorTestConfigurationTcpConfiguration {
    readonly port: number;
    readonly traceRouteEnabled?: boolean;
}
export interface NetworkConnectionMonitorTestConfiguration {
    readonly name: string;
    readonly preferredIpVersion?: string;
    readonly protocol: string;
    readonly testFrequencyInSeconds?: number;
    /**
     * http_configuration block.
     */
    readonly httpConfiguration?: NetworkConnectionMonitorTestConfigurationHttpConfiguration[];
    /**
     * icmp_configuration block.
     */
    readonly icmpConfiguration?: NetworkConnectionMonitorTestConfigurationIcmpConfiguration[];
    /**
     * success_threshold block.
     */
    readonly successThreshold?: NetworkConnectionMonitorTestConfigurationSuccessThreshold[];
    /**
     * tcp_configuration block.
     */
    readonly tcpConfiguration?: NetworkConnectionMonitorTestConfigurationTcpConfiguration[];
}
export interface NetworkConnectionMonitorTestGroup {
    readonly destinationEndpoints: string[];
    readonly enabled?: boolean;
    readonly name: string;
    readonly sourceEndpoints: string[];
    readonly testConfigurationNames: string[];
}
export interface NetworkConnectionMonitorTimeouts {
    readonly create?: string;
    readonly delete?: string;
    readonly read?: string;
    readonly update?: string;
}
export declare class NetworkConnectionMonitor extends cdktf.TerraformResource {
    constructor(scope: Construct, id: string, config: NetworkConnectionMonitorConfig);
    private _autoStart?;
    get autoStart(): boolean;
    set autoStart(value: boolean);
    resetAutoStart(): void;
    get autoStartInput(): boolean | undefined;
    get id(): string;
    private _intervalInSeconds?;
    get intervalInSeconds(): number;
    set intervalInSeconds(value: number);
    resetIntervalInSeconds(): void;
    get intervalInSecondsInput(): number | undefined;
    private _location;
    get location(): string;
    set location(value: string);
    get locationInput(): string;
    private _name;
    get name(): string;
    set name(value: string);
    get nameInput(): string;
    private _networkWatcherId;
    get networkWatcherId(): string;
    set networkWatcherId(value: string);
    get networkWatcherIdInput(): string;
    private _notes?;
    get notes(): string;
    set notes(value: string);
    resetNotes(): void;
    get notesInput(): string | undefined;
    private _outputWorkspaceResourceIds?;
    get outputWorkspaceResourceIds(): string[];
    set outputWorkspaceResourceIds(value: string[]);
    resetOutputWorkspaceResourceIds(): void;
    get outputWorkspaceResourceIdsInput(): string[] | undefined;
    private _tags?;
    get tags(): {
        [key: string]: string;
    };
    set tags(value: {
        [key: string]: string;
    });
    resetTags(): void;
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _destination?;
    get destination(): NetworkConnectionMonitorDestination[];
    set destination(value: NetworkConnectionMonitorDestination[]);
    resetDestination(): void;
    get destinationInput(): NetworkConnectionMonitorDestination[] | undefined;
    private _endpoint;
    get endpoint(): NetworkConnectionMonitorEndpoint[];
    set endpoint(value: NetworkConnectionMonitorEndpoint[]);
    get endpointInput(): NetworkConnectionMonitorEndpoint[];
    private _source?;
    get source(): NetworkConnectionMonitorSource[];
    set source(value: NetworkConnectionMonitorSource[]);
    resetSource(): void;
    get sourceInput(): NetworkConnectionMonitorSource[] | undefined;
    private _testConfiguration;
    get testConfiguration(): NetworkConnectionMonitorTestConfiguration[];
    set testConfiguration(value: NetworkConnectionMonitorTestConfiguration[]);
    get testConfigurationInput(): NetworkConnectionMonitorTestConfiguration[];
    private _testGroup;
    get testGroup(): NetworkConnectionMonitorTestGroup[];
    set testGroup(value: NetworkConnectionMonitorTestGroup[]);
    get testGroupInput(): NetworkConnectionMonitorTestGroup[];
    private _timeouts?;
    get timeouts(): NetworkConnectionMonitorTimeouts;
    set timeouts(value: NetworkConnectionMonitorTimeouts);
    resetTimeouts(): void;
    get timeoutsInput(): NetworkConnectionMonitorTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
