import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface RedisCacheConfig extends cdktf.TerraformMetaArguments {
    readonly capacity: number;
    readonly enableNonSslPort?: boolean;
    readonly family: string;
    readonly location: string;
    readonly minimumTlsVersion?: string;
    readonly name: string;
    readonly privateStaticIpAddress?: string;
    readonly resourceGroupName: string;
    readonly shardCount?: number;
    readonly skuName: string;
    readonly subnetId?: string;
    readonly tags?: {
        [key: string]: string;
    };
    readonly zones?: string[];
    /**
     * patch_schedule block.
     */
    readonly patchSchedule?: RedisCachePatchSchedule[];
    /**
     * redis_configuration block.
     */
    readonly redisConfiguration?: RedisCacheRedisConfiguration[];
    /**
     * timeouts block.
     */
    readonly timeouts?: RedisCacheTimeouts;
}
export interface RedisCachePatchSchedule {
    readonly dayOfWeek: string;
    readonly startHourUtc?: number;
}
export interface RedisCacheRedisConfiguration {
    readonly aofBackupEnabled?: boolean;
    readonly aofStorageConnectionString0?: string;
    readonly aofStorageConnectionString1?: string;
    readonly enableAuthentication?: boolean;
    readonly maxfragmentationmemoryReserved?: number;
    readonly maxmemoryDelta?: number;
    readonly maxmemoryPolicy?: string;
    readonly maxmemoryReserved?: number;
    readonly notifyKeyspaceEvents?: string;
    readonly rdbBackupEnabled?: boolean;
    readonly rdbBackupFrequency?: number;
    readonly rdbBackupMaxSnapshotCount?: number;
    readonly rdbStorageConnectionString?: string;
}
export interface RedisCacheTimeouts {
    readonly create?: string;
    readonly delete?: string;
    readonly read?: string;
    readonly update?: string;
}
export declare class RedisCache extends cdktf.TerraformResource {
    constructor(scope: Construct, id: string, config: RedisCacheConfig);
    private _capacity;
    get capacity(): number;
    set capacity(value: number);
    get capacityInput(): number;
    private _enableNonSslPort?;
    get enableNonSslPort(): boolean;
    set enableNonSslPort(value: boolean);
    resetEnableNonSslPort(): void;
    get enableNonSslPortInput(): boolean | undefined;
    private _family;
    get family(): string;
    set family(value: string);
    get familyInput(): string;
    get hostname(): string;
    get id(): string;
    private _location;
    get location(): string;
    set location(value: string);
    get locationInput(): string;
    private _minimumTlsVersion?;
    get minimumTlsVersion(): string;
    set minimumTlsVersion(value: string);
    resetMinimumTlsVersion(): void;
    get minimumTlsVersionInput(): string | undefined;
    private _name;
    get name(): string;
    set name(value: string);
    get nameInput(): string;
    get port(): number;
    get primaryAccessKey(): string;
    get primaryConnectionString(): string;
    private _privateStaticIpAddress?;
    get privateStaticIpAddress(): string;
    set privateStaticIpAddress(value: string);
    resetPrivateStaticIpAddress(): void;
    get privateStaticIpAddressInput(): string | undefined;
    private _resourceGroupName;
    get resourceGroupName(): string;
    set resourceGroupName(value: string);
    get resourceGroupNameInput(): string;
    get secondaryAccessKey(): string;
    get secondaryConnectionString(): string;
    private _shardCount?;
    get shardCount(): number;
    set shardCount(value: number);
    resetShardCount(): void;
    get shardCountInput(): number | undefined;
    private _skuName;
    get skuName(): string;
    set skuName(value: string);
    get skuNameInput(): string;
    get sslPort(): number;
    private _subnetId?;
    get subnetId(): string;
    set subnetId(value: string);
    resetSubnetId(): void;
    get subnetIdInput(): string | undefined;
    private _tags?;
    get tags(): {
        [key: string]: string;
    };
    set tags(value: {
        [key: string]: string;
    });
    resetTags(): void;
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _zones?;
    get zones(): string[];
    set zones(value: string[]);
    resetZones(): void;
    get zonesInput(): string[] | undefined;
    private _patchSchedule?;
    get patchSchedule(): RedisCachePatchSchedule[];
    set patchSchedule(value: RedisCachePatchSchedule[]);
    resetPatchSchedule(): void;
    get patchScheduleInput(): RedisCachePatchSchedule[] | undefined;
    private _redisConfiguration?;
    get redisConfiguration(): RedisCacheRedisConfiguration[];
    set redisConfiguration(value: RedisCacheRedisConfiguration[]);
    resetRedisConfiguration(): void;
    get redisConfigurationInput(): RedisCacheRedisConfiguration[] | undefined;
    private _timeouts?;
    get timeouts(): RedisCacheTimeouts;
    set timeouts(value: RedisCacheTimeouts);
    resetTimeouts(): void;
    get timeoutsInput(): RedisCacheTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
