import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface ServiceFabricClusterConfig extends cdktf.TerraformMetaArguments {
    readonly addOnFeatures?: string[];
    readonly clusterCodeVersion?: string;
    readonly location: string;
    readonly managementEndpoint: string;
    readonly name: string;
    readonly reliabilityLevel: string;
    readonly resourceGroupName: string;
    readonly tags?: {
        [key: string]: string;
    };
    readonly upgradeMode: string;
    readonly vmImage: string;
    /**
     * azure_active_directory block.
     */
    readonly azureActiveDirectory?: ServiceFabricClusterAzureActiveDirectory[];
    /**
     * certificate block.
     */
    readonly certificate?: ServiceFabricClusterCertificate[];
    /**
     * certificate_common_names block.
     */
    readonly certificateCommonNames?: ServiceFabricClusterCertificateCommonNames[];
    /**
     * client_certificate_common_name block.
     */
    readonly clientCertificateCommonName?: ServiceFabricClusterClientCertificateCommonName[];
    /**
     * client_certificate_thumbprint block.
     */
    readonly clientCertificateThumbprint?: ServiceFabricClusterClientCertificateThumbprint[];
    /**
     * diagnostics_config block.
     */
    readonly diagnosticsConfig?: ServiceFabricClusterDiagnosticsConfig[];
    /**
     * fabric_settings block.
     */
    readonly fabricSettings?: ServiceFabricClusterFabricSettings[];
    /**
     * node_type block.
     */
    readonly nodeType: ServiceFabricClusterNodeType[];
    /**
     * reverse_proxy_certificate block.
     */
    readonly reverseProxyCertificate?: ServiceFabricClusterReverseProxyCertificate[];
    /**
     * timeouts block.
     */
    readonly timeouts?: ServiceFabricClusterTimeouts;
}
export interface ServiceFabricClusterAzureActiveDirectory {
    readonly clientApplicationId: string;
    readonly clusterApplicationId: string;
    readonly tenantId: string;
}
export interface ServiceFabricClusterCertificate {
    readonly thumbprint: string;
    readonly thumbprintSecondary?: string;
    readonly x509StoreName: string;
}
export interface ServiceFabricClusterCertificateCommonNamesCommonNames {
    readonly certificateCommonName: string;
    readonly certificateIssuerThumbprint?: string;
}
export interface ServiceFabricClusterCertificateCommonNames {
    readonly x509StoreName: string;
    /**
     * common_names block.
     */
    readonly commonNames: ServiceFabricClusterCertificateCommonNamesCommonNames[];
}
export interface ServiceFabricClusterClientCertificateCommonName {
    readonly commonName: string;
    readonly isAdmin: boolean;
    readonly issuerThumbprint?: string;
}
export interface ServiceFabricClusterClientCertificateThumbprint {
    readonly isAdmin: boolean;
    readonly thumbprint: string;
}
export interface ServiceFabricClusterDiagnosticsConfig {
    readonly blobEndpoint: string;
    readonly protectedAccountKeyName: string;
    readonly queueEndpoint: string;
    readonly storageAccountName: string;
    readonly tableEndpoint: string;
}
export interface ServiceFabricClusterFabricSettings {
    readonly name: string;
    readonly parameters?: {
        [key: string]: string;
    };
}
export interface ServiceFabricClusterNodeTypeApplicationPorts {
    readonly endPort: number;
    readonly startPort: number;
}
export interface ServiceFabricClusterNodeTypeEphemeralPorts {
    readonly endPort: number;
    readonly startPort: number;
}
export interface ServiceFabricClusterNodeType {
    readonly capacities?: {
        [key: string]: string;
    };
    readonly clientEndpointPort: number;
    readonly durabilityLevel?: string;
    readonly httpEndpointPort: number;
    readonly instanceCount: number;
    readonly isPrimary: boolean;
    readonly name: string;
    readonly placementProperties?: {
        [key: string]: string;
    };
    readonly reverseProxyEndpointPort?: number;
    /**
     * application_ports block.
     */
    readonly applicationPorts?: ServiceFabricClusterNodeTypeApplicationPorts[];
    /**
     * ephemeral_ports block.
     */
    readonly ephemeralPorts?: ServiceFabricClusterNodeTypeEphemeralPorts[];
}
export interface ServiceFabricClusterReverseProxyCertificate {
    readonly thumbprint: string;
    readonly thumbprintSecondary?: string;
    readonly x509StoreName: string;
}
export interface ServiceFabricClusterTimeouts {
    readonly create?: string;
    readonly delete?: string;
    readonly read?: string;
    readonly update?: string;
}
export declare class ServiceFabricCluster extends cdktf.TerraformResource {
    constructor(scope: Construct, id: string, config: ServiceFabricClusterConfig);
    private _addOnFeatures?;
    get addOnFeatures(): string[];
    set addOnFeatures(value: string[]);
    resetAddOnFeatures(): void;
    get addOnFeaturesInput(): string[] | undefined;
    private _clusterCodeVersion?;
    get clusterCodeVersion(): string;
    set clusterCodeVersion(value: string);
    resetClusterCodeVersion(): void;
    get clusterCodeVersionInput(): string | undefined;
    get clusterEndpoint(): string;
    get id(): string;
    private _location;
    get location(): string;
    set location(value: string);
    get locationInput(): string;
    private _managementEndpoint;
    get managementEndpoint(): string;
    set managementEndpoint(value: string);
    get managementEndpointInput(): string;
    private _name;
    get name(): string;
    set name(value: string);
    get nameInput(): string;
    private _reliabilityLevel;
    get reliabilityLevel(): string;
    set reliabilityLevel(value: string);
    get reliabilityLevelInput(): string;
    private _resourceGroupName;
    get resourceGroupName(): string;
    set resourceGroupName(value: string);
    get resourceGroupNameInput(): string;
    private _tags?;
    get tags(): {
        [key: string]: string;
    };
    set tags(value: {
        [key: string]: string;
    });
    resetTags(): void;
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _upgradeMode;
    get upgradeMode(): string;
    set upgradeMode(value: string);
    get upgradeModeInput(): string;
    private _vmImage;
    get vmImage(): string;
    set vmImage(value: string);
    get vmImageInput(): string;
    private _azureActiveDirectory?;
    get azureActiveDirectory(): ServiceFabricClusterAzureActiveDirectory[];
    set azureActiveDirectory(value: ServiceFabricClusterAzureActiveDirectory[]);
    resetAzureActiveDirectory(): void;
    get azureActiveDirectoryInput(): ServiceFabricClusterAzureActiveDirectory[] | undefined;
    private _certificate?;
    get certificate(): ServiceFabricClusterCertificate[];
    set certificate(value: ServiceFabricClusterCertificate[]);
    resetCertificate(): void;
    get certificateInput(): ServiceFabricClusterCertificate[] | undefined;
    private _certificateCommonNames?;
    get certificateCommonNames(): ServiceFabricClusterCertificateCommonNames[];
    set certificateCommonNames(value: ServiceFabricClusterCertificateCommonNames[]);
    resetCertificateCommonNames(): void;
    get certificateCommonNamesInput(): ServiceFabricClusterCertificateCommonNames[] | undefined;
    private _clientCertificateCommonName?;
    get clientCertificateCommonName(): ServiceFabricClusterClientCertificateCommonName[];
    set clientCertificateCommonName(value: ServiceFabricClusterClientCertificateCommonName[]);
    resetClientCertificateCommonName(): void;
    get clientCertificateCommonNameInput(): ServiceFabricClusterClientCertificateCommonName[] | undefined;
    private _clientCertificateThumbprint?;
    get clientCertificateThumbprint(): ServiceFabricClusterClientCertificateThumbprint[];
    set clientCertificateThumbprint(value: ServiceFabricClusterClientCertificateThumbprint[]);
    resetClientCertificateThumbprint(): void;
    get clientCertificateThumbprintInput(): ServiceFabricClusterClientCertificateThumbprint[] | undefined;
    private _diagnosticsConfig?;
    get diagnosticsConfig(): ServiceFabricClusterDiagnosticsConfig[];
    set diagnosticsConfig(value: ServiceFabricClusterDiagnosticsConfig[]);
    resetDiagnosticsConfig(): void;
    get diagnosticsConfigInput(): ServiceFabricClusterDiagnosticsConfig[] | undefined;
    private _fabricSettings?;
    get fabricSettings(): ServiceFabricClusterFabricSettings[];
    set fabricSettings(value: ServiceFabricClusterFabricSettings[]);
    resetFabricSettings(): void;
    get fabricSettingsInput(): ServiceFabricClusterFabricSettings[] | undefined;
    private _nodeType;
    get nodeType(): ServiceFabricClusterNodeType[];
    set nodeType(value: ServiceFabricClusterNodeType[]);
    get nodeTypeInput(): ServiceFabricClusterNodeType[];
    private _reverseProxyCertificate?;
    get reverseProxyCertificate(): ServiceFabricClusterReverseProxyCertificate[];
    set reverseProxyCertificate(value: ServiceFabricClusterReverseProxyCertificate[]);
    resetReverseProxyCertificate(): void;
    get reverseProxyCertificateInput(): ServiceFabricClusterReverseProxyCertificate[] | undefined;
    private _timeouts?;
    get timeouts(): ServiceFabricClusterTimeouts;
    set timeouts(value: ServiceFabricClusterTimeouts);
    resetTimeouts(): void;
    get timeoutsInput(): ServiceFabricClusterTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
