import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface SpringCloudServiceConfig extends cdktf.TerraformMetaArguments {
    readonly location: string;
    readonly name: string;
    readonly resourceGroupName: string;
    readonly skuName?: string;
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * config_server_git_setting block.
     */
    readonly configServerGitSetting?: SpringCloudServiceConfigServerGitSetting[];
    /**
     * network block.
     */
    readonly network?: SpringCloudServiceNetwork[];
    /**
     * timeouts block.
     */
    readonly timeouts?: SpringCloudServiceTimeouts;
    /**
     * trace block.
     */
    readonly trace?: SpringCloudServiceTrace[];
}
export interface SpringCloudServiceConfigServerGitSettingHttpBasicAuth {
    readonly password: string;
    readonly username: string;
}
export interface SpringCloudServiceConfigServerGitSettingRepositoryHttpBasicAuth {
    readonly password: string;
    readonly username: string;
}
export interface SpringCloudServiceConfigServerGitSettingRepositorySshAuth {
    readonly hostKey?: string;
    readonly hostKeyAlgorithm?: string;
    readonly privateKey: string;
    readonly strictHostKeyCheckingEnabled?: boolean;
}
export interface SpringCloudServiceConfigServerGitSettingRepository {
    readonly label?: string;
    readonly name: string;
    readonly pattern?: string[];
    readonly searchPaths?: string[];
    readonly uri: string;
    /**
     * http_basic_auth block.
     */
    readonly httpBasicAuth?: SpringCloudServiceConfigServerGitSettingRepositoryHttpBasicAuth[];
    /**
     * ssh_auth block.
     */
    readonly sshAuth?: SpringCloudServiceConfigServerGitSettingRepositorySshAuth[];
}
export interface SpringCloudServiceConfigServerGitSettingSshAuth {
    readonly hostKey?: string;
    readonly hostKeyAlgorithm?: string;
    readonly privateKey: string;
    readonly strictHostKeyCheckingEnabled?: boolean;
}
export interface SpringCloudServiceConfigServerGitSetting {
    readonly label?: string;
    readonly searchPaths?: string[];
    readonly uri: string;
    /**
     * http_basic_auth block.
     */
    readonly httpBasicAuth?: SpringCloudServiceConfigServerGitSettingHttpBasicAuth[];
    /**
     * repository block.
     */
    readonly repository?: SpringCloudServiceConfigServerGitSettingRepository[];
    /**
     * ssh_auth block.
     */
    readonly sshAuth?: SpringCloudServiceConfigServerGitSettingSshAuth[];
}
export interface SpringCloudServiceNetwork {
    readonly appNetworkResourceGroup?: string;
    readonly appSubnetId: string;
    readonly cidrRanges: string[];
    readonly serviceRuntimeNetworkResourceGroup?: string;
    readonly serviceRuntimeSubnetId: string;
}
export interface SpringCloudServiceTimeouts {
    readonly create?: string;
    readonly delete?: string;
    readonly read?: string;
    readonly update?: string;
}
export interface SpringCloudServiceTrace {
    readonly instrumentationKey: string;
}
export declare class SpringCloudService extends cdktf.TerraformResource {
    constructor(scope: Construct, id: string, config: SpringCloudServiceConfig);
    get id(): string;
    private _location;
    get location(): string;
    set location(value: string);
    get locationInput(): string;
    private _name;
    get name(): string;
    set name(value: string);
    get nameInput(): string;
    get outboundPublicIpAddresses(): string[];
    private _resourceGroupName;
    get resourceGroupName(): string;
    set resourceGroupName(value: string);
    get resourceGroupNameInput(): string;
    private _skuName?;
    get skuName(): string;
    set skuName(value: string);
    resetSkuName(): void;
    get skuNameInput(): string | undefined;
    private _tags?;
    get tags(): {
        [key: string]: string;
    };
    set tags(value: {
        [key: string]: string;
    });
    resetTags(): void;
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _configServerGitSetting?;
    get configServerGitSetting(): SpringCloudServiceConfigServerGitSetting[];
    set configServerGitSetting(value: SpringCloudServiceConfigServerGitSetting[]);
    resetConfigServerGitSetting(): void;
    get configServerGitSettingInput(): SpringCloudServiceConfigServerGitSetting[] | undefined;
    private _network?;
    get network(): SpringCloudServiceNetwork[];
    set network(value: SpringCloudServiceNetwork[]);
    resetNetwork(): void;
    get networkInput(): SpringCloudServiceNetwork[] | undefined;
    private _timeouts?;
    get timeouts(): SpringCloudServiceTimeouts;
    set timeouts(value: SpringCloudServiceTimeouts);
    resetTimeouts(): void;
    get timeoutsInput(): SpringCloudServiceTimeouts | undefined;
    private _trace?;
    get trace(): SpringCloudServiceTrace[];
    set trace(value: SpringCloudServiceTrace[]);
    resetTrace(): void;
    get traceInput(): SpringCloudServiceTrace[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
