import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface SqlDatabaseConfig extends cdktf.TerraformMetaArguments {
    readonly collation?: string;
    readonly createMode?: string;
    readonly edition?: string;
    readonly elasticPoolName?: string;
    readonly extendedAuditingPolicy?: SqlDatabaseExtendedAuditingPolicy[];
    readonly location: string;
    readonly maxSizeBytes?: string;
    readonly maxSizeGb?: string;
    readonly name: string;
    readonly readScale?: boolean;
    readonly requestedServiceObjectiveId?: string;
    readonly requestedServiceObjectiveName?: string;
    readonly resourceGroupName: string;
    readonly restorePointInTime?: string;
    readonly serverName: string;
    readonly sourceDatabaseDeletionDate?: string;
    readonly sourceDatabaseId?: string;
    readonly tags?: {
        [key: string]: string;
    };
    readonly zoneRedundant?: boolean;
    /**
     * import block.
     */
    readonly import?: SqlDatabaseImport[];
    /**
     * threat_detection_policy block.
     */
    readonly threatDetectionPolicy?: SqlDatabaseThreatDetectionPolicy[];
    /**
     * timeouts block.
     */
    readonly timeouts?: SqlDatabaseTimeouts;
}
export interface SqlDatabaseExtendedAuditingPolicy {
    readonly retentionInDays?: number;
    readonly storageAccountAccessKey?: string;
    readonly storageAccountAccessKeyIsSecondary?: boolean;
    readonly storageEndpoint?: string;
}
export interface SqlDatabaseImport {
    readonly administratorLogin: string;
    readonly administratorLoginPassword: string;
    readonly authenticationType: string;
    readonly operationMode?: string;
    readonly storageKey: string;
    readonly storageKeyType: string;
    readonly storageUri: string;
}
export interface SqlDatabaseThreatDetectionPolicy {
    readonly disabledAlerts?: string[];
    readonly emailAccountAdmins?: string;
    readonly emailAddresses?: string[];
    readonly retentionDays?: number;
    readonly state?: string;
    readonly storageAccountAccessKey?: string;
    readonly storageEndpoint?: string;
    readonly useServerDefault?: string;
}
export interface SqlDatabaseTimeouts {
    readonly create?: string;
    readonly delete?: string;
    readonly read?: string;
    readonly update?: string;
}
export declare class SqlDatabase extends cdktf.TerraformResource {
    constructor(scope: Construct, id: string, config: SqlDatabaseConfig);
    private _collation?;
    get collation(): string;
    set collation(value: string);
    resetCollation(): void;
    get collationInput(): string | undefined;
    private _createMode?;
    get createMode(): string;
    set createMode(value: string);
    resetCreateMode(): void;
    get createModeInput(): string | undefined;
    get creationDate(): string;
    get defaultSecondaryLocation(): string;
    private _edition?;
    get edition(): string;
    set edition(value: string);
    resetEdition(): void;
    get editionInput(): string | undefined;
    private _elasticPoolName?;
    get elasticPoolName(): string;
    set elasticPoolName(value: string);
    resetElasticPoolName(): void;
    get elasticPoolNameInput(): string | undefined;
    get encryption(): string;
    private _extendedAuditingPolicy?;
    get extendedAuditingPolicy(): SqlDatabaseExtendedAuditingPolicy[];
    set extendedAuditingPolicy(value: SqlDatabaseExtendedAuditingPolicy[]);
    resetExtendedAuditingPolicy(): void;
    get extendedAuditingPolicyInput(): SqlDatabaseExtendedAuditingPolicy[] | undefined;
    get id(): string;
    private _location;
    get location(): string;
    set location(value: string);
    get locationInput(): string;
    private _maxSizeBytes?;
    get maxSizeBytes(): string;
    set maxSizeBytes(value: string);
    resetMaxSizeBytes(): void;
    get maxSizeBytesInput(): string | undefined;
    private _maxSizeGb?;
    get maxSizeGb(): string;
    set maxSizeGb(value: string);
    resetMaxSizeGb(): void;
    get maxSizeGbInput(): string | undefined;
    private _name;
    get name(): string;
    set name(value: string);
    get nameInput(): string;
    private _readScale?;
    get readScale(): boolean;
    set readScale(value: boolean);
    resetReadScale(): void;
    get readScaleInput(): boolean | undefined;
    private _requestedServiceObjectiveId?;
    get requestedServiceObjectiveId(): string;
    set requestedServiceObjectiveId(value: string);
    resetRequestedServiceObjectiveId(): void;
    get requestedServiceObjectiveIdInput(): string | undefined;
    private _requestedServiceObjectiveName?;
    get requestedServiceObjectiveName(): string;
    set requestedServiceObjectiveName(value: string);
    resetRequestedServiceObjectiveName(): void;
    get requestedServiceObjectiveNameInput(): string | undefined;
    private _resourceGroupName;
    get resourceGroupName(): string;
    set resourceGroupName(value: string);
    get resourceGroupNameInput(): string;
    private _restorePointInTime?;
    get restorePointInTime(): string;
    set restorePointInTime(value: string);
    resetRestorePointInTime(): void;
    get restorePointInTimeInput(): string | undefined;
    private _serverName;
    get serverName(): string;
    set serverName(value: string);
    get serverNameInput(): string;
    private _sourceDatabaseDeletionDate?;
    get sourceDatabaseDeletionDate(): string;
    set sourceDatabaseDeletionDate(value: string);
    resetSourceDatabaseDeletionDate(): void;
    get sourceDatabaseDeletionDateInput(): string | undefined;
    private _sourceDatabaseId?;
    get sourceDatabaseId(): string;
    set sourceDatabaseId(value: string);
    resetSourceDatabaseId(): void;
    get sourceDatabaseIdInput(): string | undefined;
    private _tags?;
    get tags(): {
        [key: string]: string;
    };
    set tags(value: {
        [key: string]: string;
    });
    resetTags(): void;
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _zoneRedundant?;
    get zoneRedundant(): boolean;
    set zoneRedundant(value: boolean);
    resetZoneRedundant(): void;
    get zoneRedundantInput(): boolean | undefined;
    private _import?;
    get import(): SqlDatabaseImport[];
    set import(value: SqlDatabaseImport[]);
    resetImport(): void;
    get importInput(): SqlDatabaseImport[] | undefined;
    private _threatDetectionPolicy?;
    get threatDetectionPolicy(): SqlDatabaseThreatDetectionPolicy[];
    set threatDetectionPolicy(value: SqlDatabaseThreatDetectionPolicy[]);
    resetThreatDetectionPolicy(): void;
    get threatDetectionPolicyInput(): SqlDatabaseThreatDetectionPolicy[] | undefined;
    private _timeouts?;
    get timeouts(): SqlDatabaseTimeouts;
    set timeouts(value: SqlDatabaseTimeouts);
    resetTimeouts(): void;
    get timeoutsInput(): SqlDatabaseTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
