import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface StorageAccountConfig extends cdktf.TerraformMetaArguments {
    readonly accessTier?: string;
    readonly accountKind?: string;
    readonly accountReplicationType: string;
    readonly accountTier: string;
    readonly allowBlobPublicAccess?: boolean;
    readonly enableHttpsTrafficOnly?: boolean;
    readonly isHnsEnabled?: boolean;
    readonly largeFileShareEnabled?: boolean;
    readonly location: string;
    readonly minTlsVersion?: string;
    readonly name: string;
    readonly resourceGroupName: string;
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * blob_properties block.
     */
    readonly blobProperties?: StorageAccountBlobProperties[];
    /**
     * custom_domain block.
     */
    readonly customDomain?: StorageAccountCustomDomain[];
    /**
     * identity block.
     */
    readonly identity?: StorageAccountIdentity[];
    /**
     * network_rules block.
     */
    readonly networkRules?: StorageAccountNetworkRules[];
    /**
     * queue_properties block.
     */
    readonly queueProperties?: StorageAccountQueueProperties[];
    /**
     * static_website block.
     */
    readonly staticWebsite?: StorageAccountStaticWebsite[];
    /**
     * timeouts block.
     */
    readonly timeouts?: StorageAccountTimeouts;
}
export interface StorageAccountBlobPropertiesCorsRule {
    readonly allowedHeaders: string[];
    readonly allowedMethods: string[];
    readonly allowedOrigins: string[];
    readonly exposedHeaders: string[];
    readonly maxAgeInSeconds: number;
}
export interface StorageAccountBlobPropertiesDeleteRetentionPolicy {
    readonly days?: number;
}
export interface StorageAccountBlobProperties {
    /**
     * cors_rule block.
     */
    readonly corsRule?: StorageAccountBlobPropertiesCorsRule[];
    /**
     * delete_retention_policy block.
     */
    readonly deleteRetentionPolicy?: StorageAccountBlobPropertiesDeleteRetentionPolicy[];
}
export interface StorageAccountCustomDomain {
    readonly name: string;
    readonly useSubdomain?: boolean;
}
export interface StorageAccountIdentity {
    readonly type: string;
}
export interface StorageAccountNetworkRules {
    readonly bypass?: string[];
    readonly defaultAction: string;
    readonly ipRules?: string[];
    readonly virtualNetworkSubnetIds?: string[];
}
export interface StorageAccountQueuePropertiesCorsRule {
    readonly allowedHeaders: string[];
    readonly allowedMethods: string[];
    readonly allowedOrigins: string[];
    readonly exposedHeaders: string[];
    readonly maxAgeInSeconds: number;
}
export interface StorageAccountQueuePropertiesHourMetrics {
    readonly enabled: boolean;
    readonly includeApis?: boolean;
    readonly retentionPolicyDays?: number;
    readonly version: string;
}
export interface StorageAccountQueuePropertiesLogging {
    readonly delete: boolean;
    readonly read: boolean;
    readonly retentionPolicyDays?: number;
    readonly version: string;
    readonly write: boolean;
}
export interface StorageAccountQueuePropertiesMinuteMetrics {
    readonly enabled: boolean;
    readonly includeApis?: boolean;
    readonly retentionPolicyDays?: number;
    readonly version: string;
}
export interface StorageAccountQueueProperties {
    /**
     * cors_rule block.
     */
    readonly corsRule?: StorageAccountQueuePropertiesCorsRule[];
    /**
     * hour_metrics block.
     */
    readonly hourMetrics?: StorageAccountQueuePropertiesHourMetrics[];
    /**
     * logging block.
     */
    readonly logging?: StorageAccountQueuePropertiesLogging[];
    /**
     * minute_metrics block.
     */
    readonly minuteMetrics?: StorageAccountQueuePropertiesMinuteMetrics[];
}
export interface StorageAccountStaticWebsite {
    readonly error404Document?: string;
    readonly indexDocument?: string;
}
export interface StorageAccountTimeouts {
    readonly create?: string;
    readonly delete?: string;
    readonly read?: string;
    readonly update?: string;
}
export declare class StorageAccount extends cdktf.TerraformResource {
    constructor(scope: Construct, id: string, config: StorageAccountConfig);
    private _accessTier?;
    get accessTier(): string;
    set accessTier(value: string);
    resetAccessTier(): void;
    get accessTierInput(): string | undefined;
    private _accountKind?;
    get accountKind(): string;
    set accountKind(value: string);
    resetAccountKind(): void;
    get accountKindInput(): string | undefined;
    private _accountReplicationType;
    get accountReplicationType(): string;
    set accountReplicationType(value: string);
    get accountReplicationTypeInput(): string;
    private _accountTier;
    get accountTier(): string;
    set accountTier(value: string);
    get accountTierInput(): string;
    private _allowBlobPublicAccess?;
    get allowBlobPublicAccess(): boolean;
    set allowBlobPublicAccess(value: boolean);
    resetAllowBlobPublicAccess(): void;
    get allowBlobPublicAccessInput(): boolean | undefined;
    private _enableHttpsTrafficOnly?;
    get enableHttpsTrafficOnly(): boolean;
    set enableHttpsTrafficOnly(value: boolean);
    resetEnableHttpsTrafficOnly(): void;
    get enableHttpsTrafficOnlyInput(): boolean | undefined;
    get id(): string;
    private _isHnsEnabled?;
    get isHnsEnabled(): boolean;
    set isHnsEnabled(value: boolean);
    resetIsHnsEnabled(): void;
    get isHnsEnabledInput(): boolean | undefined;
    private _largeFileShareEnabled?;
    get largeFileShareEnabled(): boolean;
    set largeFileShareEnabled(value: boolean);
    resetLargeFileShareEnabled(): void;
    get largeFileShareEnabledInput(): boolean | undefined;
    private _location;
    get location(): string;
    set location(value: string);
    get locationInput(): string;
    private _minTlsVersion?;
    get minTlsVersion(): string;
    set minTlsVersion(value: string);
    resetMinTlsVersion(): void;
    get minTlsVersionInput(): string | undefined;
    private _name;
    get name(): string;
    set name(value: string);
    get nameInput(): string;
    get primaryAccessKey(): string;
    get primaryBlobConnectionString(): string;
    get primaryBlobEndpoint(): string;
    get primaryBlobHost(): string;
    get primaryConnectionString(): string;
    get primaryDfsEndpoint(): string;
    get primaryDfsHost(): string;
    get primaryFileEndpoint(): string;
    get primaryFileHost(): string;
    get primaryLocation(): string;
    get primaryQueueEndpoint(): string;
    get primaryQueueHost(): string;
    get primaryTableEndpoint(): string;
    get primaryTableHost(): string;
    get primaryWebEndpoint(): string;
    get primaryWebHost(): string;
    private _resourceGroupName;
    get resourceGroupName(): string;
    set resourceGroupName(value: string);
    get resourceGroupNameInput(): string;
    get secondaryAccessKey(): string;
    get secondaryBlobConnectionString(): string;
    get secondaryBlobEndpoint(): string;
    get secondaryBlobHost(): string;
    get secondaryConnectionString(): string;
    get secondaryDfsEndpoint(): string;
    get secondaryDfsHost(): string;
    get secondaryFileEndpoint(): string;
    get secondaryFileHost(): string;
    get secondaryLocation(): string;
    get secondaryQueueEndpoint(): string;
    get secondaryQueueHost(): string;
    get secondaryTableEndpoint(): string;
    get secondaryTableHost(): string;
    get secondaryWebEndpoint(): string;
    get secondaryWebHost(): string;
    private _tags?;
    get tags(): {
        [key: string]: string;
    };
    set tags(value: {
        [key: string]: string;
    });
    resetTags(): void;
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _blobProperties?;
    get blobProperties(): StorageAccountBlobProperties[];
    set blobProperties(value: StorageAccountBlobProperties[]);
    resetBlobProperties(): void;
    get blobPropertiesInput(): StorageAccountBlobProperties[] | undefined;
    private _customDomain?;
    get customDomain(): StorageAccountCustomDomain[];
    set customDomain(value: StorageAccountCustomDomain[]);
    resetCustomDomain(): void;
    get customDomainInput(): StorageAccountCustomDomain[] | undefined;
    private _identity?;
    get identity(): StorageAccountIdentity[];
    set identity(value: StorageAccountIdentity[]);
    resetIdentity(): void;
    get identityInput(): StorageAccountIdentity[] | undefined;
    private _networkRules?;
    get networkRules(): StorageAccountNetworkRules[];
    set networkRules(value: StorageAccountNetworkRules[]);
    resetNetworkRules(): void;
    get networkRulesInput(): StorageAccountNetworkRules[] | undefined;
    private _queueProperties?;
    get queueProperties(): StorageAccountQueueProperties[];
    set queueProperties(value: StorageAccountQueueProperties[]);
    resetQueueProperties(): void;
    get queuePropertiesInput(): StorageAccountQueueProperties[] | undefined;
    private _staticWebsite?;
    get staticWebsite(): StorageAccountStaticWebsite[];
    set staticWebsite(value: StorageAccountStaticWebsite[]);
    resetStaticWebsite(): void;
    get staticWebsiteInput(): StorageAccountStaticWebsite[] | undefined;
    private _timeouts?;
    get timeouts(): StorageAccountTimeouts;
    set timeouts(value: StorageAccountTimeouts);
    resetTimeouts(): void;
    get timeoutsInput(): StorageAccountTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
