import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface VirtualMachineConfig extends cdktf.TerraformMetaArguments {
    readonly availabilitySetId?: string;
    readonly deleteDataDisksOnTermination?: boolean;
    readonly deleteOsDiskOnTermination?: boolean;
    readonly licenseType?: string;
    readonly location: string;
    readonly name: string;
    readonly networkInterfaceIds: string[];
    readonly primaryNetworkInterfaceId?: string;
    readonly proximityPlacementGroupId?: string;
    readonly resourceGroupName: string;
    readonly tags?: {
        [key: string]: string;
    };
    readonly vmSize: string;
    readonly zones?: string[];
    /**
     * additional_capabilities block.
     */
    readonly additionalCapabilities?: VirtualMachineAdditionalCapabilities[];
    /**
     * boot_diagnostics block.
     */
    readonly bootDiagnostics?: VirtualMachineBootDiagnostics[];
    /**
     * identity block.
     */
    readonly identity?: VirtualMachineIdentity[];
    /**
     * os_profile block.
     */
    readonly osProfile?: VirtualMachineOsProfile[];
    /**
     * os_profile_linux_config block.
     */
    readonly osProfileLinuxConfig?: VirtualMachineOsProfileLinuxConfig[];
    /**
     * os_profile_secrets block.
     */
    readonly osProfileSecrets?: VirtualMachineOsProfileSecrets[];
    /**
     * os_profile_windows_config block.
     */
    readonly osProfileWindowsConfig?: VirtualMachineOsProfileWindowsConfig[];
    /**
     * plan block.
     */
    readonly plan?: VirtualMachinePlan[];
    /**
     * storage_data_disk block.
     */
    readonly storageDataDisk?: VirtualMachineStorageDataDisk[];
    /**
     * storage_image_reference block.
     */
    readonly storageImageReference?: VirtualMachineStorageImageReference[];
    /**
     * storage_os_disk block.
     */
    readonly storageOsDisk: VirtualMachineStorageOsDisk[];
    /**
     * timeouts block.
     */
    readonly timeouts?: VirtualMachineTimeouts;
}
export interface VirtualMachineAdditionalCapabilities {
    readonly ultraSsdEnabled: boolean;
}
export interface VirtualMachineBootDiagnostics {
    readonly enabled: boolean;
    readonly storageUri: string;
}
export interface VirtualMachineIdentity {
    readonly identityIds?: string[];
    readonly type: string;
}
export interface VirtualMachineOsProfile {
    readonly adminPassword?: string;
    readonly adminUsername: string;
    readonly computerName: string;
    readonly customData?: string;
}
export interface VirtualMachineOsProfileLinuxConfigSshKeys {
    readonly keyData: string;
    readonly path: string;
}
export interface VirtualMachineOsProfileLinuxConfig {
    readonly disablePasswordAuthentication: boolean;
    /**
     * ssh_keys block.
     */
    readonly sshKeys?: VirtualMachineOsProfileLinuxConfigSshKeys[];
}
export interface VirtualMachineOsProfileSecretsVaultCertificates {
    readonly certificateStore?: string;
    readonly certificateUrl: string;
}
export interface VirtualMachineOsProfileSecrets {
    readonly sourceVaultId: string;
    /**
     * vault_certificates block.
     */
    readonly vaultCertificates?: VirtualMachineOsProfileSecretsVaultCertificates[];
}
export interface VirtualMachineOsProfileWindowsConfigAdditionalUnattendConfig {
    readonly component: string;
    readonly content: string;
    readonly pass: string;
    readonly settingName: string;
}
export interface VirtualMachineOsProfileWindowsConfigWinrm {
    readonly certificateUrl?: string;
    readonly protocol: string;
}
export interface VirtualMachineOsProfileWindowsConfig {
    readonly enableAutomaticUpgrades?: boolean;
    readonly provisionVmAgent?: boolean;
    readonly timezone?: string;
    /**
     * additional_unattend_config block.
     */
    readonly additionalUnattendConfig?: VirtualMachineOsProfileWindowsConfigAdditionalUnattendConfig[];
    /**
     * winrm block.
     */
    readonly winrm?: VirtualMachineOsProfileWindowsConfigWinrm[];
}
export interface VirtualMachinePlan {
    readonly name: string;
    readonly product: string;
    readonly publisher: string;
}
export interface VirtualMachineStorageDataDisk {
    readonly caching?: string;
    readonly createOption: string;
    readonly diskSizeGb?: number;
    readonly lun: number;
    readonly managedDiskId?: string;
    readonly managedDiskType?: string;
    readonly name: string;
    readonly vhdUri?: string;
    readonly writeAcceleratorEnabled?: boolean;
}
export interface VirtualMachineStorageImageReference {
    readonly id?: string;
    readonly offer?: string;
    readonly publisher?: string;
    readonly sku?: string;
    readonly version?: string;
}
export interface VirtualMachineStorageOsDisk {
    readonly caching?: string;
    readonly createOption: string;
    readonly diskSizeGb?: number;
    readonly imageUri?: string;
    readonly managedDiskId?: string;
    readonly managedDiskType?: string;
    readonly name: string;
    readonly osType?: string;
    readonly vhdUri?: string;
    readonly writeAcceleratorEnabled?: boolean;
}
export interface VirtualMachineTimeouts {
    readonly create?: string;
    readonly delete?: string;
    readonly read?: string;
    readonly update?: string;
}
export declare class VirtualMachine extends cdktf.TerraformResource {
    constructor(scope: Construct, id: string, config: VirtualMachineConfig);
    private _availabilitySetId?;
    get availabilitySetId(): string;
    set availabilitySetId(value: string);
    resetAvailabilitySetId(): void;
    get availabilitySetIdInput(): string | undefined;
    private _deleteDataDisksOnTermination?;
    get deleteDataDisksOnTermination(): boolean;
    set deleteDataDisksOnTermination(value: boolean);
    resetDeleteDataDisksOnTermination(): void;
    get deleteDataDisksOnTerminationInput(): boolean | undefined;
    private _deleteOsDiskOnTermination?;
    get deleteOsDiskOnTermination(): boolean;
    set deleteOsDiskOnTermination(value: boolean);
    resetDeleteOsDiskOnTermination(): void;
    get deleteOsDiskOnTerminationInput(): boolean | undefined;
    get id(): string;
    private _licenseType?;
    get licenseType(): string;
    set licenseType(value: string);
    resetLicenseType(): void;
    get licenseTypeInput(): string | undefined;
    private _location;
    get location(): string;
    set location(value: string);
    get locationInput(): string;
    private _name;
    get name(): string;
    set name(value: string);
    get nameInput(): string;
    private _networkInterfaceIds;
    get networkInterfaceIds(): string[];
    set networkInterfaceIds(value: string[]);
    get networkInterfaceIdsInput(): string[];
    private _primaryNetworkInterfaceId?;
    get primaryNetworkInterfaceId(): string;
    set primaryNetworkInterfaceId(value: string);
    resetPrimaryNetworkInterfaceId(): void;
    get primaryNetworkInterfaceIdInput(): string | undefined;
    private _proximityPlacementGroupId?;
    get proximityPlacementGroupId(): string;
    set proximityPlacementGroupId(value: string);
    resetProximityPlacementGroupId(): void;
    get proximityPlacementGroupIdInput(): string | undefined;
    private _resourceGroupName;
    get resourceGroupName(): string;
    set resourceGroupName(value: string);
    get resourceGroupNameInput(): string;
    private _tags?;
    get tags(): {
        [key: string]: string;
    };
    set tags(value: {
        [key: string]: string;
    });
    resetTags(): void;
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _vmSize;
    get vmSize(): string;
    set vmSize(value: string);
    get vmSizeInput(): string;
    private _zones?;
    get zones(): string[];
    set zones(value: string[]);
    resetZones(): void;
    get zonesInput(): string[] | undefined;
    private _additionalCapabilities?;
    get additionalCapabilities(): VirtualMachineAdditionalCapabilities[];
    set additionalCapabilities(value: VirtualMachineAdditionalCapabilities[]);
    resetAdditionalCapabilities(): void;
    get additionalCapabilitiesInput(): VirtualMachineAdditionalCapabilities[] | undefined;
    private _bootDiagnostics?;
    get bootDiagnostics(): VirtualMachineBootDiagnostics[];
    set bootDiagnostics(value: VirtualMachineBootDiagnostics[]);
    resetBootDiagnostics(): void;
    get bootDiagnosticsInput(): VirtualMachineBootDiagnostics[] | undefined;
    private _identity?;
    get identity(): VirtualMachineIdentity[];
    set identity(value: VirtualMachineIdentity[]);
    resetIdentity(): void;
    get identityInput(): VirtualMachineIdentity[] | undefined;
    private _osProfile?;
    get osProfile(): VirtualMachineOsProfile[];
    set osProfile(value: VirtualMachineOsProfile[]);
    resetOsProfile(): void;
    get osProfileInput(): VirtualMachineOsProfile[] | undefined;
    private _osProfileLinuxConfig?;
    get osProfileLinuxConfig(): VirtualMachineOsProfileLinuxConfig[];
    set osProfileLinuxConfig(value: VirtualMachineOsProfileLinuxConfig[]);
    resetOsProfileLinuxConfig(): void;
    get osProfileLinuxConfigInput(): VirtualMachineOsProfileLinuxConfig[] | undefined;
    private _osProfileSecrets?;
    get osProfileSecrets(): VirtualMachineOsProfileSecrets[];
    set osProfileSecrets(value: VirtualMachineOsProfileSecrets[]);
    resetOsProfileSecrets(): void;
    get osProfileSecretsInput(): VirtualMachineOsProfileSecrets[] | undefined;
    private _osProfileWindowsConfig?;
    get osProfileWindowsConfig(): VirtualMachineOsProfileWindowsConfig[];
    set osProfileWindowsConfig(value: VirtualMachineOsProfileWindowsConfig[]);
    resetOsProfileWindowsConfig(): void;
    get osProfileWindowsConfigInput(): VirtualMachineOsProfileWindowsConfig[] | undefined;
    private _plan?;
    get plan(): VirtualMachinePlan[];
    set plan(value: VirtualMachinePlan[]);
    resetPlan(): void;
    get planInput(): VirtualMachinePlan[] | undefined;
    private _storageDataDisk?;
    get storageDataDisk(): VirtualMachineStorageDataDisk[];
    set storageDataDisk(value: VirtualMachineStorageDataDisk[]);
    resetStorageDataDisk(): void;
    get storageDataDiskInput(): VirtualMachineStorageDataDisk[] | undefined;
    private _storageImageReference?;
    get storageImageReference(): VirtualMachineStorageImageReference[];
    set storageImageReference(value: VirtualMachineStorageImageReference[]);
    resetStorageImageReference(): void;
    get storageImageReferenceInput(): VirtualMachineStorageImageReference[] | undefined;
    private _storageOsDisk;
    get storageOsDisk(): VirtualMachineStorageOsDisk[];
    set storageOsDisk(value: VirtualMachineStorageOsDisk[]);
    get storageOsDiskInput(): VirtualMachineStorageOsDisk[];
    private _timeouts?;
    get timeouts(): VirtualMachineTimeouts;
    set timeouts(value: VirtualMachineTimeouts);
    resetTimeouts(): void;
    get timeoutsInput(): VirtualMachineTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
