import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface VirtualNetworkGatewayConnectionConfig extends cdktf.TerraformMetaArguments {
    readonly authorizationKey?: string;
    readonly connectionProtocol?: string;
    readonly dpdTimeoutSeconds?: number;
    readonly enableBgp?: boolean;
    readonly expressRouteCircuitId?: string;
    readonly expressRouteGatewayBypass?: boolean;
    readonly localAzureIpAddressEnabled?: boolean;
    readonly localNetworkGatewayId?: string;
    readonly location: string;
    readonly name: string;
    readonly peerVirtualNetworkGatewayId?: string;
    readonly resourceGroupName: string;
    readonly routingWeight?: number;
    readonly sharedKey?: string;
    readonly tags?: {
        [key: string]: string;
    };
    readonly type: string;
    readonly usePolicyBasedTrafficSelectors?: boolean;
    readonly virtualNetworkGatewayId: string;
    /**
     * ipsec_policy block.
     */
    readonly ipsecPolicy?: VirtualNetworkGatewayConnectionIpsecPolicy[];
    /**
     * timeouts block.
     */
    readonly timeouts?: VirtualNetworkGatewayConnectionTimeouts;
    /**
     * traffic_selector_policy block.
     */
    readonly trafficSelectorPolicy?: VirtualNetworkGatewayConnectionTrafficSelectorPolicy[];
}
export interface VirtualNetworkGatewayConnectionIpsecPolicy {
    readonly dhGroup: string;
    readonly ikeEncryption: string;
    readonly ikeIntegrity: string;
    readonly ipsecEncryption: string;
    readonly ipsecIntegrity: string;
    readonly pfsGroup: string;
    readonly saDatasize?: number;
    readonly saLifetime?: number;
}
export interface VirtualNetworkGatewayConnectionTimeouts {
    readonly create?: string;
    readonly delete?: string;
    readonly read?: string;
    readonly update?: string;
}
export interface VirtualNetworkGatewayConnectionTrafficSelectorPolicy {
    readonly localAddressCidrs: string[];
    readonly remoteAddressCidrs: string[];
}
export declare class VirtualNetworkGatewayConnection extends cdktf.TerraformResource {
    constructor(scope: Construct, id: string, config: VirtualNetworkGatewayConnectionConfig);
    private _authorizationKey?;
    get authorizationKey(): string;
    set authorizationKey(value: string);
    resetAuthorizationKey(): void;
    get authorizationKeyInput(): string | undefined;
    private _connectionProtocol?;
    get connectionProtocol(): string;
    set connectionProtocol(value: string);
    resetConnectionProtocol(): void;
    get connectionProtocolInput(): string | undefined;
    private _dpdTimeoutSeconds?;
    get dpdTimeoutSeconds(): number;
    set dpdTimeoutSeconds(value: number);
    resetDpdTimeoutSeconds(): void;
    get dpdTimeoutSecondsInput(): number | undefined;
    private _enableBgp?;
    get enableBgp(): boolean;
    set enableBgp(value: boolean);
    resetEnableBgp(): void;
    get enableBgpInput(): boolean | undefined;
    private _expressRouteCircuitId?;
    get expressRouteCircuitId(): string;
    set expressRouteCircuitId(value: string);
    resetExpressRouteCircuitId(): void;
    get expressRouteCircuitIdInput(): string | undefined;
    private _expressRouteGatewayBypass?;
    get expressRouteGatewayBypass(): boolean;
    set expressRouteGatewayBypass(value: boolean);
    resetExpressRouteGatewayBypass(): void;
    get expressRouteGatewayBypassInput(): boolean | undefined;
    get id(): string;
    private _localAzureIpAddressEnabled?;
    get localAzureIpAddressEnabled(): boolean;
    set localAzureIpAddressEnabled(value: boolean);
    resetLocalAzureIpAddressEnabled(): void;
    get localAzureIpAddressEnabledInput(): boolean | undefined;
    private _localNetworkGatewayId?;
    get localNetworkGatewayId(): string;
    set localNetworkGatewayId(value: string);
    resetLocalNetworkGatewayId(): void;
    get localNetworkGatewayIdInput(): string | undefined;
    private _location;
    get location(): string;
    set location(value: string);
    get locationInput(): string;
    private _name;
    get name(): string;
    set name(value: string);
    get nameInput(): string;
    private _peerVirtualNetworkGatewayId?;
    get peerVirtualNetworkGatewayId(): string;
    set peerVirtualNetworkGatewayId(value: string);
    resetPeerVirtualNetworkGatewayId(): void;
    get peerVirtualNetworkGatewayIdInput(): string | undefined;
    private _resourceGroupName;
    get resourceGroupName(): string;
    set resourceGroupName(value: string);
    get resourceGroupNameInput(): string;
    private _routingWeight?;
    get routingWeight(): number;
    set routingWeight(value: number);
    resetRoutingWeight(): void;
    get routingWeightInput(): number | undefined;
    private _sharedKey?;
    get sharedKey(): string;
    set sharedKey(value: string);
    resetSharedKey(): void;
    get sharedKeyInput(): string | undefined;
    private _tags?;
    get tags(): {
        [key: string]: string;
    };
    set tags(value: {
        [key: string]: string;
    });
    resetTags(): void;
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _type;
    get type(): string;
    set type(value: string);
    get typeInput(): string;
    private _usePolicyBasedTrafficSelectors?;
    get usePolicyBasedTrafficSelectors(): boolean;
    set usePolicyBasedTrafficSelectors(value: boolean);
    resetUsePolicyBasedTrafficSelectors(): void;
    get usePolicyBasedTrafficSelectorsInput(): boolean | undefined;
    private _virtualNetworkGatewayId;
    get virtualNetworkGatewayId(): string;
    set virtualNetworkGatewayId(value: string);
    get virtualNetworkGatewayIdInput(): string;
    private _ipsecPolicy?;
    get ipsecPolicy(): VirtualNetworkGatewayConnectionIpsecPolicy[];
    set ipsecPolicy(value: VirtualNetworkGatewayConnectionIpsecPolicy[]);
    resetIpsecPolicy(): void;
    get ipsecPolicyInput(): VirtualNetworkGatewayConnectionIpsecPolicy[] | undefined;
    private _timeouts?;
    get timeouts(): VirtualNetworkGatewayConnectionTimeouts;
    set timeouts(value: VirtualNetworkGatewayConnectionTimeouts);
    resetTimeouts(): void;
    get timeoutsInput(): VirtualNetworkGatewayConnectionTimeouts | undefined;
    private _trafficSelectorPolicy?;
    get trafficSelectorPolicy(): VirtualNetworkGatewayConnectionTrafficSelectorPolicy[];
    set trafficSelectorPolicy(value: VirtualNetworkGatewayConnectionTrafficSelectorPolicy[]);
    resetTrafficSelectorPolicy(): void;
    get trafficSelectorPolicyInput(): VirtualNetworkGatewayConnectionTrafficSelectorPolicy[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
