import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface VirtualNetworkGatewayConfig extends cdktf.TerraformMetaArguments {
    readonly activeActive?: boolean;
    readonly defaultLocalNetworkGatewayId?: string;
    readonly enableBgp?: boolean;
    readonly generation?: string;
    readonly location: string;
    readonly name: string;
    readonly privateIpAddressEnabled?: boolean;
    readonly resourceGroupName: string;
    readonly sku: string;
    readonly tags?: {
        [key: string]: string;
    };
    readonly type: string;
    readonly vpnType?: string;
    /**
     * bgp_settings block.
     */
    readonly bgpSettings?: VirtualNetworkGatewayBgpSettings[];
    /**
     * custom_route block.
     */
    readonly customRoute?: VirtualNetworkGatewayCustomRoute[];
    /**
     * ip_configuration block.
     */
    readonly ipConfiguration: VirtualNetworkGatewayIpConfiguration[];
    /**
     * timeouts block.
     */
    readonly timeouts?: VirtualNetworkGatewayTimeouts;
    /**
     * vpn_client_configuration block.
     */
    readonly vpnClientConfiguration?: VirtualNetworkGatewayVpnClientConfiguration[];
}
export interface VirtualNetworkGatewayBgpSettings {
    readonly asn?: number;
    readonly peerWeight?: number;
    readonly peeringAddress?: string;
}
export interface VirtualNetworkGatewayCustomRoute {
    readonly addressPrefixes?: string[];
}
export interface VirtualNetworkGatewayIpConfiguration {
    readonly name?: string;
    readonly privateIpAddressAllocation?: string;
    readonly publicIpAddressId: string;
    readonly subnetId: string;
}
export interface VirtualNetworkGatewayTimeouts {
    readonly create?: string;
    readonly delete?: string;
    readonly read?: string;
    readonly update?: string;
}
export interface VirtualNetworkGatewayVpnClientConfigurationRevokedCertificate {
    readonly name: string;
    readonly thumbprint: string;
}
export interface VirtualNetworkGatewayVpnClientConfigurationRootCertificate {
    readonly name: string;
    readonly publicCertData: string;
}
export interface VirtualNetworkGatewayVpnClientConfiguration {
    readonly aadAudience?: string;
    readonly aadIssuer?: string;
    readonly aadTenant?: string;
    readonly addressSpace: string[];
    readonly radiusServerAddress?: string;
    readonly radiusServerSecret?: string;
    readonly vpnClientProtocols?: string[];
    /**
     * revoked_certificate block.
     */
    readonly revokedCertificate?: VirtualNetworkGatewayVpnClientConfigurationRevokedCertificate[];
    /**
     * root_certificate block.
     */
    readonly rootCertificate?: VirtualNetworkGatewayVpnClientConfigurationRootCertificate[];
}
export declare class VirtualNetworkGateway extends cdktf.TerraformResource {
    constructor(scope: Construct, id: string, config: VirtualNetworkGatewayConfig);
    private _activeActive?;
    get activeActive(): boolean;
    set activeActive(value: boolean);
    resetActiveActive(): void;
    get activeActiveInput(): boolean | undefined;
    private _defaultLocalNetworkGatewayId?;
    get defaultLocalNetworkGatewayId(): string;
    set defaultLocalNetworkGatewayId(value: string);
    resetDefaultLocalNetworkGatewayId(): void;
    get defaultLocalNetworkGatewayIdInput(): string | undefined;
    private _enableBgp?;
    get enableBgp(): boolean;
    set enableBgp(value: boolean);
    resetEnableBgp(): void;
    get enableBgpInput(): boolean | undefined;
    private _generation?;
    get generation(): string;
    set generation(value: string);
    resetGeneration(): void;
    get generationInput(): string | undefined;
    get id(): string;
    private _location;
    get location(): string;
    set location(value: string);
    get locationInput(): string;
    private _name;
    get name(): string;
    set name(value: string);
    get nameInput(): string;
    private _privateIpAddressEnabled?;
    get privateIpAddressEnabled(): boolean;
    set privateIpAddressEnabled(value: boolean);
    resetPrivateIpAddressEnabled(): void;
    get privateIpAddressEnabledInput(): boolean | undefined;
    private _resourceGroupName;
    get resourceGroupName(): string;
    set resourceGroupName(value: string);
    get resourceGroupNameInput(): string;
    private _sku;
    get sku(): string;
    set sku(value: string);
    get skuInput(): string;
    private _tags?;
    get tags(): {
        [key: string]: string;
    };
    set tags(value: {
        [key: string]: string;
    });
    resetTags(): void;
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _type;
    get type(): string;
    set type(value: string);
    get typeInput(): string;
    private _vpnType?;
    get vpnType(): string;
    set vpnType(value: string);
    resetVpnType(): void;
    get vpnTypeInput(): string | undefined;
    private _bgpSettings?;
    get bgpSettings(): VirtualNetworkGatewayBgpSettings[];
    set bgpSettings(value: VirtualNetworkGatewayBgpSettings[]);
    resetBgpSettings(): void;
    get bgpSettingsInput(): VirtualNetworkGatewayBgpSettings[] | undefined;
    private _customRoute?;
    get customRoute(): VirtualNetworkGatewayCustomRoute[];
    set customRoute(value: VirtualNetworkGatewayCustomRoute[]);
    resetCustomRoute(): void;
    get customRouteInput(): VirtualNetworkGatewayCustomRoute[] | undefined;
    private _ipConfiguration;
    get ipConfiguration(): VirtualNetworkGatewayIpConfiguration[];
    set ipConfiguration(value: VirtualNetworkGatewayIpConfiguration[]);
    get ipConfigurationInput(): VirtualNetworkGatewayIpConfiguration[];
    private _timeouts?;
    get timeouts(): VirtualNetworkGatewayTimeouts;
    set timeouts(value: VirtualNetworkGatewayTimeouts);
    resetTimeouts(): void;
    get timeoutsInput(): VirtualNetworkGatewayTimeouts | undefined;
    private _vpnClientConfiguration?;
    get vpnClientConfiguration(): VirtualNetworkGatewayVpnClientConfiguration[];
    set vpnClientConfiguration(value: VirtualNetworkGatewayVpnClientConfiguration[]);
    resetVpnClientConfiguration(): void;
    get vpnClientConfigurationInput(): VirtualNetworkGatewayVpnClientConfiguration[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
