import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface VpnServerConfigurationConfig extends cdktf.TerraformMetaArguments {
    readonly location: string;
    readonly name: string;
    readonly resourceGroupName: string;
    readonly tags?: {
        [key: string]: string;
    };
    readonly vpnAuthenticationTypes: string[];
    readonly vpnProtocols?: string[];
    /**
     * azure_active_directory_authentication block.
     */
    readonly azureActiveDirectoryAuthentication?: VpnServerConfigurationAzureActiveDirectoryAuthentication[];
    /**
     * client_revoked_certificate block.
     */
    readonly clientRevokedCertificate?: VpnServerConfigurationClientRevokedCertificate[];
    /**
     * client_root_certificate block.
     */
    readonly clientRootCertificate?: VpnServerConfigurationClientRootCertificate[];
    /**
     * ipsec_policy block.
     */
    readonly ipsecPolicy?: VpnServerConfigurationIpsecPolicy[];
    /**
     * radius block.
     */
    readonly radius?: VpnServerConfigurationRadius[];
    /**
     * radius_server block.
     */
    readonly radiusServer?: VpnServerConfigurationRadiusServerA[];
    /**
     * timeouts block.
     */
    readonly timeouts?: VpnServerConfigurationTimeouts;
}
export interface VpnServerConfigurationAzureActiveDirectoryAuthentication {
    readonly audience: string;
    readonly issuer: string;
    readonly tenant: string;
}
export interface VpnServerConfigurationClientRevokedCertificate {
    readonly name: string;
    readonly thumbprint: string;
}
export interface VpnServerConfigurationClientRootCertificate {
    readonly name: string;
    readonly publicCertData: string;
}
export interface VpnServerConfigurationIpsecPolicy {
    readonly dhGroup: string;
    readonly ikeEncryption: string;
    readonly ikeIntegrity: string;
    readonly ipsecEncryption: string;
    readonly ipsecIntegrity: string;
    readonly pfsGroup: string;
    readonly saDataSizeKilobytes: number;
    readonly saLifetimeSeconds: number;
}
export interface VpnServerConfigurationRadiusClientRootCertificate {
    readonly name: string;
    readonly thumbprint: string;
}
export interface VpnServerConfigurationRadiusServer {
    readonly address: string;
    readonly score: number;
    readonly secret: string;
}
export interface VpnServerConfigurationRadiusServerRootCertificate {
    readonly name: string;
    readonly publicCertData: string;
}
export interface VpnServerConfigurationRadius {
    /**
     * client_root_certificate block.
     */
    readonly clientRootCertificate?: VpnServerConfigurationRadiusClientRootCertificate[];
    /**
     * server block.
     */
    readonly server?: VpnServerConfigurationRadiusServer[];
    /**
     * server_root_certificate block.
     */
    readonly serverRootCertificate: VpnServerConfigurationRadiusServerRootCertificate[];
}
export interface VpnServerConfigurationRadiusServerClientRootCertificate {
    readonly name: string;
    readonly thumbprint: string;
}
export interface VpnServerConfigurationRadiusServerServerRootCertificate {
    readonly name: string;
    readonly publicCertData: string;
}
export interface VpnServerConfigurationRadiusServerA {
    readonly address: string;
    readonly secret: string;
    /**
     * client_root_certificate block.
     */
    readonly clientRootCertificate?: VpnServerConfigurationRadiusServerClientRootCertificate[];
    /**
     * server_root_certificate block.
     */
    readonly serverRootCertificate: VpnServerConfigurationRadiusServerServerRootCertificate[];
}
export interface VpnServerConfigurationTimeouts {
    readonly create?: string;
    readonly delete?: string;
    readonly read?: string;
    readonly update?: string;
}
export declare class VpnServerConfiguration extends cdktf.TerraformResource {
    constructor(scope: Construct, id: string, config: VpnServerConfigurationConfig);
    get id(): string;
    private _location;
    get location(): string;
    set location(value: string);
    get locationInput(): string;
    private _name;
    get name(): string;
    set name(value: string);
    get nameInput(): string;
    private _resourceGroupName;
    get resourceGroupName(): string;
    set resourceGroupName(value: string);
    get resourceGroupNameInput(): string;
    private _tags?;
    get tags(): {
        [key: string]: string;
    };
    set tags(value: {
        [key: string]: string;
    });
    resetTags(): void;
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _vpnAuthenticationTypes;
    get vpnAuthenticationTypes(): string[];
    set vpnAuthenticationTypes(value: string[]);
    get vpnAuthenticationTypesInput(): string[];
    private _vpnProtocols?;
    get vpnProtocols(): string[];
    set vpnProtocols(value: string[]);
    resetVpnProtocols(): void;
    get vpnProtocolsInput(): string[] | undefined;
    private _azureActiveDirectoryAuthentication?;
    get azureActiveDirectoryAuthentication(): VpnServerConfigurationAzureActiveDirectoryAuthentication[];
    set azureActiveDirectoryAuthentication(value: VpnServerConfigurationAzureActiveDirectoryAuthentication[]);
    resetAzureActiveDirectoryAuthentication(): void;
    get azureActiveDirectoryAuthenticationInput(): VpnServerConfigurationAzureActiveDirectoryAuthentication[] | undefined;
    private _clientRevokedCertificate?;
    get clientRevokedCertificate(): VpnServerConfigurationClientRevokedCertificate[];
    set clientRevokedCertificate(value: VpnServerConfigurationClientRevokedCertificate[]);
    resetClientRevokedCertificate(): void;
    get clientRevokedCertificateInput(): VpnServerConfigurationClientRevokedCertificate[] | undefined;
    private _clientRootCertificate?;
    get clientRootCertificate(): VpnServerConfigurationClientRootCertificate[];
    set clientRootCertificate(value: VpnServerConfigurationClientRootCertificate[]);
    resetClientRootCertificate(): void;
    get clientRootCertificateInput(): VpnServerConfigurationClientRootCertificate[] | undefined;
    private _ipsecPolicy?;
    get ipsecPolicy(): VpnServerConfigurationIpsecPolicy[];
    set ipsecPolicy(value: VpnServerConfigurationIpsecPolicy[]);
    resetIpsecPolicy(): void;
    get ipsecPolicyInput(): VpnServerConfigurationIpsecPolicy[] | undefined;
    private _radius?;
    get radius(): VpnServerConfigurationRadius[];
    set radius(value: VpnServerConfigurationRadius[]);
    resetRadius(): void;
    get radiusInput(): VpnServerConfigurationRadius[] | undefined;
    private _radiusServer?;
    get radiusServer(): VpnServerConfigurationRadiusServerA[];
    set radiusServer(value: VpnServerConfigurationRadiusServerA[]);
    resetRadiusServer(): void;
    get radiusServerInput(): VpnServerConfigurationRadiusServerA[] | undefined;
    private _timeouts?;
    get timeouts(): VpnServerConfigurationTimeouts;
    set timeouts(value: VpnServerConfigurationTimeouts);
    resetTimeouts(): void;
    get timeoutsInput(): VpnServerConfigurationTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
