import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface WindowsVirtualMachineConfig extends cdktf.TerraformMetaArguments {
    readonly adminPassword: string;
    readonly adminUsername: string;
    readonly allowExtensionOperations?: boolean;
    readonly availabilitySetId?: string;
    readonly computerName?: string;
    readonly customData?: string;
    readonly dedicatedHostId?: string;
    readonly enableAutomaticUpdates?: boolean;
    readonly encryptionAtHostEnabled?: boolean;
    readonly evictionPolicy?: string;
    readonly extensionsTimeBudget?: string;
    readonly licenseType?: string;
    readonly location: string;
    readonly maxBidPrice?: number;
    readonly name: string;
    readonly networkInterfaceIds: string[];
    readonly patchMode?: string;
    readonly priority?: string;
    readonly provisionVmAgent?: boolean;
    readonly proximityPlacementGroupId?: string;
    readonly resourceGroupName: string;
    readonly size: string;
    readonly sourceImageId?: string;
    readonly tags?: {
        [key: string]: string;
    };
    readonly timezone?: string;
    readonly virtualMachineScaleSetId?: string;
    readonly zone?: string;
    /**
     * additional_capabilities block.
     */
    readonly additionalCapabilities?: WindowsVirtualMachineAdditionalCapabilities[];
    /**
     * additional_unattend_content block.
     */
    readonly additionalUnattendContent?: WindowsVirtualMachineAdditionalUnattendContent[];
    /**
     * boot_diagnostics block.
     */
    readonly bootDiagnostics?: WindowsVirtualMachineBootDiagnostics[];
    /**
     * identity block.
     */
    readonly identity?: WindowsVirtualMachineIdentity[];
    /**
     * os_disk block.
     */
    readonly osDisk: WindowsVirtualMachineOsDisk[];
    /**
     * plan block.
     */
    readonly plan?: WindowsVirtualMachinePlan[];
    /**
     * secret block.
     */
    readonly secret?: WindowsVirtualMachineSecret[];
    /**
     * source_image_reference block.
     */
    readonly sourceImageReference?: WindowsVirtualMachineSourceImageReference[];
    /**
     * timeouts block.
     */
    readonly timeouts?: WindowsVirtualMachineTimeouts;
    /**
     * winrm_listener block.
     */
    readonly winrmListener?: WindowsVirtualMachineWinrmListener[];
}
export interface WindowsVirtualMachineAdditionalCapabilities {
    readonly ultraSsdEnabled?: boolean;
}
export interface WindowsVirtualMachineAdditionalUnattendContent {
    readonly content: string;
    readonly setting: string;
}
export interface WindowsVirtualMachineBootDiagnostics {
    readonly storageAccountUri?: string;
}
export interface WindowsVirtualMachineIdentity {
    readonly identityIds?: string[];
    readonly type: string;
}
export interface WindowsVirtualMachineOsDiskDiffDiskSettings {
    readonly option: string;
}
export interface WindowsVirtualMachineOsDisk {
    readonly caching: string;
    readonly diskEncryptionSetId?: string;
    readonly diskSizeGb?: number;
    readonly name?: string;
    readonly storageAccountType: string;
    readonly writeAcceleratorEnabled?: boolean;
    /**
     * diff_disk_settings block.
     */
    readonly diffDiskSettings?: WindowsVirtualMachineOsDiskDiffDiskSettings[];
}
export interface WindowsVirtualMachinePlan {
    readonly name: string;
    readonly product: string;
    readonly publisher: string;
}
export interface WindowsVirtualMachineSecretCertificate {
    readonly store: string;
    readonly url: string;
}
export interface WindowsVirtualMachineSecret {
    readonly keyVaultId: string;
    /**
     * certificate block.
     */
    readonly certificate: WindowsVirtualMachineSecretCertificate[];
}
export interface WindowsVirtualMachineSourceImageReference {
    readonly offer: string;
    readonly publisher: string;
    readonly sku: string;
    readonly version: string;
}
export interface WindowsVirtualMachineTimeouts {
    readonly create?: string;
    readonly delete?: string;
    readonly read?: string;
    readonly update?: string;
}
export interface WindowsVirtualMachineWinrmListener {
    readonly certificateUrl?: string;
    readonly protocol: string;
}
export declare class WindowsVirtualMachine extends cdktf.TerraformResource {
    constructor(scope: Construct, id: string, config: WindowsVirtualMachineConfig);
    private _adminPassword;
    get adminPassword(): string;
    set adminPassword(value: string);
    get adminPasswordInput(): string;
    private _adminUsername;
    get adminUsername(): string;
    set adminUsername(value: string);
    get adminUsernameInput(): string;
    private _allowExtensionOperations?;
    get allowExtensionOperations(): boolean;
    set allowExtensionOperations(value: boolean);
    resetAllowExtensionOperations(): void;
    get allowExtensionOperationsInput(): boolean | undefined;
    private _availabilitySetId?;
    get availabilitySetId(): string;
    set availabilitySetId(value: string);
    resetAvailabilitySetId(): void;
    get availabilitySetIdInput(): string | undefined;
    private _computerName?;
    get computerName(): string;
    set computerName(value: string);
    resetComputerName(): void;
    get computerNameInput(): string | undefined;
    private _customData?;
    get customData(): string;
    set customData(value: string);
    resetCustomData(): void;
    get customDataInput(): string | undefined;
    private _dedicatedHostId?;
    get dedicatedHostId(): string;
    set dedicatedHostId(value: string);
    resetDedicatedHostId(): void;
    get dedicatedHostIdInput(): string | undefined;
    private _enableAutomaticUpdates?;
    get enableAutomaticUpdates(): boolean;
    set enableAutomaticUpdates(value: boolean);
    resetEnableAutomaticUpdates(): void;
    get enableAutomaticUpdatesInput(): boolean | undefined;
    private _encryptionAtHostEnabled?;
    get encryptionAtHostEnabled(): boolean;
    set encryptionAtHostEnabled(value: boolean);
    resetEncryptionAtHostEnabled(): void;
    get encryptionAtHostEnabledInput(): boolean | undefined;
    private _evictionPolicy?;
    get evictionPolicy(): string;
    set evictionPolicy(value: string);
    resetEvictionPolicy(): void;
    get evictionPolicyInput(): string | undefined;
    private _extensionsTimeBudget?;
    get extensionsTimeBudget(): string;
    set extensionsTimeBudget(value: string);
    resetExtensionsTimeBudget(): void;
    get extensionsTimeBudgetInput(): string | undefined;
    get id(): string;
    private _licenseType?;
    get licenseType(): string;
    set licenseType(value: string);
    resetLicenseType(): void;
    get licenseTypeInput(): string | undefined;
    private _location;
    get location(): string;
    set location(value: string);
    get locationInput(): string;
    private _maxBidPrice?;
    get maxBidPrice(): number;
    set maxBidPrice(value: number);
    resetMaxBidPrice(): void;
    get maxBidPriceInput(): number | undefined;
    private _name;
    get name(): string;
    set name(value: string);
    get nameInput(): string;
    private _networkInterfaceIds;
    get networkInterfaceIds(): string[];
    set networkInterfaceIds(value: string[]);
    get networkInterfaceIdsInput(): string[];
    private _patchMode?;
    get patchMode(): string;
    set patchMode(value: string);
    resetPatchMode(): void;
    get patchModeInput(): string | undefined;
    private _priority?;
    get priority(): string;
    set priority(value: string);
    resetPriority(): void;
    get priorityInput(): string | undefined;
    get privateIpAddress(): string;
    get privateIpAddresses(): string[];
    private _provisionVmAgent?;
    get provisionVmAgent(): boolean;
    set provisionVmAgent(value: boolean);
    resetProvisionVmAgent(): void;
    get provisionVmAgentInput(): boolean | undefined;
    private _proximityPlacementGroupId?;
    get proximityPlacementGroupId(): string;
    set proximityPlacementGroupId(value: string);
    resetProximityPlacementGroupId(): void;
    get proximityPlacementGroupIdInput(): string | undefined;
    get publicIpAddress(): string;
    get publicIpAddresses(): string[];
    private _resourceGroupName;
    get resourceGroupName(): string;
    set resourceGroupName(value: string);
    get resourceGroupNameInput(): string;
    private _size;
    get size(): string;
    set size(value: string);
    get sizeInput(): string;
    private _sourceImageId?;
    get sourceImageId(): string;
    set sourceImageId(value: string);
    resetSourceImageId(): void;
    get sourceImageIdInput(): string | undefined;
    private _tags?;
    get tags(): {
        [key: string]: string;
    };
    set tags(value: {
        [key: string]: string;
    });
    resetTags(): void;
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _timezone?;
    get timezone(): string;
    set timezone(value: string);
    resetTimezone(): void;
    get timezoneInput(): string | undefined;
    get virtualMachineId(): string;
    private _virtualMachineScaleSetId?;
    get virtualMachineScaleSetId(): string;
    set virtualMachineScaleSetId(value: string);
    resetVirtualMachineScaleSetId(): void;
    get virtualMachineScaleSetIdInput(): string | undefined;
    private _zone?;
    get zone(): string;
    set zone(value: string);
    resetZone(): void;
    get zoneInput(): string | undefined;
    private _additionalCapabilities?;
    get additionalCapabilities(): WindowsVirtualMachineAdditionalCapabilities[];
    set additionalCapabilities(value: WindowsVirtualMachineAdditionalCapabilities[]);
    resetAdditionalCapabilities(): void;
    get additionalCapabilitiesInput(): WindowsVirtualMachineAdditionalCapabilities[] | undefined;
    private _additionalUnattendContent?;
    get additionalUnattendContent(): WindowsVirtualMachineAdditionalUnattendContent[];
    set additionalUnattendContent(value: WindowsVirtualMachineAdditionalUnattendContent[]);
    resetAdditionalUnattendContent(): void;
    get additionalUnattendContentInput(): WindowsVirtualMachineAdditionalUnattendContent[] | undefined;
    private _bootDiagnostics?;
    get bootDiagnostics(): WindowsVirtualMachineBootDiagnostics[];
    set bootDiagnostics(value: WindowsVirtualMachineBootDiagnostics[]);
    resetBootDiagnostics(): void;
    get bootDiagnosticsInput(): WindowsVirtualMachineBootDiagnostics[] | undefined;
    private _identity?;
    get identity(): WindowsVirtualMachineIdentity[];
    set identity(value: WindowsVirtualMachineIdentity[]);
    resetIdentity(): void;
    get identityInput(): WindowsVirtualMachineIdentity[] | undefined;
    private _osDisk;
    get osDisk(): WindowsVirtualMachineOsDisk[];
    set osDisk(value: WindowsVirtualMachineOsDisk[]);
    get osDiskInput(): WindowsVirtualMachineOsDisk[];
    private _plan?;
    get plan(): WindowsVirtualMachinePlan[];
    set plan(value: WindowsVirtualMachinePlan[]);
    resetPlan(): void;
    get planInput(): WindowsVirtualMachinePlan[] | undefined;
    private _secret?;
    get secret(): WindowsVirtualMachineSecret[];
    set secret(value: WindowsVirtualMachineSecret[]);
    resetSecret(): void;
    get secretInput(): WindowsVirtualMachineSecret[] | undefined;
    private _sourceImageReference?;
    get sourceImageReference(): WindowsVirtualMachineSourceImageReference[];
    set sourceImageReference(value: WindowsVirtualMachineSourceImageReference[]);
    resetSourceImageReference(): void;
    get sourceImageReferenceInput(): WindowsVirtualMachineSourceImageReference[] | undefined;
    private _timeouts?;
    get timeouts(): WindowsVirtualMachineTimeouts;
    set timeouts(value: WindowsVirtualMachineTimeouts);
    resetTimeouts(): void;
    get timeoutsInput(): WindowsVirtualMachineTimeouts | undefined;
    private _winrmListener?;
    get winrmListener(): WindowsVirtualMachineWinrmListener[];
    set winrmListener(value: WindowsVirtualMachineWinrmListener[]);
    resetWinrmListener(): void;
    get winrmListenerInput(): WindowsVirtualMachineWinrmListener[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
